;;; rdf-prefix.el --- Prefix lookup for RDF  -*- lexical-binding: t; -*-

;; Copyright (C) 2014-2024 Simen Heggestøyl

;; Author: Simen Heggestøyl <simenheg@runbox.com>
;; Maintainer: Simen Heggestøyl <simenheg@runbox.com>
;; Version: 1.14
;; Keywords: convenience, abbrev
;; Homepage: https://github.com/simenheg/rdf-prefix

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.

;;; Commentary:

;; The intention of this package is to simplify a common task in the
;; work of RDF developers: remembering and looking up URI prefixes.
;;
;; The `rdf-prefix-insert' command is used to look up- and insert URIs
;; based on a prefix.
;;
;; RDF prefixes are mapped to URIs by the alist `rdf-prefix-alist'. New
;; prefixes can be defined by adding them to `rdf-prefix-alist', on the
;; form (PREFIX . URI), where PREFIX and URI are both strings.
;;
;; The prefix list is updated regularly from http://prefix.cc/.

;;; Code:

(defvar rdf-prefix-alist
  '(("aair" . "http://xmlns.notu.be/aair#")
    ("aao" . "http://purl.obolibrary.org/obo/AAO_")
    ("aapi" . "http://rdf.alchemyapi.com/rdf/v1/s/aapi-schema#")
    ("aat" . "http://vocab.getty.edu/aat/")
    ("abc" . "http://www.metadata.net/harmony/ABCSchemaV5Commented.rdf#")
    ("abs" . "http://abs.270a.info/dataset/")
    ("ac" . "http://umbel.org/umbel/ac/")
    ("acc" . "http://purl.org/NET/acc#")
    ("accid" . "http://pid.accurids.com/")
    ("acco" . "http://purl.org/acco/ns#")
    ("accom" . "http://purl.org/acco/ns#")
    ("acl" . "http://www.w3.org/ns/auth/acl#")
    ("acm" . "http://www.rkbexplorer.com/ontologies/acm#")
    ("acp" . "http://www.w3.org/ns/solid/acp#")
    ("acrt" . "http://privatealpha.com/ontology/certification/1#")
    ("act" . "http://www.w3.org/2007/rif-builtin-action#")
    ("activity" . "https://www.w3.org/TR/activitystreams-vocabulary/")
    ("ad" . "http://schemas.talis.com/2005/address/schema#")
    ("add" . "http://www.datatourisme.fr/ontology/core/1.0#")
    ("address" . "http://schemas.talis.com/2005/address/schema#")
    ("adf" . "http://purl.allotrope.org/ontologies/datapackage#")
    ("admin" . "http://webns.net/mvcb/")
    ("admingeo" . "http://data.ordnancesurvey.co.uk/ontology/admingeo/")
    ("adms" . "http://www.w3.org/ns/adms#")
    ("admssw" . "http://purl.org/adms/sw/")
    ("ado" . "http://purl.obolibrary.org/obo/ADO_")
    ("adr" . "http://kg.artsdata.ca/resource/")
    ("adw" . "https://animaldiversity.org/accounts/")
    ("aec3po" . "https://w3id.org/lbd/aec3po/")
    ("aerols" . "http://xmlns.com/aerols/0.1/")
    ("aers" . "http://aers.data2semantics.org/resource/")
    ("aersv" . "http://aers.data2semantics.org/vocab/")
    ("af" . "http://purl.org/ontology/af/")
    ("aff" . "https://w3id.org/affectedBy#")
    ("affy" . "http://www.affymetrix.com/community/publications/affymetrix/tmsplice#")
    ("affymetrix" . "http://bio2rdf.org/affymetrix_vocabulary:")
    ("afm" . "http://purl.allotrope.org/ontologies/material/")
    ("afn" . "http://jena.apache.org/ARQ/function#")
    ("afr" . "http://purl.allotrope.org/ontologies/result#")
    ("agent" . "http://eulersharp.sourceforge.net/2003/03swap/agent#")
    ("agents" . "http://eulersharp.sourceforge.net/2003/03swap/agent#")
    ("agetec" . "http://www.agetec.org/")
    ("agg" . "http://purl.org/twc/health/vocab/aggregate/")
    ("agls" . "http://www.agls.gov.au/agls/terms/")
    ("ago" . "http://awesemantic-geo.link/ontology/")
    ("agr" . "http://promsns.org/def/agr#")
    ("agrd" . "http://agrinepaldata.com/")
    ("agrelon" . "http://d-nb.info/standards/elementset/agrelon#")
    ("agro" . "http://purl.obolibrary.org/obo/agro.owl#")
    ("agrovoc" . "http://aims.fao.org/aos/agrovoc/")
    ("ags" . "https://id.agschemas.org/")
    ("aifb" . "http://www.aifb.kit.edu/id/")
    ("aigp" . "http://swat.cse.lehigh.edu/resources/onto/aigp.owl#")
    ("aiiso" . "http://purl.org/vocab/aiiso/schema#")
    ("aims" . "http://aims.fao.org/aos/common/")
    ("air" . "http://dig.csail.mit.edu/TAMI/2007/amord/air#")
    ("airport" . "http://www.daml.org/2001/10/html/airport-ont#")
    ("airs" . "https://raw.githubusercontent.com/airs-linked-data/lov/latest/src/airs_vocabulary.ttl#")
    ("aksw" . "http://aksw.org/")
    ("akt" . "http://www.aktors.org/ontology/portal#")
    ("aktivesa" . "http://sa.aktivespace.org/ontologies/aktivesa#")
    ("akts" . "http://www.aktors.org/ontology/support#")
    ("alchemy" . "http://rdf.alchemyapi.com/rdf/v1/s/aapi-schema#")
    ("alethio" . "http://aleth.io/")
    ("alg" . "http://drakon.su/ADF#")
    ("algo" . "http://securitytoolbox.appspot.com/securityAlgorithms#")
    ("ali" . "http://www.niso.org/schemas/ali/1.0/")
    ("alice" . "http://example.org/")
    ("allot" . "https://w3id.org/akn/ontology/allot#")
    ("am" . "http://vocab.deri.ie/am#")
    ("amalgame" . "http://purl.org/vocabularies/amalgame#")
    ("aml" . "https://w3id.org/i40/aml#")
    ("ammo" . "http://ldf.fi/schema/ammo/")
    ("ams" . "http://data.amadeus.com/")
    ("amsl" . "http://vocab.ub.uni-leipzig.de/amsl/")
    ("amt" . "http://academic-meta-tool.xyz/vocab#")
    ("anca" . "http://users.utcluj.ro/~raluca/rdf_ontologies_ralu/ralu_modified_ontology_pizzas2_0#")
    ("aneo" . "http://akonadi-project.org/ontologies/aneo#")
    ("ann" . "http://www.w3.org/2000/10/annotation-ns#")
    ("antenne" . "https://data.zendantennes.omgeving.vlaanderen.be/ns/zendantenne#")
    ("ao" . "http://purl.org/ontology/ao/core#")
    ("aos" . "http://rdf.muninn-project.org/ontologies/appearances#")
    ("aozora" . "http://purl.org/net/aozora/")
    ("apb" . "http://www.analysispartners.org/businessmodel/")
    ("apf" . "http://jena.apache.org/ARQ/property#")
    ("api" . "http://purl.org/linked-data/api/vocab#")
    ("apivc" . "http://purl.org/linked-data/api/vocab#")
    ("apods" . "http://activitypods.org/ns/core#")
    ("app" . "http://jmvanel.free.fr/ontology/software_applications.n3#")
    ("aprov" . "http://purl.org/a-proc#")
    ("arch" . "http://purl.org/archival/vocab/arch#")
    ("archdesc" . "http://archdesc.info/archEvent#")
    ("archivo" . "https://archivo.dbpedia.org/onto#")
    ("arecipe" . "http://purl.org/amicroformat/arecipe/")
    ("arena" . "https://solid.ti.rw.fau.de/public/ns/arena#")
    ("arg" . "http://rdfs.org/sioc/argument#")
    ("arp" . "http://www.arpenteur.org/ontology/Arpenteur.owl#")
    ("arpfo" . "http://vocab.ouls.ox.ac.uk/projectfunding#")
    ("art" . "http://w3id.org/art/terms/1.0/")
    ("article" . "http://ogp.me/ns/article#")
    ("artstor" . "http://simile.mit.edu/2003/10/ontologies/artstor#")
    ("as" . "https://www.w3.org/ns/activitystreams#")
    ("asawoo" . "http://liris.cnrs.fr/asawoo/")
    ("asb" . "https://w3id.org/asbingowl/core#")
    ("aseonto" . "http://requirement.ase.ru/requirements_ontology#")
    ("asf" . "https://www.stm-assoc.org/asf/")
    ("asgs" . "http://linked.data.gov.au/def/asgs#")
    ("asgv" . "http://aims.fao.org/aos/agrovoc/")
    ("asio" . "http://purl.org/hercules/asio/core#")
    ("asn" . "http://purl.org/ASN/schema/core/")
    ("aspect" . "http://purl.org/aspect/")
    ("ass" . "http://uptheasset.org/ontology#")
    ("assoc" . "https://w3id.org/associations/vocab#")
    ("atcc" . "https://www.atcc.org/products/")
    ("atd" . "https://data.nasa.gov/ontologies/atmonto/data#")
    ("atlas" . "http://rdf.ebi.ac.uk/resource/atlas/")
    ("atlasterms" . "http://rdf.ebi.ac.uk/terms/atlas/")
    ("atm" . "https://data.nasa.gov/ontologies/atmonto/ATM#")
    ("atom" . "http://www.w3.org/2005/Atom/")
    ("atomix" . "http://buzzword.org.uk/rdf/atomix#")
    ("atomowl" . "http://bblfish.net/work/atom-owl/2006-06-06/#")
    ("atomrdf" . "http://atomowl.org/ontologies/atomrdf#")
    ("atts" . "https://data.nasa.gov/ontologies/atmonto/general#")
    ("audio" . "http://purl.org/media/audio#")
    ("audit" . "http://fedora.info/definitions/v4/audit#")
    ("auto" . "http://auto.schema.org/")
    ("awol" . "http://bblfish.net/work/atom-owl/2006-06-06/#")
    ("aws" . "http://purl.oclc.org/NET/ssnx/meteo/aws#")
    ("az" . "https://w3id.org/people/az/")
    ("b2bo" . "http://purl.org/b2bo#")
    ("b2rpubchem" . "http://bio2rdf.org/ns/ns/ns/pubchem#")
    ("b3kat" . "http://lod.b3kat.de/title/")
    ("babelnet" . "http://babelnet.org/2.0/")
    ("bacnet" . "http://data.ashrae.org/bacnet/2020#")
    ("baf" . "https://w3id.org/baf#")
    ("bag" . "https://bag2.basisregistraties.overheid.nl/bag/def/")
    ("bag2" . "http://bag.basisregistraties.overheid.nl/def/bag#")
    ("bao" . "http://www.bioassayontology.org/bao#")
    ("basic" . "http://def.seegrid.csiro.au/isotc211/iso19103/2005/basic#")
    ("batmanont" . "http://emmo.info/emmo/application/bmo#")
    ("bau" . "https://terminology.fraunhofer.de/voc/bau#")
    ("bb" . "http://www.snik.eu/ontology/bb/")
    ("bbc" . "http://www.bbc.co.uk/ontologies/news/")
    ("bbccms" . "http://www.bbc.co.uk/ontologies/cms/")
    ("bbccore" . "http://www.bbc.co.uk/ontologies/coreconcepts/")
    ("bbcprov" . "http://www.bbc.co.uk/ontologies/provenance/")
    ("bblfish" . "http://bblfish.net/people/henry/card#")
    ("bcfowl" . "http://lbd.arch.rwth-aachen.de/bcfOWL#")
    ("bcgo" . "http://purl.obolibrary.org/obo/ZP_")
    ("bci" . "https://w3id.org/BCI-ontology#")
    ("bcnbio" . "http://datos.bcn.cl/ontologies/bcn-biographies#")
    ("bcncon" . "http://datos.bcn.cl/ontologies/bcn-congress#")
    ("bcngeo" . "http://datos.bcn.cl/ontologies/bcn-geographics#")
    ("bcnnorms" . "http://datos.bcn.cl/ontologies/bcn-norms#")
    ("bco" . "http://purl.obolibrary.org/obo/bco.owl#")
    ("bcom" . "https://w3id.org/bcom#")
    ("bd" . "http://www.bigdata.com/rdf#")
    ("bdc" . "http://dbpedia.org/resource/Category:")
    ("bdd" . "https://api.bloomberg.com/eap/catalogs/bbg/fields/")
    ("bdg" . "http://data.bigdatagrapes.eu/resource/ontology/")
    ("bdo" . "http://purl.bdrc.io/ontology/core/")
    ("bdr" . "http://purl.bdrc.io/resource/")
    ("bds" . "http://www.bigdata.com/rdf/search#")
    ("bdsubj" . "https://purl.org/fidbaudigital/subjects#")
    ("beer" . "http://beer.com/")
    ("being" . "http://purl.org/ontomedia/ext/common/being#")
    ("beo" . "http://pi.pauwel.be/voc/buildingelement#")
    ("besluit" . "http://data.vlaanderen.be/ns/besluit#")
    ("besluitvor" . "https://data.vlaanderen.be/ns/besluitvorming#")
    ("beth" . "http://www.google.com/")
    ("bevon" . "http://rdfs.co/bevon/")
    ("bf" . "http://id.loc.gov/ontologies/bibframe/")
    ("bflc" . "http://id.loc.gov/ontologies/bflc/")
    ("bfo" . "http://purl.obolibrary.org/obo/")
    ("bgcat" . "http://bg.dbpedia.org/resource/Категория:")
    ("bgdbp" . "http://bg.dbpedia.org/property/")
    ("bgdbr" . "http://bg.dbpedia.org/resource/")
    ("bgn" . "http://bibliograph.net/schemas/")
    ("bgt" . "https://bgt.basisregistraties.overheid.nl/bgt/def/")
    ("bib" . "http://zeitkunst.org/bibtex/0.1/bibtex.owl#")
    ("bibframe" . "http://id.loc.gov/ontologies/bibframe/")
    ("biblio" . "http://purl.org/net/biblio#")
    ("bibo" . "http://purl.org/ontology/bibo/")
    ("bibrm" . "http://vocab.ub.uni-leipzig.de/bibrm/")
    ("bibtex" . "http://purl.org/net/nknouf/ns/bibtex#")
    ("bif" . "http://www.openlinksw.com/schemas/bif#")
    ("bihap" . "http://bihap.kb.gov.tr/ontology/")
    ("bill" . "http://www.rdfabout.com/rdf/schema/usbill/")
    ("biml" . "http://schemas.varigence.com/biml.xsd#")
    ("bing" . "http://bing.com/schema/media/")
    ("bio" . "http://purl.org/vocab/bio/0.1/")
    ("bio2rdf" . "http://bio2rdf.org/")
    ("bioc" . "http://deductions.github.io/biological-collections.owl.ttl#")
    ("biocore" . "http://bio2rdf.org/core#")
    ("biocrm" . "http://ldf.fi/schema/bioc/")
    ("bioentity" . "http://bioentity.io/vocab/")
    ("biogrid" . "http://thebiogrid.org/")
    ("biol" . "http://purl.org/NET/biol/ns#")
    ("biolink" . "https://w3id.org/biolink/vocab/")
    ("biopax" . "http://www.biopax.org/release/biopax-level3.owl#")
    ("biordf" . "http://purl.org/net/biordfmicroarray/ns#")
    ("bioschemas" . "https://bioschemas.org/")
    ("bioskos" . "http://eulersharp.sourceforge.net/2003/03swap/bioSKOSSchemes#")
    ("biotop" . "http://purl.org/biotop/biotop.owl#")
    ("biro" . "http://purl.org/spar/biro/")
    ("birthdate" . "http://schema.org/birthDate/")
    ("bis" . "http://bis.270a.info/dataset/")
    ("bitl" . "http://lib.bit.edu.cn/ontology/1.0/")
    ("bk" . "http://www.provbook.org/ns/#")
    ("bkb" . "https://budayakb.cs.ui.ac.id/ns#")
    ("bl" . "https://w3id.org/biolink/vocab/")
    ("bld" . "http://biglinkeddata.com/")
    ("bldont" . "http://ont.biglinkeddata.com/")
    ("ble" . "http://vocab.rapidthings.eu/ns/ble.ttl#")
    ("bleadapter" . "http://vocab.rapidthings.eu/ns/ble/adapter.ttl#")
    ("blt" . "http://www.bl.uk/schemas/bibliographic/blterms#")
    ("bm" . "http://bio2rdf.org/")
    ("bmo" . "http://collection.britishmuseum.org/id/ontology/")
    ("bmp" . "http://w3id.org/bmp#")
    ("bn" . "http://babelnet.org/rdf/")
    ("bne" . "http://datos.bne.es/resource/")
    ("bner" . "http://datos.bne.es/resource/")
    ("bnf" . "http://www.w3.org/2000/10/swap/grammar/bnf#")
    ("bob" . "http://good.dad/meaning/bob#")
    ("book" . "http://purl.org/NET/book/vocab#")
    ("bookmark" . "http://www.w3.org/2002/01/bookmark#")
    ("bop" . "https://w3id.org/bop#")
    ("bot" . "https://w3id.org/bot#")
    ("botany" . "http://purl.org/NET/biol/botany#")
    ("bp" . "http://www.biopax.org/release/biopax-level3.owl#")
    ("bp3" . "http://www.biopax.org/release/biopax-level3.owl#")
    ("bperson" . "http://data.vlaanderen.be/ns/persoon#")
    ("bpo" . "https://w3id.org/bpo#")
    ("br" . "http://vocab.deri.ie/br#")
    ("brick" . "https://brickschema.org/schema/Brick#")
    ("bridge" . "http://purl.org/vocommons/bridge#")
    ("brk" . "http://brk.basisregistraties.overheid.nl/def/brk#")
    ("brot" . "https://w3id.org/brot#")
    ("brt" . "http://brt.basisregistraties.overheid.nl/def/top10nl#")
    ("bs" . "https://w3id.org/def/basicsemantics-owl#")
    ("bsb" . "http://opacplus.bsb-muenchen.de/title/")
    ("bsbm" . "http://www4.wiwiss.fu-berlin.de/bizer/bsbm/v01/vocabulary/")
    ("bsdd" . "http://bsdd.buildingsmart.org/def#")
    ("bsh" . "https://brickschema.org/schema/1.1.0/BrickShape#")
    ("bsym" . "http://bsym.bloomberg.com/sym/")
    ("bte" . "http://purl.org/twc/vocab/between-the-edges/")
    ("bto" . "http://w3id.org/emmo-bto/bto#")
    ("bv" . "http://purl.org/vocommons/bv#")
    ("bwb" . "http://doc.metalex.eu/bwb/ontology/")
    ("c4dm" . "http://purl.org/NET/c4dm/event.owl#")
    ("c4n" . "http://vocab.deri.ie/c4n#")
    ("c4o" . "http://purl.org/spar/c4o/")
    ("c9d" . "http://purl.org/twc/vocab/conversion/")
    ("ca" . "http://complyadvantage.com/")
    ("cacax" . "http://cacax.fun/")
    ("cal" . "http://www.w3.org/2002/12/cal/ical#")
    ("call" . "http://webofcode.org/wfn/call:")
    ("calli" . "http://callimachusproject.org/rdf/2009/framework#")
    ("camelot" . "http://vocab.ox.ac.uk/camelot#")
    ("campsite" . "http://www.openlinksw.com/campsites/schema#")
    ("cao" . "http://purl.org/makolab/caont/")
    ("capes" . "http://vocab.capes.gov.br/def/vcav#")
    ("caplibacl" . "http://schemas.capita-libraries.co.uk/2015/acl/schema#")
    ("card" . "http://www.ashutosh.com/test/")
    ("care" . "http://eulersharp.sourceforge.net/2003/03swap/care#")
    ("carfo" . "http://purl.org/carfo#")
    ("cart" . "http://purl.org/net/cartCoord#")
    ("caso" . "http://www.w3id.org/def/caso#")
    ("category" . "http://dbpedia.org/resource/Category:")
    ("cb" . "http://cbasewrap.ontologycentral.com/vocab#")
    ("cbase" . "http://ontologycentral.com/2010/05/cb/vocab#")
    ("cbb" . "https://data.cbb.omgeving.vlaanderen.be/ns/cbb#")
    ("cbim" . "http://www.coinsweb.nl/cbim-2.0.rdf#")
    ("cbo" . "http://comicmeta.org/cbo/")
    ("cbs" . "http://betalinkeddata.cbs.nl/def/cbs#")
    ("cbv" . "https://ns.gs1.org/cbv/")
    ("cc" . "http://creativecommons.org/ns#")
    ("ccard" . "http://purl.org/commerce/creditcard#")
    ("cci" . "http://cookingbigdata.com/linkeddata/ccinstances#")
    ("cco" . "http://www.ontologyrepository.com/CommonCoreOntologies/")
    ("ccom" . "http://purl.org/ontology/cco/mappings#")
    ("ccomid" . "http://www.ontologyrepository.com/CommonCoreOntologies/Mid/")
    ("ccp" . "http://cookingbigdata.com/linkeddata/ccpricing#")
    ("ccr" . "http://cookingbigdata.com/linkeddata/ccregions#")
    ("ccrel" . "http://creativecommons.org/ns#")
    ("ccsla" . "http://cookingbigdata.com/linkeddata/ccsla#")
    ("cd" . "http://citydata.wu.ac.at/ns#")
    ("cdao" . "http://purl.obolibrary.org/obo/")
    ("cdc" . "https://w3id.org/cdc#")
    ("cdm" . "http://publications.europa.eu/ontology/cdm#")
    ("cdt" . "https://w3id.org/cdt/")
    ("cdtype" . "http://purl.org/cld/cdtype/")
    ("centrifuge" . "http://purl.org/twc/vocab/centrifuge#")
    ("ceo" . "https://linkeddata.cultureelerfgoed.nl/def/ceo#")
    ("ceosp" . "https://linkeddata.cultureelerfgoed.nl/def/ceosp/")
    ("ceox" . "https://linkeddata.cultureelerfgoed.nl/def/ceox#")
    ("cercabib" . "https://cercabib.ub.edu/")
    ("cerealstoo" . "http://rdf.ag/o/cerealstoo#")
    ("cergy" . "https://dbpedia.org/page/Cergy/")
    ("cerif" . "http://spi-fm.uca.es/neologism/cerif#")
    ("cert" . "http://www.w3.org/ns/auth/cert#")
    ("ceterms" . "http://purl.org/ctdl/terms/")
    ("cex" . "http://purl.org/weso/ontology/computex#")
    ("cf" . "http://mmisw.org/ont/cf/parameter/")
    ("cff" . "http://purl.oclc.org/NET/ssnx/cf/cf-feature#")
    ("cfp" . "http://sw.deri.org/2005/08/conf/cfp.owl#")
    ("cfrl" . "http://linkeddata.finki.ukim.mk/lod/ontology/cfrl#")
    ("cgo" . "https://www.tno.nl/agrifood/ontology/common-greenhouse-ontology#")
    ("cgov" . "http://reference.data.gov.uk/def/central-government/")
    ("ch" . "https://schema.ld.admin.ch/")
    ("chameo" . "http://w3id.org/emmo-chameo/chameo#")
    ("changeset" . "http://purl.org/vocab/changeset/schema#")
    ("chear" . "http://hadatac.org/ont/chear#")
    ("chebi" . "http://purl.obolibrary.org/obo/CHEBI_")
    ("check" . "http://pornhub.com/")
    ("chembl" . "http://rdf.ebi.ac.uk/terms/chembl#")
    ("cheminf" . "http://www.semanticweb.org/ontologies/cheminf.owl#")
    ("chemrof" . "https://w3id.org/chemrof/")
    ("chemsci" . "https://w3id.org/skgo/chemsci#")
    ("chess" . "http://purl.org/NET/rdfchess/ontology/")
    ("chord" . "http://purl.org/ontology/chord/")
    ("chpaf" . "https://ch.paf.link/")
    ("ci" . "https://privatealpha.com/ontology/content-inventory/1#")
    ("ciao" . "http://ciao.it/")
    ("cido" . "http://purl.obolibrary.org/obo/cido.owl/")
    ("cidoc" . "http://www.cidoc-crm.org/cidoc-crm/")
    ("cidoccrm" . "http://purl.org/NET/cidoc-crm/core#")
    ("cim" . "http://iec.ch/TC57/2013/CIM-schema-cim16#")
    ("cinema" . "http://www.semanticweb.org/julien/morgann/cinema#")
    ("cis" . "http://purl.org/NET/cloudisus#")
    ("citedcat" . "https://w3id.org/citedcat-ap/")
    ("cito" . "http://purl.org/spar/cito/")
    ("citof" . "http://www.essepuntato.it/2013/03/cito-functions#")
    ("city" . "http://datos.localidata.com/def/City#")
    ("cjr" . "http://vocab.linkeddata.es/datosabiertos/def/urbanismo-infraestructuras/callejero#")
    ("ckg" . "http://example.org/ckg#")
    ("cl" . "http://advene.org/ns/cinelab/")
    ("clapit" . "http://dati.gov.it/onto/clapit/")
    ("cld" . "http://purl.org/cld/terms/")
    ("climb" . "http://climb.dataincubator.org/vocabs/climb/")
    ("clineva" . "http://www.agfa.com/w3c/2009/clinicalEvaluation#")
    ("clinic" . "http://example.com/clinic#")
    ("clinproc" . "http://www.agfa.com/w3c/2009/clinicalProcedure#")
    ("clirio" . "http://clirio.kaerle.com/clirio.owl#")
    ("clo" . "http://purl.obolibrary.org/obo/ZP_")
    ("clyh" . "http://purl.obolibrary.org/obo/ZP_")
    ("cmd" . "http://clarin.eu/cmd#")
    ("cmdi" . "http://www.clarin.eu/cmd/")
    ("cmdm" . "http://infra.clarin.eu/cmd/")
    ("cmo" . "http://purl.org/twc/ontologies/cmo.owl#")
    ("cmp" . "http://www.ontologydesignpatterns.org/cp/owl/componency.owl#")
    ("cnt" . "http://www.w3.org/2011/content#")
    ("co" . "http://purl.org/ontology/co/core#")
    ("cocoon" . "https://w3id.org/cocoon/v1.0#")
    ("coda" . "http://art.uniroma2.it/coda/contracts/")
    ("code" . "http://telegraphis.net/ontology/measurement/code#")
    ("coeus" . "http://bioinformatics.ua.pt/coeus/")
    ("cog" . "http://purl.org/ontology/cco/core#")
    ("cogs" . "http://vocab.deri.ie/cogs#")
    ("coin" . "http://purl.org/court/def/2009/coin#")
    ("cold" . "http://purl.org/configurationontology#")
    ("coll" . "http://purl.org/co/")
    ("com" . "http://purl.org/commerce#")
    ("comm" . "http://vocab.resc.info/communication#")
    ("commerce" . "http://search.yahoo.com/searchmonkey/commerce/")
    ("common" . "http://www.w3.org/2007/uwa/context/common.owl#")
    ("commons" . "http://commons.psi.enakting.org/def/")
    ("comp" . "http://semweb.mmlab.be/ns/rml-compression#")
    ("company" . "http://intellimind.io/ns/company#")
    ("compass" . "http://purl.org/net/compass#")
    ("composer" . "http://dbpedia.org/ontology/composer/")
    ("compub" . "https://sireneld.io/vocab/compub#")
    ("con" . "http://www.w3.org/2000/10/swap/pim/contact#")
    ("condition" . "http://www.kinjal.com/condition:")
    ("conf" . "http://richard.cyganiak.de/2007/pubby/config.rdf#")
    ("conference" . "https://w3id.org/scholarlydata/ontology/conference-ontology.owl#")
    ("conll" . "http://ufal.mff.cuni.cz/conll2009-st/task-description.html#")
    ("conllu" . "https://universaldependencies.org/format.html#")
    ("connard" . "https://mail.google.com/mail/u/1/#")
    ("conserv" . "http://conserv.deri.ie/ontology#")
    ("consolid" . "https://w3id.org/consolid#")
    ("constant" . "http://qudt.org/vocab/constant/")
    ("contact" . "http://www.w3.org/2000/10/swap/pim/contact#")
    ("contax" . "https://w3id.org/con-tax#")
    ("content" . "http://purl.org/rss/1.0/modules/content/")
    ("contry" . "http://dbpedia.org/resource/Lyon#")
    ("contsem" . "http://contsem.unizar.es/def/sector-publico/contratacion#")
    ("conv" . "http://purl.org/twc/vocab/conversion/")
    ("conversion" . "http://purl.org/twc/vocab/conversion/")
    ("coo" . "http://purl.org/coo/ns#")
    ("coos" . "http://id.unece.org/def/coos#")
    ("copyright" . "http://rhizomik.net/ontologies/copyrightonto.owl#")
    ("cordis" . "http://cordis.europa.eu/projects/")
    ("core" . "http://vivoweb.org/ontology/core#")
    ("coref" . "http://www.rkbexplorer.com/ontologies/coref#")
    ("coreo" . "http://purl.org/coreo#")
    ("cos" . "http://www.inria.fr/acacia/corese#")
    ("cosmo" . "http://purl.org/ontology/cosmo#")
    ("coswot" . "https://w3id.org/coswot/")
    ("coun" . "http://www.daml.org/2001/09/countries/iso-3166-ont#")
    ("countries" . "http://eulersharp.sourceforge.net/2003/03swap/countries#")
    ("country" . "http://eulersharp.sourceforge.net/2003/03swap/countries#")
    ("county" . "http://myexample.org/county#")
    ("courseware" . "http://courseware.rkbexplorer.com/ontologies/courseware#")
    ("covido" . "https://w3id.org/CovidO#")
    ("coy" . "https://schema.coypu.org/global#")
    ("cp" . "http://schemas.openxmlformats.org/package/2006/metadata/core-properties/")
    ("cpa" . "http://www.ontologydesignpatterns.org/schemas/cpannotationschema.owl#")
    ("cpack" . "http://cliopatria.swi-prolog.org/schema/cpack#")
    ("cpant" . "http://purl.org/NET/cpan-uri/terms#")
    ("cpc" . "https://data.epo.org/linked-data/def/cpc/")
    ("cpg" . "http://modellingdh.github.io/ont/odp/pgc/")
    ("cpi" . "http://www.ebusiness-unibw.org/ontologies/cpi/ns#")
    ("cpm" . "http://catalogus-professorum.org/cpm/2/")
    ("cpov" . "http://data.europa.eu/m8g/")
    ("cpsv" . "http://purl.org/vocab/cpsv#")
    ("cpsvno" . "http://data.norge.no/vocabulary/cpsvno#")
    ("cpv" . "http://purl.org/weso/cpv/")
    ("crcr" . "https://credit.niso.org/contributor-roles/")
    ("crime" . "http://purl.org/vocab/reloc/")
    ("crm" . "http://www.cidoc-crm.org/cidoc-crm/")
    ("crmdig" . "http://www.ics.forth.gr/isl/CRMdig/")
    ("crmeh" . "http://purl.org/crmeh#")
    ("crminf" . "http://www.cidoc-crm.org/cidoc-crm/CRMinf/")
    ("crml" . "http://semweb.mmlab.be/ns/rml/condition#")
    ("crmsci" . "http://cidoc-crm.org/crmsci/")
    ("cro" . "http://rhizomik.net/ontologies/copyrightonto.owl#")
    ("crowd" . "http://purl.org/crowd/")
    ("crsw" . "http://courseware.rkbexplorer.com/ontologies/courseware#")
    ("crtv" . "http://open-services.net/ns/crtv#")
    ("crv" . "http://purl.org/twc/vocab/datacarver#")
    ("crypto" . "http://www.w3.org/2000/10/swap/crypto#")
    ("cs" . "http://purl.org/vocab/changeset/schema#")
    ("csdbp" . "http://cs.dbpedia.org/")
    ("cska" . "http://pfclitex.com/")
    ("csm" . "http://purl.org/csm/1.0#")
    ("cso" . "http://cso.kmi.open.ac.uk/schema/cso/")
    ("csp" . "http://vocab.deri.ie/csp#")
    ("csv" . "http://vocab.sindice.net/csv/")
    ("csvw" . "http://www.w3.org/ns/csvw#")
    ("ct" . "http://data.linkedct.org/resource/linkedct/")
    ("ctag" . "http://commontag.org/ns#")
    ("cto" . "https://w3id.org/cto#")
    ("ctorg" . "http://purl.org/ctic/infraestructuras/organizacion#")
    ("ctrl" . "https://w3id.org/ibp/CTRLont#")
    ("cts" . "http://rdf.cdisc.org/ct/schema#")
    ("cts2" . "http://schema.omg.org/spec/CTS2/1.0/")
    ("ctxdesc" . "http://www.demcare.eu/ontologies/contextdescriptor.owl#")
    ("cube" . "https://cube.link/")
    ("cubeont" . "http://ontology.cube.global/")
    ("cue" . "http://www.clarin.eu/cmdi/cues/display/1.0#")
    ("cur" . "http://qudt.org/2.1/vocab/currency/")
    ("curr" . "https://w3id.org/cc#")
    ("custom" . "http://www.openrdf.org/config/sail/custom#")
    ("customer" . "http://www.valuelabs.com/")
    ("cv" . "http://rdfs.org/resume-rdf/")
    ("cvb" . "http://rdfs.org/resume-rdf/base.rdfs#")
    ("cvbase" . "http://purl.org/captsolo/resume-rdf/0.2/base#")
    ("cwl" . "https://w3id.org/cwl/cwl#")
    ("cwlgit" . "https://w3id.org/cwl/view/git/")
    ("cwlprov" . "https://w3id.org/cwl/prov#")
    ("cwmo" . "http://purl.org/cwmo/#")
    ("cwo" . "http://kcoyle.net/cwo/")
    ("cwork" . "http://www.bbc.co.uk/ontologies/creativework/")
    ("cwrc" . "http://sparql.cwrc.ca/ontology/cwrc#")
    ("cyc" . "http://sw.opencyc.org/concept/")
    ("cycann" . "http://sw.cyc.com/CycAnnotations_v1#")
    ("d0" . "http://ontologydesignpatterns.org/ont/wikipedia/d0.owl#")
    ("d2d" . "http://rdfns.org/d2d/")
    ("d2r" . "http://sites.wiwiss.fu-berlin.de/suhl/bizer/d2r-server/config.rdf#")
    ("d2rq" . "http://www.wiwiss.fu-berlin.de/suhl/bizer/D2RQ/0.1#")
    ("d2s" . "https://w3id.org/d2s/")
    ("d3s" . "http://vocbench.solidaridad.cloud/taxonomies#")
    ("da" . "https://www.wowman.org/index.php?id=1&type=get#")
    ("daap" . "http://daap.dsi.universite-paris-saclay.fr/wiki/")
    ("dady" . "http://purl.org/NET/dady#")
    ("daia" . "http://purl.org/ontology/daia/")
    ("daiaserv" . "http://purl.org/ontology/daia/Service/")
    ("dailymed" . "http://www4.wiwiss.fu-berlin.de/dailymed/resource/dailymed/")
    ("daisy" . "http://www.daisy.org/z3998/2012/vocab/")
    ("daml" . "http://www.daml.org/2001/03/daml+oil#")
    ("dannet" . "http://www.wordnet.dk/owl/instance/2009/03/instances/")
    ("dao" . "http://purl.org/dao#")
    ("daq" . "http://purl.org/eis/vocab/daq#")
    ("dash" . "http://datashapes.org/dash#")
    ("data" . "http://data.odw.tw/")
    ("databus" . "https://dataid.dbpedia.org/databus#")
    ("datacite" . "http://purl.org/spar/datacite/")
    ("datacron" . "http://www.datacron-project.eu/datAcron#")
    ("datafaqs" . "http://purl.org/twc/vocab/datafaqs#")
    ("datagc" . "https://data.grottocenter.org/ldp/")
    ("dataid" . "http://dataid.dbpedia.org/ns/core#")
    ("date" . "http://contextus.net/ontology/ontomedia/misc/date#")
    ("datex" . "http://vocab.datex.org/terms#")
    ("dave" . "http://theme-e.adaptcentre.ie/dave#")
    ("dawgt" . "http://www.w3.org/2001/sw/DataAccess/tests/test-dawg#")
    ("days" . "http://ontologi.es/days#")
    ("dayta" . "http://dayta.me/resource#")
    ("db" . "http://dbpedia.org/")
    ("dbc" . "http://dbpedia.org/resource/Category:")
    ("dbcat" . "http://dbpedia.org/resource/Category:")
    ("dbd" . "http://dbpedia.org/datatype/")
    ("dbfo" . "http://dbpedia.org/facts/ontology#")
    ("dbkwik" . "http://dbkwik.webdatacommons.org/")
    ("dblp" . "http://dblp.uni-trier.de/rdf/schema-2015-01-26#")
    ("dbm" . "http://purl.org/net/dbm/ontology#")
    ("dbms" . "http://www.openlinksw.com/ontology/dbms-app-ontology#")
    ("dbnary" . "http://kaiko.getalp.org/dbnary#")
    ("dbo" . "http://dbpedia.org/ontology/")
    ("dbonto" . "http://dbepedia.org/ontology/")
    ("dbowl" . "http://ontology.cybershare.utep.edu/dbowl/relational-to-ontology-mapping-primitive.owl#")
    ("dbp" . "http://dbpedia.org/property/")
    ("dbpedia" . "http://dbpedia.org/resource/")
    ("dbpedia2" . "http://dbpedia.org/property/")
    ("dbpediaowl" . "http://dbpedia.org/owl/")
    ("dbpg" . "http://dbpedia.org/page/")
    ("dbpo" . "http://dbpedia.org/ontology/")
    ("dbpp" . "http://dbpedia.org/property/")
    ("dbpprop" . "http://dbpedia.org/property/")
    ("dbpr" . "http://dbpedia.org/resource/")
    ("dbprop" . "http://dbpedia.org/property/")
    ("dbptmpl" . "http://dbpedia.org/resource/Template:")
    ("dbr" . "http://dbpedia.org/resource/")
    ("dbrc" . "http://dbpedia.org/resource/Category:")
    ("dbt" . "http://dbpedia.org/resource/Template:")
    ("dbtont" . "http://dbtropes.org/ont/")
    ("dbug" . "http://ontologi.es/doap-bugs#")
    ("dby" . "http://dbpedia.org/class/yago/")
    ("dbyago" . "http://dbpedia.org/class/yago/")
    ("dc" . "http://purl.org/dc/elements/1.1/")
    ("dc11" . "http://purl.org/dc/elements/1.1/")
    ("dcam" . "http://purl.org/dc/dcam/")
    ("dcap" . "http://purl.org/ws-mmi-dc/terms/")
    ("dcat" . "http://www.w3.org/ns/dcat#")
    ("dcatap" . "http://data.europa.eu/r5r/")
    ("dcatapit" . "http://dati.gov.it/onto/dcatapit#")
    ("dcatnl" . "http://standaarden.overheid.nl/dcatnl/terms/")
    ("dcatno" . "https://data.norge.no/vocabulary/dcatno#")
    ("dcb" . "http://dbpedia.org/resource/Category:")
    ("dce" . "http://purl.org/dc/elements/1.1/")
    ("dcid" . "https://datacommons.org/browser/")
    ("dcite" . "http://purl.org/spar/datacite/")
    ("dcm" . "http://purl.org/dc/dcmitype/")
    ("dcmit" . "http://purl.org/dc/dcmitype/")
    ("dcmitype" . "http://purl.org/dc/dcmitype/")
    ("dcn" . "http://www.w3.org/2007/uwa/context/deliverycontext.owl#")
    ("dcndl" . "http://ndl.go.jp/dcndl/terms/")
    ("dco" . "http://info.deepcarbon.net/schema#")
    ("dcodata" . "http://info.deepcarbon.net/data/schema#")
    ("dcodt" . "http://info.deepcarbon.net/datatype/schema#")
    ("dcoid" . "http://dx.deepcarbon.net/")
    ("dcosample" . "http://info.deepcarbon.net/sample/schema#")
    ("dcq" . "http://purl.org/dc/qualifiers/1.0/")
    ("dcr" . "http://www.isocat.org/ns/dcr.rdf#")
    ("dcs" . "http://ontologi.es/doap-changeset#")
    ("dct" . "http://purl.org/dc/terms/")
    ("dcterm" . "http://purl.org/dc/terms/")
    ("dcterms" . "http://purl.org/dc/terms/")
    ("dctype" . "http://purl.org/dc/dcmitype/")
    ("dctypes" . "http://purl.org/dc/dcmitype/")
    ("dcx" . "http://dublincore.org/dcx/")
    ("dd" . "http://example.org/dummydata/")
    ("ddb" . "http://www.deutsche-digitale-bibliothek.de/edm/")
    ("ddc" . "http://purl.org/NET/decimalised#")
    ("dde" . "https://www.ddeworld.org/")
    ("ddl" . "http://purl.org/vocab/riro/ddl#")
    ("dead" . "http://utpl.edu.ec/sbc/data/")
    ("decision" . "https://decision-ontology.googlecode.com/svn/trunk/decision.owl#")
    ("decl" . "http://www.linkedmodel.org/1.0/schema/decl#")
    ("decprov" . "http://promsns.org/def/decprov#")
    ("defns" . "http://www.openarchives.org/OAI/2.0/")
    ("delta" . "http://www.w3.org/2004/delta#")
    ("demlab" . "http://www.demcare.eu/ontologies/demlab.owl#")
    ("dentsci" . "https://w3id.org/skgo/dentsci#")
    ("deo" . "http://purl.org/spar/deo/")
    ("deonta" . "https://deonta.linkedmodel.org/deonta/")
    ("deps" . "http://ontologi.es/doap-deps#")
    ("derecho" . "http://purl.org/derecho#")
    ("devuan" . "https://devuan.net.br/")
    ("dfc" . "http://datafoodconsortium.org/ontologies/DFC_FullModel.owl#")
    ("dfcb" . "http://datafoodconsortium.org/ontologies/DFC_BusinessOntology.owl#")
    ("dgfoaf" . "http://west.uni-koblenz.de/ontologies/2010/07/dgfoaf.owl#")
    ("dgfr" . "http://colin.maudry.com/ontologies/dgfr#")
    ("dgtwc" . "http://data-gov.tw.rpi.edu/2009/data-gov-twc.rdf#")
    ("diag" . "http://www.loc.gov/zing/srw/diagnostic/")
    ("dicera" . "http://semweb.mmlab.be/ns/dicera#")
    ("dick" . "http://pornhub.com/")
    ("dicom" . "http://purl.org/healthcarevocab/v1#")
    ("dinto" . "http://purl.obolibrary.org/obo/ZP_")
    ("dio" . "https://w3id.org/dio#")
    ("dir" . "http://schemas.talis.com/2005/dir/schema#")
    ("dis" . "http://stanbol.apache.org/ontology/disambiguation/disambiguation#")
    ("disco" . "http://rdf-vocabulary.ddialliance.org/discovery#")
    ("disease" . "http://www.agfa.com/w3c/2009/humanDisorder#")
    ("diseasome" . "http://www4.wiwiss.fu-berlin.de/diseasome/resource/diseasome/")
    ("diso" . "https://purls.helmholtz-metadaten.de/diso#")
    ("dita" . "http://purl.org/dita/ns#")
    ("dive" . "http://scubadive.networld.to/dive.rdf#")
    ("djo" . "http://purl.org/datajourneys/")
    ("dk" . "http://www.data-knowledge.org/dk/schema/rdf/latest/")
    ("dl" . "http://ontology.ip.rm.cnr.it/ontologies/DOLCE-Lite#")
    ("dm" . "http://datamusee.givingsense.eu/onto/")
    ("dm2e" . "http://onto.dm2e.eu/schemas/dm2e/")
    ("dmo" . "https://w3id.org/dmo#")
    ("dmp" . "http://www.sysresearch.org/rda-common-dmp#")
    ("dn" . "http://purl.org/datanode/ns/")
    ("dnb" . "http://d-nb.info/gnd/")
    ("dnbt" . "http://d-nb.info/standards/elementset/dnb#")
    ("dnr" . "http://www.dotnetrdf.org/configuration#")
    ("doac" . "http://ramonantonio.net/doac/0.1/#")
    ("doacc" . "http://purl.org/net/bel-epa/doacc#")
    ("doam" . "http://emmo.info/doam#")
    ("doap" . "http://usefulinc.com/ns/doap#")
    ("doas" . "http://deductions.github.io/doas.owl.ttl#")
    ("doc" . "http://www.w3.org/2000/10/swap/pim/doc#")
    ("docam" . "https://www.docam.ca/glossaurus/")
    ("docbook" . "http://docbook.org/ns/docbook/")
    ("doce" . "http://purl.org/nemo/doce#")
    ("docker" . "http://www.w3.org/ns/bde/docker/")
    ("doclist" . "http://www.junkwork.net/xml/DocumentList#")
    ("doco" . "http://purl.org/spar/doco/")
    ("dogont" . "http://elite.polito.it/ontologies/dogont.owl#")
    ("doi" . "https://doi.org/")
    ("dom" . "https://html.spec.whatwg.org/#")
    ("donto" . "http://reference.data.gov.au/def/ont/dataset#")
    ("door" . "http://kannel.open.ac.uk/ontology#")
    ("dossier" . "https://data.omgeving.vlaanderen.be/ns/dossier#")
    ("dot" . "https://w3id.org/dot#")
    ("dpc" . "http://hospee.org/ontologies/dpc/")
    ("dpd" . "http://www.kanzaki.com/ns/dpd#")
    ("dpl" . "http://dbpedialite.org/things/")
    ("dpla" . "http://dp.la/info/developers/map/")
    ("dpn" . "http://purl.org/dpn#")
    ("dprov" . "http://promsns.org/def/do#")
    ("dpv" . "http://www.w3.org/ns/dpv#")
    ("dq" . "http://def.seegrid.csiro.au/isotc211/iso19115/2003/dataquality#")
    ("dqc" . "http://semwebquality.org/ontologies/dq-constraints#")
    ("dqm" . "http://purl.org/dqm-vocabulary/v1/dqm#")
    ("dqv" . "http://www.w3.org/ns/dqv#")
    ("dqvno" . "https://data.norge.no/vocabulary/dqvno#")
    ("dr" . "http://purl.org/swan/2.0/discourse-relationships/")
    ("driver" . "http://deductions.github.io/drivers.owl.ttl#")
    ("drk" . "http://drakon.su/")
    ("drm" . "http://vocab.data.gov/def/drm#")
    ("drug" . "http://www.agfa.com/w3c/2009/drugTherapy#")
    ("drugbank" . "http://www4.wiwiss.fu-berlin.de/drugbank/resource/drugbank/")
    ("ds" . "http://purl.org/ctic/dcat#")
    ("dsd" . "https://w3id.org/dsd#")
    ("dsfv" . "http://sws.ifi.uio.no/vocab/dsf/henriwi/dsf#")
    ("dsi" . "https://data.dsi.omgeving.vlaanderen.be/ns/dsi#")
    ("dsn" . "http://purl.org/dsnotify/vocab/eventset/")
    ("dso" . "http://purl.org/ontology/dso#")
    ("dsp" . "http://purl.org/metainfo/terms/dsp#")
    ("dssn" . "http://purl.org/net/dssn/")
    ("dsv" . "https://w3id.org/dsv#")
    ("dsw" . "http://purl.org/dsw/")
    ("dt" . "http://dbpedia.org/datatype/")
    ("dto" . "http://www.datatourisme.fr/ontology/core/1.0#")
    ("dtype" . "http://www.linkedmodel.org/schema/dtype#")
    ("dul" . "http://www.ontologydesignpatterns.org/ont/dul/DUL.owl#")
    ("dummy" . "http://hello.com/")
    ("duv" . "http://www.w3.org/ns/duv#")
    ("dv" . "http://rdf.data-vocabulary.org/#")
    ("dvia" . "http://data.eurecom.fr/ontology/dvia#")
    ("dwc" . "http://rs.tdwg.org/dwc/terms/")
    ("dwciri" . "http://rs.tdwg.org/dwc/iri/")
    ("ea" . "http://eaontology.protect.linkeddata.es/def/")
    ("eame" . "http://www.semanticweb.org/ontologia_EA#")
    ("ean" . "http://openean.kaufkauf.net/id/")
    ("earl" . "http://www.w3.org/ns/earl#")
    ("earth" . "http://linked.earth/ontology#")
    ("eat" . "http://www.eat.rl.ac.uk/#")
    ("eb" . "https://w3id.org/eb#")
    ("ebg" . "http://data.businessgraph.io/ontology#")
    ("ebu" . "http://semantic.eurobau.com/eurobau-utility.owl#")
    ("ebucore" . "http://www.ebu.ch/metadata/ontologies/ebucore/ebucore#")
    ("ec" . "http://eulergui.sourceforge.net/contacts.owl.n3#")
    ("ecb" . "http://ecb.270a.info/class/1.0/")
    ("ecc" . "https://ns.eccenca.com/")
    ("eccauth" . "https://vocab.eccenca.com/auth/")
    ("eccdi" . "https://vocab.eccenca.com/di/")
    ("eccf" . "http://data.europa.eu/54i/")
    ("eccpubsub" . "https://vocab.eccenca.com/pubsub/")
    ("eccrev" . "https://vocab.eccenca.com/revision/")
    ("ecfo" . "https://w3id.org/ecfo#")
    ("ecgl" . "http://schema.geolink.org/")
    ("ecglview" . "http://schema.geolink.org/view/")
    ("eclap" . "http://www.eclap.eu/schema/eclap/")
    ("eco" . "http://www.ebusiness-unibw.org/ontologies/eclass/5.1.4/#")
    ("ecoll" . "http://purl.org/ceu/eco/1.0#")
    ("ecore" . "http://www.eclipse.org/emf/2002/Ecore#")
    ("ecos" . "http://purl.org/ecos#")
    ("ecowlim" . "http://ecowlim.tfri.gov.tw/lode/resource/")
    ("ecpo" . "http://purl.org/ontology/ecpo#")
    ("ecrm" . "http://erlangen-crm.org/current/")
    ("ecs" . "http://rdf.ecs.soton.ac.uk/ontology/ecs#")
    ("edac" . "http://ontology.cybershare.utep.edu/ELSEWeb/elseweb-edac.owl#")
    ("edam" . "http://edamontology.org/")
    ("edg" . "http://edg.topbraid.solutions/model/")
    ("edgar" . "http://edgarwrap.ontologycentral.com/vocab/edgar#")
    ("edgarcik" . "http://edgarwrap.ontologycentral.com/cik/")
    ("edm" . "http://www.europeana.eu/schemas/edm/")
    ("edr" . "https://w3id.org/laas-iot/edr#")
    ("edu" . "https://schema.edu.ee/")
    ("edupro" . "http://ns.inria.fr/semed/eduprogression#")
    ("eem" . "http://purl.org/eem#")
    ("eep" . "https://w3id.org/eep#")
    ("eepsa" . "https://w3id.org/eepsa#")
    ("efd" . "http://data.foodanddrinkeurope.eu/ontology#")
    ("efo" . "http://www.ebi.ac.uk/efo/")
    ("efrbroo" . "http://erlangen-crm.org/efrbroo/")
    ("eg" . "http://www.example.org/")
    ("egdo" . "http://example.org/")
    ("ei2a" . "http://opendata.aragon.es/def/ei2a#")
    ("ekaw" . "http://data.semanticweb.org/conference/ekaw/2012/complete/")
    ("elec" . "http://purl.org/ctic/sector-publico/elecciones#")
    ("eli" . "http://data.europa.eu/eli/ontology#")
    ("elod" . "http://linkedeconomy.org/ontology#")
    ("elog" . "http://eulersharp.sourceforge.net/2003/03swap/log-rules#")
    ("emergel" . "http://purl.org/emergel/core#")
    ("emergelm" . "http://purl.org/emergel/modules#")
    ("emmo" . "https://w3id.org/emmo#")
    ("emoca" . "http://ns.inria.fr/emoca#")
    ("emotion" . "http://ns.inria.fr/emoca#")
    ("emp" . "http://purl.org/ctic/empleo/oferta#")
    ("employee" . "http://www.employee.com/data#")
    ("emtr" . "http://purl.org/NET/ssnext/electricmeters#")
    ("enc" . "http://www.w3.org/2001/04/xmlenc#")
    ("encargado" . "http://semRAT.edu/")
    ("ends" . "http://labs.mondeca.com/vocab/endpointStatus#")
    ("enhancer" . "http://stanbol.apache.org/ontology/enhancer/enhancer#")
    ("ens" . "http://models.okkam.org/ENS-core-vocabulary.owl#")
    ("ensembl" . "http://rdf.ebi.ac.uk/resource/ensembl/")
    ("environ" . "http://eulersharp.sourceforge.net/2003/03swap/environment#")
    ("envo" . "http://purl.obolibrary.org/obo/ZP_")
    ("eol" . "http://purl.org/biodiversity/eol/")
    ("ep" . "http://eprints.org/ontology/")
    ("epcis" . "https://ns.gs1.org/epcis/")
    ("epo" . "http://data.europa.eu/a4g/ontology#")
    ("eppl" . "https://w3id.org/ep-plan#")
    ("epplan" . "https://w3id.org/ep-plan#")
    ("eppo" . "https://gd.eppo.int/taxon/")
    ("eprints" . "http://eprints.org/ontology/")
    ("eproc" . "http://10.0.3.120/download/eproc_FORN_v02.owl#")
    ("eproc2" . "http://10.0.3.120/download/eproc_FORN_v04.owl#")
    ("eqp" . "https://data.nasa.gov/ontologies/atmonto/equipment#")
    ("era" . "http://data.europa.eu/949/")
    ("erce" . "http://xxefe.de/")
    ("ermrk" . "http://www.essepuntato.it/2008/12/earmark#")
    ("ero" . "http://purl.obolibrary.org/obo/")
    ("es" . "http://eulersharp.sourceforge.net/2003/03swap/log-rules#")
    ("esadm" . "http://vocab.linkeddata.es/datosabiertos/def/sector-publico/territorio#")
    ("esagen" . "http://vocab.ciudadesabiertas.es/def/sector-publico/agenda-municipal#")
    ("esagm" . "http://vocab.ciudadesabiertas.es/def/sector-publico/agenda-municipal#")
    ("esair" . "http://vocab.linkeddata.es/datosabiertos/def/medio-ambiente/calidad-aire#")
    ("esaloj" . "http://vocab.linkeddata.es/datosabiertos/def/turismo/alojamiento#")
    ("esapar" . "http://vocab.linkeddata.es/datosabiertos/def/urbanismo-infraestructuras/aparcamiento#")
    ("esautob" . "http://vocab.ciudadesabiertas.es/def/transporte/autobus#")
    ("esbici" . "http://vocab.ciudadesabiertas.es/def/transporte/bicicleta-publica#")
    ("esc" . "https://solid.ti.rw.fau.de/public/ns/event-sourcing-containers#")
    ("escjr" . "http://vocab.linkeddata.es/datosabiertos/def/urbanismo-infraestructuras/callejero#")
    ("esco" . "http://data.europa.eu/esco/model#")
    ("escom" . "http://vocab.linkeddata.es/datosabiertos/def/comercio/tejidoComercial#")
    ("esconv" . "http://vocab.ciudadesabiertas.es/def/sector-publico/convenio#")
    ("esd" . "http://def.esd.org.uk/")
    ("esdbpr" . "http://es.dbpedia.org/resource/")
    ("esdir" . "http://vocab.linkeddata.es/datosabiertos/def/urbanismo-infraestructuras/direccion-postal#")
    ("eseduc" . "http://www.purl.org/ontologia/eseduc#")
    ("esempleo" . "http://vocab.ciudadesabiertas.es/def/sector-publico/empleo#")
    ("esequip" . "http://vocab.linkeddata.es/datosabiertos/def/urbanismo-infraestructuras/equipamiento#")
    ("esgs" . "https://w3id.org/edwin/ontology/")
    ("espresup" . "http://vocab.linkeddata.es/datosabiertos/def/hacienda/presupuestos#")
    ("esproc" . "http://vocab.linkeddata.es/datosabiertos/def/sector-publico/procedimientos#")
    ("esservicio" . "http://vocab.linkeddata.es/datosabiertos/def/sector-publico/servicio#")
    ("essglobal" . "http://purl.org/essglobal/vocab/v1.0/")
    ("estatgph" . "http://estatwrap.ontologycentral.com/id/nama_aux_gph#")
    ("estatwrap" . "http://ontologycentral.com/2009/01/eurostat/ns#")
    ("estraf" . "http://vocab.ciudadesabiertas.es/def/transporte/trafico#")
    ("estrf" . "http://vocab.linkeddata.es/datosabiertos/def/transporte/trafico#")
    ("estrn" . "http://vocab.linkeddata.es/datosabiertos/def/urbanismo-infraestructuras/transporte#")
    ("ethc" . "http://ethoinformatics.org/ethocore/")
    ("eu" . "http://eulersharp.sourceforge.net/2003/03swap/log-rules#")
    ("eui" . "http://institutions.publicdata.eu/#")
    ("eumida" . "http://data.kasabi.com/dataset/eumida/terms/")
    ("eunis" . "http://eunis.eea.europa.eu/rdf/species-schema.rdf#")
    ("eupont" . "http://elite.polito.it/ontologies/eupont.owl#")
    ("eurio" . "http://data.europa.eu/s66#")
    ("eurlex" . "http://eur-lex.publicdata.eu/ontology/")
    ("eurostat" . "http://wifo5-04.informatik.uni-mannheim.de/eurostat/resource/eurostat/")
    ("eurovoc" . "http://eurovoc.europa.eu/")
    ("eustd" . "http://eurostat.linked-statistics.org/data#")
    ("euvoc" . "http://publications.europa.eu/ontology/euvoc#")
    ("ev" . "http://www.w3.org/2001/xml-events/")
    ("event" . "http://purl.org/NET/c4dm/event.owl#")
    ("events" . "http://eulersharp.sourceforge.net/2003/03swap/event#")
    ("evident" . "http://purl.org/net/evident#")
    ("evopat" . "http://ns.aksw.org/Evolution/")
    ("evset" . "http://dsnotify.org/vocab/eventset/0.1/")
    ("ewg" . "http://ethoinformatics.org/")
    ("ex" . "http://example.org/")
    ("example" . "http://www.example.org/rdf#")
    ("exekg" . "https://raw.githubusercontent.com/nsai-uio/ExeKGOntology/main/ds_exeKGOntology.ttl#")
    ("exif" . "http://www.w3.org/2003/12/exif/ns#")
    ("exo" . "https://w3id.org/example#")
    ("experts" . "http://emmo.info/emmo/application/maeo/experts#")
    ("express" . "https://w3id.org/express#")
    ("ext" . "http://mu.semte.ch/vocabularies/ext/")
    ("extech" . "https://w3id.org/executionTechnique/ontology/")
    ("exterms" . "http://www.example.org/terms/")
    ("eye" . "http://jena.hpl.hp.com/Eyeball#")
    ("ezcontext" . "http://ontologies.ezweb.morfeo-project.org/ezcontext/ns#")
    ("eztag" . "http://ontologies.ezweb.morfeo-project.org/eztag/ns#")
    ("faas" . "http://semantic-faas.com/ontology#")
    ("fab" . "http://purl.org/fab/ns#")
    ("fabio" . "http://purl.org/spar/fabio/")
    ("factbook" . "http://wifo5-04.informatik.uni-mannheim.de/factbook/ns#")
    ("faldo" . "http://biohackathon.org/resource/faldo#")
    ("fam" . "http://vocab.fusepool.info/fam#")
    ("fao" . "http://fao.270a.info/dataset/")
    ("faostat" . "http://reference.eionet.europa.eu/faostat/schema/")
    ("faq" . "http://www.openlinksw.com/ontology/faq#")
    ("fb" . "http://rdf.freebase.com/ns/")
    ("fbgeo" . "http://rdf.freebase.com/ns/location/geocode/")
    ("fc" . "http://www.freeclass.eu/freeclass_v1#")
    ("fcm" . "http://eulersharp.sourceforge.net/2006/02swap/fcm#")
    ("fcp" . "http://www.newmedialab.at/fcp/")
    ("fcs" . "http://clarin.eu/fcs/resource#")
    ("fct" . "http://openlinksw.com/services/facets/1.0/")
    ("fd" . "http://foodable.co/ns/")
    ("fdbp" . "http://fr.dbpedia.org/property/")
    ("fdof" . "https://w3id.org/fdof/ontology#")
    ("fdp" . "https://w3id.org/fdp/fdp-o#")
    ("fe" . "http://www.ontologydesignpatterns.org/ont/framenet/abox/fe/")
    ("fea" . "http://vocab.data.gov/def/fea#")
    ("fec" . "http://www.rdfabout.com/rdf/schema/usfec/")
    ("fed" . "http://www.openrdf.org/config/sail/federation#")
    ("feed" . "https://www.feedipedia.org/")
    ("fel" . "http://w3id.org/vcb/fel#")
    ("fernanda" . "http://fernanda.nl/")
    ("fhir" . "http://hl7.org/fhir/")
    ("fibo" . "https://spec.edmcouncil.org/fibo/ontology/master/latest/")
    ("figigii" . "http://www.omg.org/spec/FIGI/GlobalInstrumentIdentifiers/")
    ("film" . "http://semantics.id/ns/example/film/")
    ("fincaselaw" . "http://purl.org/finlex/schema/oikeus/")
    ("fingal" . "http://vocab.deri.ie/fingal#")
    ("finlaw" . "http://purl.org/finlex/schema/laki/")
    ("fire" . "http://tldp.org/HOWTO/XML-RPC-HOWTO/xmlrpc-howto-java.html#")
    ("firebim" . "http://w3id.org/firebim#")
    ("fisa" . "https://ifitkau.github.io/fisa/")
    ("fise" . "http://fise.iks-project.eu/ontology/")
    ("fl" . "http://eulersharp.sourceforge.net/2003/03swap/fl-rules#")
    ("flow" . "http://www.w3.org/2005/01/wf/flow#")
    ("fls" . "http://lukasblaho.sk/football_league_schema#")
    ("fluidops" . "http://www.fluidops.com/")
    ("fma" . "http://sig.uw.edu/fma#")
    ("fn" . "http://www.w3.org/2005/xpath-functions#")
    ("fnabox" . "http://www.ontologydesignpatterns.org/ont/framenet/abox/")
    ("fnml" . "http://semweb.mmlab.be/ns/fnml#")
    ("fno" . "https://w3id.org/function/ontology#")
    ("fnom" . "https://w3id.org/function/vocabulary/mapping#")
    ("fntbox" . "http://www.ontologydesignpatterns.org/ont/framenet/tbox/")
    ("fo" . "http://www.w3.org/1999/XSL/Format#")
    ("foaf" . "http://xmlns.com/foaf/0.1/")
    ("foaffff" . "http://gogl.com/")
    ("foam" . "https://www.koerperfettwaage-test.de/")
    ("fog" . "https://w3id.org/fog#")
    ("foio" . "https://w3id.org/seas/FeatureOfInterestOntology/")
    ("folio" . "http://IBCNServices.github.io/Folio-Ontology/Folio.owl#")
    ("foo" . "http://filmontology.org/ontology/1.0/")
    ("food" . "http://purl.org/foodontology#")
    ("form" . "http://deductions-software.com/ontologies/forms.owl.ttl#")
    ("formats" . "http://www.w3.org/ns/formats/")
    ("fos" . "http://futurios.org/fos/spec/")
    ("fowl" . "http://www.w3.org/TR/2003/PR-owl-guide-20031209/food#")
    ("fp3" . "http://vocab.fusepool.info/fp3#")
    ("fpr" . "http://www.filmstandards.org/schemas/filmportal_relations#")
    ("fr" . "https://w3id.org/fr/def/core#")
    ("frad" . "http://iflastandards.info/ns/fr/frad/")
    ("frame" . "http://www.ontologydesignpatterns.org/ont/framenet/abox/frame/")
    ("frapo" . "http://purl.org/cerif/frapo/")
    ("frappe" . "http://streamreasoning.org/ontologies/frappe#")
    ("frb" . "http://frb.270a.info/dataset/")
    ("frbr" . "http://purl.org/vocab/frbr/core#")
    ("frbrcore" . "http://purl.org/vocab/frbr/core#")
    ("frbre" . "http://purl.org/vocab/frbr/extended#")
    ("frbrer" . "http://iflastandards.info/ns/fr/frbr/frbrer/")
    ("frbroo" . "http://iflastandards.info/ns/fr/frbr/frbroo/")
    ("fred" . "http://www.ontologydesignpatterns.org/ont/fred/domain.owl#")
    ("freebase" . "http://rdf.freebase.com/ns/")
    ("freq" . "http://purl.org/cld/freq/")
    ("fresnel" . "http://www.w3.org/2004/09/fresnel#")
    ("frgeo" . "http://rdf.insee.fr/geo/")
    ("friends" . "http://www.openarchives.org/OAI/2.0/friends/")
    ("frir" . "http://purl.org/twc/ontology/frir.owl#")
    ("frsad" . "http://iflastandards.info/ns/fr/frsad/")
    ("fs" . "https://www.compliancequest.com/training-management-software-system-solutions/")
    ("fso" . "https://w3id.org/fso#")
    ("fssp" . "http://linkeddata.fssprus.ru/resource/")
    ("ftcontent" . "http://www.ft.com/ontology/content/")
    ("fun" . "http://w3id.org/sparql-generate/fn/")
    ("func" . "http://www.w3.org/2007/rif-builtin-function#")
    ("fuseki" . "http://jena.apache.org/fuseki#")
    ("fx" . "http://sparql.xyz/facade-x/ns/")
    ("gadm" . "http://gadm.geovocab.org/ontology#")
    ("gaf" . "http://groundedannotationframework.org/")
    ("galaksiya" . "http://ontoloji.galaksiya.com/vocab/")
    ("game" . "http://data.totl.net/game/")
    ("gas" . "http://www.bigdata.com/rdf/gas#")
    ("gastro" . "http://www.ebsemantics.net/gastro#")
    ("gawd" . "http://gawd.atlantides.org/terms/")
    ("gax" . "http://w3id.org/gaia-x/core#")
    ("gazetteer" . "http://data.ordnancesurvey.co.uk/ontology/50kGazetteer/")
    ("gbol" . "http://gbol.life/0.1#")
    ("gbv" . "http://purl.org/ontology/gbv/")
    ("gc" . "http://www.oegov.org/core/owl/gc#")
    ("gci" . "http://ontology.eil.utoronto.ca/GCI/Foundation/GCI-Foundation.owl#")
    ("gcis" . "http://data.globalchange.gov/gcis.owl#")
    ("gco" . "http://purl.jp/bio/12/glyco/conjugate#")
    ("gcon" . "https://w3id.org/GConsent#")
    ("gd" . "http://rdf.data-vocabulary.org/#")
    ("gdc" . "https://portal.gdc.cancer.gov/cases/")
    ("gdpr" . "https://vocab.eccenca.com/gdpr/")
    ("gdprov" . "https://w3id.org/GDPRov#")
    ("gdprtext" . "https://w3id.org/GDPRtEXT#")
    ("gecko" . "http://purl.obolibrary.org/obo/ZP_")
    ("gelo" . "http://krauthammerlab.med.yale.edu/ontologies/gelo#")
    ("gen" . "http://purl.org/gen/0.1#")
    ("genab" . "http://eulersharp.sourceforge.net/2003/03swap/genomeAbnormality#")
    ("genea" . "http://www.owl-ontologies.com/generations.owl#")
    ("generiek" . "https://data.vlaanderen.be/ns/generiek#")
    ("genre" . "http://sparql.cwrc.ca/ontologies/genre#")
    ("geo" . "http://www.opengis.net/ont/geosparql#")
    ("geo7" . "https://www.geo7.ch/")
    ("geocontext" . "http://www.geocontext.org/publ/2013/vocab#")
    ("geod" . "http://vocab.lenka.no/geo-deling#")
    ("geodata" . "http://sws.geonames.org/")
    ("geodcat" . "http://data.europa.eu/930/")
    ("geoes" . "http://geo.linkeddata.es/ontology/")
    ("geof" . "http://www.opengis.net/def/function/geosparql/")
    ("geofabric" . "http://linked.data.gov.au/def/geofabric#")
    ("geofla" . "http://data.ign.fr/ontologies/geofla#")
    ("geographis" . "http://telegraphis.net/ontology/geography/geography#")
    ("geojson" . "https://purl.org/geojson/vocab#")
    ("geoloc" . "http://deductions.github.io/geoloc.owl.ttl#")
    ("geom" . "http://data.ign.fr/def/geometrie#")
    ("geonames" . "http://www.geonames.org/ontology#")
    ("geop" . "http://aims.fao.org/aos/geopolitical.owl#")
    ("geor" . "http://www.opengis.net/def/rule/geosparql/")
    ("georss" . "http://www.georss.org/georss/")
    ("geos" . "http://www.telegraphis.net/ontology/geography/geography#")
    ("geosp" . "http://rdf.geospecies.org/ont/geospecies#")
    ("geosparql" . "http://www.opengis.net/ont/geosparql#")
    ("geospecies" . "http://rdf.geospecies.org/ont/geospecies#")
    ("geovocab" . "http://geovocab.org/")
    ("geovoid" . "http://purl.org/geovocamp/ontology/geovoid/")
    ("germplasm" . "http://purl.org/germplasm/terms#")
    ("gesis" . "http://lod.gesis.org/lodpilot/ALLBUS/vocab.rdf#")
    ("gf" . "http://def.seegrid.csiro.au/isotc211/iso19109/2005/feature#")
    ("gfo" . "http://www.onto-med.de/ontologies/gfo.owl#")
    ("gg" . "http://www.gemeentegeschiedenis.nl/gg-schema#")
    ("ggbn" . "http://data.ggbn.org/schemas/ggbn/terms/")
    ("ghga" . "http://w3id.org/ghga/")
    ("gist" . "https://ontologies.semanticarts.com/o/gistCore#")
    ("giving" . "http://ontologi.es/giving#")
    ("gl" . "http://schema.geolink.org/")
    ("gldp" . "http://www.w3.org/ns/people#")
    ("gleio" . "http://lei.info/gleio/")
    ("globalcube" . "http://kalmar32.fzi.de/triples/global-cube.ttl#")
    ("glview" . "http://schema.geolink.org/dev/view/")
    ("glycan" . "http://purl.jp/bio/12/glyco/glycan#")
    ("gm" . "http://def.seegrid.csiro.au/isotc211/iso19107/2003/geometry#")
    ("gml" . "http://www.opengis.net/ont/gml#")
    ("gmo" . "http://purl.jp/bio/10/gmo/")
    ("gn" . "http://www.geonames.org/ontology#")
    ("gnaf" . "http://linked.data.gov.au/def/gnaf#")
    ("gnd" . "http://d-nb.info/gnd/")
    ("gndo" . "http://d-nb.info/standards/elementset/gnd#")
    ("gnm" . "http://www.geonames.org/ontology/mappings/")
    ("gns" . "http://sws.geonames.org/")
    ("gnvc" . "http://purl.org/gc/")
    ("go" . "http://purl.obolibrary.org/obo/GO_")
    ("goaf" . "http://goaf.fr/goaf#")
    ("goavoc" . "http://bio2rdf.org/goa_vocabulary:")
    ("gob" . "http://purl.org/ontology/last-fm/")
    ("gobierno" . "http://www.gobierno.es/gobierno/")
    ("godaddy" . "https://sso.godaddy.com/")
    ("goef" . "http://purl.org/twc/vocab/goef#")
    ("gold" . "http://purl.org/linguistics/gold/")
    ("gom" . "https://w3id.org/gom#")
    ("gont" . "https://gont.ch/")
    ("goog" . "http://schema.googleapis.com/")
    ("gov" . "http://gov.genealogy.net/ontology.owl#")
    ("govtrackus" . "http://www.rdfabout.com/rdf/usgov/geo/us/")
    ("govwild" . "http://govwild.org/0.6/GWOntology.rdf/")
    ("gpml" . "http://vocabularies.wikipathways.org/gpml#")
    ("gpt" . "http://purl.org/vocab/riro/gpt#")
    ("gq" . "http://genomequest.com/")
    ("gql" . "http://www.openlinksw.com/schemas/graphql#")
    ("gr" . "http://purl.org/goodrelations/v1#")
    ("graffle" . "http://purl.org/twc/vocab/vsr/graffle#")
    ("granatum" . "http://chem.deri.ie/granatum/")
    ("graves" . "http://rdf.muninn-project.org/ontologies/graves#")
    ("grddl" . "http://www.w3.org/2003/g/data-view#")
    ("greg" . "http://kasei.us/about/foaf.xrdf#")
    ("grel" . "http://users.ugent.be/~bjdmeest/function/grel.ttl#")
    ("gridworks" . "http://purl.org/net/opmv/types/gridworks#")
    ("grs" . "http://www.georss.org/georss/")
    ("grscicoll" . "https://www.gbif.org/grscicoll/collection/")
    ("gs1" . "https://gs1.org/voc/")
    ("gso" . "http://www.w3.org/2006/gen/ont#")
    ("gsp" . "http://www.opengis.net/ont/geosparql#")
    ("gt" . "https://vocab.eccenca.com/geniustex/")
    ("gtfs" . "http://vocab.gtfs.org/terms#")
    ("gts" . "http://resource.geosciml.org/ontology/timescale/gts#")
    ("guez" . "http://guez.fr/")
    ("gufo" . "http://purl.org/nemo/gufo#")
    ("guo" . "http://purl.org/hpi/guo#")
    ("gv" . "http://rdf.data-vocabulary.org/#")
    ("gvoi" . "http://assemblee-virtuelle.github.io/grands-voisins-v2/gv.owl.ttl#")
    ("gvoith" . "http://assemblee-virtuelle.github.io/grands-voisins-v2/thesaurus.ttl#")
    ("gvp" . "http://vocab.getty.edu/ontology#")
    ("gx" . "https://graphite.synaptica.net/extension/")
    ("gxa" . "http://www.ebi.ac.uk/gxa/")
    ("h2o" . "http://def.seegrid.csiro.au/isotc211/iso19150/-2/2012/basic#")
    ("h5" . "http://buzzword.org.uk/rdf/h5#")
    ("ha" . "http://sensormeasurement.appspot.com/ont/home/homeActivity#")
    ("halyard" . "http://merck.github.io/Halyard/ns#")
    ("hard" . "http://www.w3.org/2007/uwa/context/hardware.owl#")
    ("harrisons" . "http://harrisons.cc/")
    ("hartigprov" . "http://purl.org/net/provenance/ns#")
    ("hasco" . "http://hadatac.org/ont/hasco/")
    ("hasneto" . "http://hadatac.org/ont/hasneto#")
    ("hcard" . "http://purl.org/uF/hCard/terms/")
    ("hcterms" . "http://purl.org/uF/hCard/terms/")
    ("hctl" . "https://www.w3.org/2019/wot/hypermedia#")
    ("hdgi" . "https://w3id.org/hdgi#")
    ("hdo" . "http://www.samos.gr/ontologies/helpdeskOnto.owl#")
    ("health" . "http://purl.org/twc/health/vocab/")
    ("healthcare" . "http://www.agfa.com/w3c/2009/healthCare#")
    ("hello" . "https://www.youtube.com/user/SuperTellAFriend/featured/")
    ("hemogram" . "http://www.agfa.com/w3c/2009/hemogram#")
    ("hg" . "http://rdf.histograph.io/")
    ("hgnc" . "http://bio2rdf.org/hgnc:")
    ("hico" . "http://purl.org/emmedi/hico/")
    ("hifm" . "http://purl.org/net/hifm/data#")
    ("hints2005" . "http://purl.org/twc/cabig/model/HINTS2005-1.owl#")
    ("hlisting" . "http://sindice.com/hlisting/0.1/")
    ("hlygt" . "http://www.holygoat.co.uk/owl/redwood/0.1/tags/")
    ("hmas" . "https://purl.org/hmas/")
    ("hni" . "https://collectiedata.hetnieuweinstituut.nl/")
    ("hola" . "https://moodle.insa-lyon.fr/course/view.php?id=")
    ("holding" . "http://purl.org/ontology/holding#")
    ("hops" . "https://rdf.ag/o/hops#")
    ("hosp" . "http://health.data.gov/def/hospital/")
    ("hospital" . "http://www.agfa.com/w3c/2009/hospital#")
    ("hp" . "http://purl.org/voc/hp/")
    ("hpo" . "http://w3id.org/emmo-hpo/hpo#")
    ("hpont" . "https://w3id.org/hpont#")
    ("hqdm" . "http://www.semanticweb.org/hqdm#")
    ("hqdmontol" . "http://www.semanticweb.org/magma-core/ontologies/hqdm#")
    ("hr" . "http://iserve.kmi.open.ac.uk/ns/hrests#")
    ("htir" . "http://www.w3.org/2011/http#")
    ("html" . "http://www.w3.org/1999/xhtml/")
    ("htn" . "http://purl.obolibrary.org/obo/ZP_")
    ("hto" . "http://project-haystack.org/hto#")
    ("http" . "http://www.w3.org/2011/http#")
    ("httph" . "http://www.w3.org/2007/ont/httph#")
    ("httpm" . "http://www.w3.org/2011/http-methods#")
    ("httpvoc" . "http://www.w3.org/2006/http#")
    ("htv" . "http://www.w3.org/2011/http#")
    ("hu" . "https://mail.google.com/")
    ("human" . "http://eulersharp.sourceforge.net/2003/03swap/human#")
    ("humanbody" . "http://eulersharp.sourceforge.net/2003/03swap/humanBody#")
    ("huto" . "http://ns.inria.fr/huto/")
    ("hva" . "http://www.ebusiness-unibw.org/ontologies/hva/ontology#")
    ("hxl" . "http://hxl.humanitarianresponse.info/ns/#")
    ("hy" . "https://api.hyprdia.com/")
    ("hydra" . "http://www.w3.org/ns/hydra/core#")
    ("hyr" . "https://w3id.org/simulation/data/")
    ("i18n" . "https://www.w3.org/ns/i18n#")
    ("iab" . "https://www.iab.com/guidelines/taxonomy/")
    ("iaco" . "https://iaco.me/")
    ("iana" . "http://www.iana.org/assignments/relation/")
    ("ianarel" . "https://www.w3.org/ns/iana/link-relations/relation#")
    ("iao" . "http://purl.obolibrary.org/obo/IAO_")
    ("iaph" . "http://www.juntadeandalucia.es/datosabiertos/portal/iaph/dataset/dataset/6c199ca2-8d2e-4c12-833c-f28")
    ("iati" . "http://purl.org/collections/iati/")
    ("ibeacon" . "http://vocab.rapidthings.eu/ns/apple/ibeacon.ttl#")
    ("ibis" . "http://purl.org/ibis#")
    ("ic" . "http://imi.go.jp/ns/core/rdf#")
    ("ical" . "http://www.w3.org/2002/12/cal/ical#")
    ("icaltzd" . "http://www.w3.org/2002/12/cal/icaltzd#")
    ("icane" . "http://www.icane.es/opendata/vocab#")
    ("icon" . "https://w3id.org/icon/ontology/")
    ("id" . "http://identifiers.org/")
    ("iddo" . "https://w3id.org/iddo#")
    ("idemo" . "http://rdf.insee.fr/def/demo#")
    ("identity" . "http://purl.org/twc/ontologies/identity.owl#")
    ("ideotalex" . "http://www.ideotalex.eu/datos/recurso/")
    ("ido" . "http://purl.obolibrary.org/obo/ido.owl#")
    ("idot" . "http://identifiers.org/idot/")
    ("idpo" . "https://w3id.org/idpo#")
    ("ids" . "https://w3id.org/idsa/core/")
    ("idsc" . "https://w3id.org/idsa/code/")
    ("ies" . "http://ies.data.gov.uk/ontology/ies4#")
    ("ies4" . "http://ies.data.gov.uk/ontology/ies4#")
    ("ifc" . "http://ifcowl.openbimstandards.org/IFC2X3_Final#")
    ("ifcowl" . "http://www.buildingsmart-tech.org/ifcOWL/IFC4_ADD2#")
    ("igeo" . "http://rdf.insee.fr/def/geo#")
    ("ignf" . "http://data.ign.fr/def/ignf#")
    ("ii" . "http://sparql.cwrc.ca/ontologies/ii#")
    ("iig" . "https://w3id.org/iicongraph/data/")
    ("iiif" . "http://iiif.io/api/image/2#")
    ("ilap" . "http://data.posccaesar.org/ilap/")
    ("im" . "http://imgpedia.dcc.uchile.cl/resource/")
    ("imas" . "https://sparql.crssnky.xyz/imasrdf/URIs/imas-schema.ttl#")
    ("imbor" . "https://data.crow.nl/imbor/def/")
    ("imf" . "http://imf.270a.info/dataset/")
    ("imind" . "http://schema.intellimind.ns/symbology#")
    ("imjv" . "https://data.imjv.omgeving.vlaanderen.be/ns/imjv#")
    ("imm" . "http://schemas.microsoft.com/imm/")
    ("imo" . "http://imgpedia.dcc.uchile.cl/ontology#")
    ("imreg" . "http://www.w3.org/2004/02/image-regions#")
    ("ims" . "http://www.imsglobal.org/xsd/imsmd_v1p2/")
    ("inchikey" . "https://identifiers.org/inchikey:")
    ("incident" . "http://vocab.resc.info/incident#")
    ("ind" . "https://w3id.org/inesdata#")
    ("infection" . "http://www.agfa.com/w3c/2009/infectiousDisorder#")
    ("infor" . "http://www.ontologydesignpatterns.org/cp/owl/informationrealization.owl#")
    ("infosys" . "http://www.infosys.com/")
    ("ingredient" . "http://www.owl-ontologies.com/test.owl/ingredient/")
    ("inno" . "http://purl.org/innovation/ns#")
    ("input" . "http://volt-name.space/vocab/input#")
    ("insdc" . "http://ddbj.nig.ac.jp/ontologies/sequence#")
    ("interop" . "http://www.w3.org/ns/solid/interop#")
    ("interval" . "http://reference.data.gov.uk/def/intervals/")
    ("intervals" . "http://reference.data.gov.uk/def/intervals/")
    ("into" . "https://www.apluss.de/ontology/into#")
    ("io" . "https://iaco.me/")
    ("ioc" . "http://w3id.org/ioc#")
    ("iol" . "http://www.ontologydesignpatterns.org/ont/dul/IOLite.owl#")
    ("iop" . "https://w3id.org/iadopt/ont/")
    ("iospress" . "http://ld.iospress.nl/rdf/ontology/")
    ("iot" . "http://iotschema.org/")
    ("iotlite" . "http://purl.oclc.org/NET/UNIS/fiware/iot-lite#")
    ("ioto" . "http://www.irit.fr/recherches/MELODI/ontologies/IoT-O#")
    ("iottta" . "https://w3id.org/iot-tta#")
    ("ipad" . "http://www.padinthecity.com/")
    ("ipo" . "http://purl.org/ipo/core#")
    ("ipsv" . "http://id.esd.org.uk/list/")
    ("ir" . "http://www.ontologydesignpatterns.org/cp/owl/informationrealization.owl#")
    ("ire" . "http://www.ontologydesignpatterns.org/cpont/ire.owl#")
    ("iron" . "http://purl.org/ontology/iron#")
    ("irrl" . "http://www.ontologydesignpatterns.org/cp/owl/informationobjectsandrepresentationlanguages.owl#")
    ("irstea" . "http://ontology.irstea.fr/")
    ("irsteaont" . "http://ontology.irstea.fr/weather/ontology#")
    ("irw" . "http://www.ontologydesignpatterns.org/ont/web/irw.owl#")
    ("is" . "http://purl.org/ontology/is/core#")
    ("isaterms" . "http://purl.org/isaterms/")
    ("isbd" . "http://iflastandards.info/ns/isbd/elements/")
    ("isbdu" . "http://iflastandards.info/ns/isbd/unc/elements/")
    ("isi" . "http://purl.org/ontology/is/inst/")
    ("isidore" . "http://www.rechercheisidore.fr/class/")
    ("iso" . "http://purl.org/iso25964/skos-thes#")
    ("iso37120" . "http://ontology.eil.utoronto.ca/ISO37120.owl#")
    ("isoadr" . "http://reference.data.gov.au/def/ont/iso19160-1-address#")
    ("isocat" . "http://www.isocat.org/datcat/")
    ("isothes" . "http://purl.org/iso25964/skos-thes#")
    ("ispra" . "http://dati.isprambiente.it/ontology/core#")
    ("isq" . "http://purl.org/ontology/is/quality/")
    ("ist" . "http://purl.org/ontology/is/types/")
    ("istex" . "https://data.istex.fr/ontology/istex#")
    ("iswc" . "http://annotation.semanticweb.org/2004/iswc#")
    ("it" . "http://www.influencetracker.com/ontology#")
    ("italy" . "http://data.kasabi.com/dataset/italy/schema/")
    ("itcat" . "http://th-brandenburg.de/ns/itcat#")
    ("itcrdf" . "http://www.w3.org/2005/11/its/rdf#")
    ("iter" . "http://w3id.org/sparql-generate/iter/")
    ("itm" . "http://spi-fm.uca.es/spdef/models/genericTools/itm/1.0#")
    ("itops" . "https://vocab.eccenca.com/itops/")
    ("its" . "http://www.w3.org/2005/11/its/rdf#")
    ("itsmo" . "http://ontology.it/itsmo/v1#")
    ("itsrdf" . "http://www.w3.org/2005/11/its/rdf#")
    ("ja" . "http://jena.hpl.hp.com/2005/11/Assembler#")
    ("java" . "http://www.w3.org/2007/uwa/context/java.owl#")
    ("jdbc" . "http://d2rq.org/terms/jdbc/")
    ("jerm" . "http://jermontology.org/ontology/JERMOntology#")
    ("jita" . "http://aims.fao.org/aos/jita/")
    ("jjd" . "http://www.joshuajeeson.com/")
    ("jolux" . "http://data.legilux.public.lu/resource/ontology/jolux#")
    ("jp1" . "http://rdf.muninn-project.org/ontologies/jp1/")
    ("jpo" . "http://rdf.jpostdb.org/ontology/jpost.owl#")
    ("jpost" . "http://rdf.jpostdb.org/ontology/jpost.owl#")
    ("json" . "https://www.ecma-international.org/publications/files/ECMA-ST/ECMA-404.pdf#")
    ("jsonld" . "http://www.w3.org/ns/json-ld#")
    ("jsonschema" . "https://www.w3.org/2019/wot/json-schema#")
    ("jup" . "http://w3id.org/charta77/jup/")
    ("jur" . "http://sweet.jpl.nasa.gov/2.3/humanJurisdiction.owl#")
    ("juso" . "http://rdfs.co/juso/")
    ("kai" . "http://kai.uni-kiel.de/")
    ("karstlink" . "https://ontology.uis-speleo.org/ontology/#")
    ("kb" . "http://deductions.sf.net/ontology/knowledge_base.owl#")
    ("kbmarc" . "https://id.kb.se/marc/")
    ("kbp" . "http://tackbp.org/2013/ontology#")
    ("kbv" . "https://id.kb.se/vocab/")
    ("kdo" . "http://kdo.render-project.eu/kdo#")
    ("kdsf" . "https://kerndatensatz-forschung.de/version1/technisches_datenmodell/owl/kdsf.owl#")
    ("kees" . "http://linkeddata.center/kees/v1#")
    ("kegg" . "http://bio2rdf.org/ns/kegg#")
    ("keyon" . "http://keyelements.ltd/ontologies/keyon/#")
    ("keys" . "http://purl.org/NET/c4dm/keys.owl#")
    ("kgi" . "http://ns.inria.fr/kg/index#")
    ("kko" . "http://kbpedia.org/kko/rc/")
    ("km4c" . "http://www.disit.org/km4city/schema#")
    ("kmgeo" . "http://km.aifb.kit.edu/services/geo/ontology#")
    ("kml" . "http://www.opengis.net/kml/2.2#")
    ("knows" . "http://semantic.komc/usu/2020/knows#")
    ("koko" . "https://seznam.cz/")
    ("kokot" . "http://www.koko.t/")
    ("koly" . "http://www.ensias.ma/")
    ("kontakt" . "http://richard.cyganiak.de/")
    ("kpd" . "http://purl.org/kpd/")
    ("ksam" . "http://kulturarvsdata.se/ksamsok#")
    ("ksamsok" . "http://kulturarvsdata.se/ksamsok#")
    ("kupkb" . "http://www.e-lico.eu/data/kupkb/")
    ("kw" . "http://kwantu.net/kw/")
    ("kwijibo" . "http://kwijibo.talis.com/")
    ("l2sp" . "http://www.linked2safety-project.eu/properties/")
    ("l4a" . "http://labels4all.info/ns/")
    ("l4lod" . "http://ns.inria.fr/l4lod/v2/")
    ("la" . "https://linked.art/ns/terms/")
    ("laabs" . "http://dbpedia.org/resource/")
    ("label" . "http://purl.org/net/vocab/2004/03/label#")
    ("lado" . "http://archaeology.link/ontology#")
    ("lang" . "http://ontologi.es/lang/core#")
    ("language" . "http://id.loc.gov/vocabulary/iso639-1/")
    ("languages" . "http://eulersharp.sourceforge.net/2003/03swap/languages#")
    ("laposte" . "http://data.lirmm.fr/ontologies/laposte#")
    ("lark1" . "http://users.utcluj.ro/~raluca/ontology/Ontology1279614123500.owl#")
    ("lastfm" . "http://purl.org/ontology/last-fm/")
    ("latitude" . "https://www.w3.org/2006/vcard/ns#")
    ("lawd" . "http://lawd.info/ontology/")
    ("lbds" . "https://w3id.org/lbdserver#")
    ("lbdserver" . "https://w3id.org/lbdserver#")
    ("lblodlg" . "http://data.lblod.info/vocabularies/leidinggevenden/")
    ("lc" . "http://semweb.mmlab.be/ns/linkedconnections#")
    ("lcdr" . "http://ns.lucid-project.org/revision/")
    ("lcnaf" . "http://id.loc.gov/authorities/names/")
    ("lcsh" . "http://id.loc.gov/authorities/subjects/")
    ("lctr" . "http://data.linkedct.org/vocab/resource/")
    ("lcy" . "http://purl.org/vocab/lifecycle/schema#")
    ("ld" . "http://linkeddata.ru/")
    ("lda" . "http://purl.org/linked-data/api/vocab#")
    ("ldap" . "http://purl.org/net/ldap/")
    ("ldc" . "https://tac.nist.gov/tracks/SM-KBP/2018/ontologies/SeedlingOntology#")
    ("lden" . "http://www.linklion.org/lden/")
    ("ldes" . "https://w3id.org/ldes#")
    ("ldl" . "https://w3id.org/ldpdl/ns#")
    ("ldn" . "https://www.w3.org/TR/ldn/#")
    ("ldp" . "http://www.w3.org/ns/ldp#")
    ("ldpsc" . "https://solid.ti.rw.fau.de/public/ns/stream-containers#")
    ("ldq" . "http://www.linkeddata.es/ontology/ldq#")
    ("ldqm" . "http://linkeddata.es/resource/ldqm/")
    ("ldr" . "http://purl.oclc.org/NET/ldr/ns#")
    ("lds" . "https://solid.ti.rw.fau.de/public/ns/linked-data-structures#")
    ("ldt" . "https://www.w3.org/ns/ldt#")
    ("ldvm" . "http://linked.opendata.cz/ontology/ldvm/")
    ("leak" . "http://data.ontotext.com/resource/leak/")
    ("leaks" . "https://cuzin.com/")
    ("led" . "http://led.kmi.open.ac.uk/term/")
    ("legal" . "http://www.w3.org/ns/legal#")
    ("lemon" . "http://lemon-model.net/lemon#")
    ("lemonuby" . "http://lemon-model.net/lexica/uby/")
    ("lesa" . "http://hadatac.org/ont/lesa#")
    ("lex" . "http://purl.org/lex#")
    ("lexcz" . "http://purl.org/lex/cz#")
    ("lexicog" . "http://www.w3.org/ns/lemon/lexicog#")
    ("lexicon" . "http://www.example.org/lexicon#")
    ("lexinfo" . "http://www.lexinfo.net/ontology/3.0/lexinfo#")
    ("lexvo" . "http://lexvo.org/ontology#")
    ("lfm" . "http://purl.org/ontology/last-fm/")
    ("lfn" . "http://www.dotnetrdf.org/leviathan#")
    ("lfov" . "https://w3id.org/legal_form#")
    ("lg" . "https://purl.org/lg/")
    ("lgd" . "http://linkedgeodata.org/triplify/")
    ("lgdm" . "http://linkedgeodata.org/meta/")
    ("lgdo" . "http://linkedgeodata.org/ontology/")
    ("lgdt" . "http://linkedgeodata.org/triplify/")
    ("lgt" . "http://linkedgadget.com/wiki/Property:")
    ("lgv" . "http://linkedgeodata.org/ontology/")
    ("lh" . "http://vocab.inf.ed.ac.uk/library/holdings#")
    ("lheo" . "http://www.conjecto.com/ontology/2015/lheo#")
    ("li" . "http://def.seegrid.csiro.au/isotc211/iso19115/2003/lineage#")
    ("lib" . "http://purl.org/library/")
    ("library" . "http://purl.org/library/")
    ("lido" . "http://www.lido-schema.org/")
    ("life" . "http://life.deri.ie/schema/")
    ("lifecycle" . "http://purl.org/vocab/lifecycle/schema#")
    ("like" . "http://ontologi.es/like#")
    ("lime" . "http://www.w3.org/ns/lemon/lime#")
    ("limo" . "http://www.purl.org/limo-ontology/limo#")
    ("limoo" . "http://purl.org/LiMo/0.1/")
    ("lindt" . "http://purl.org/NET/lindt#")
    ("ling" . "http://purl.org/voc/ling/")
    ("lingvo" . "http://www.lingvoj.org/ontology#")
    ("lingvoj" . "http://www.lingvoj.org/ontology#")
    ("link" . "http://www.w3.org/2007/ont/link#")
    ("linkedart" . "https://linked.art/ns/terms/")
    ("linkedct" . "http://data.linkedct.org/vocab/")
    ("linkedmdb" . "http://data.linkedmdb.org/")
    ("linkml" . "https://w3id.org/linkml/")
    ("linkrel" . "https://www.w3.org/ns/iana/link-relations/relation#")
    ("lio" . "http://purl.org/net/lio#")
    ("list" . "http://www.w3.org/2000/10/swap/list#")
    ("literal" . "http://www.essepuntato.it/2010/06/literalreification/")
    ("literature" . "http://purl.org/net/cnyt-literature#")
    ("ljkl" . "http://teste.com/")
    ("ll" . "http://lodlaundromat.org/resource/")
    ("llalg" . "http://www.linklion.org/algorithm/")
    ("lldr" . "http://purl.oclc.org/NET/lldr/ns#")
    ("llm" . "http://lodlaundromat.org/metrics/ontology/")
    ("llo" . "http://lodlaundromat.org/ontology/")
    ("llont" . "http://www.linklion.org/ontology#")
    ("llr" . "http://lodlaundromat.org/resource/")
    ("lmdb" . "http://data.linkedmdb.org/")
    ("lmf" . "http://www.lexinfo.net/lmf#")
    ("lmm1" . "http://www.ontologydesignpatterns.org/ont/lmm/LMM_L1.owl#")
    ("lmm2" . "http://www.ontologydesignpatterns.org/ont/lmm/LMM_L2.owl#")
    ("lmo" . "http://linkedmultimedia.org/sparql-mm/ns/2.0.0/ontology#")
    ("lmu" . "https://w3id.org/laas-iot/lmu#")
    ("lmx" . "http://www.w3.org/XML/1998/namespace/")
    ("ln" . "https://w3id.org/ln#")
    ("loc" . "http://purl.org/ontomedia/core/space#")
    ("locah" . "http://data.archiveshub.ac.uk/def/")
    ("location" . "http://sw.deri.org/2006/07/location/loc#")
    ("loci" . "http://linked.data.gov.au/def/loci#")
    ("locn" . "http://www.w3.org/ns/locn#")
    ("locwd" . "http://purl.org/locwd/schema#")
    ("lod2" . "http://lod2.eu/schema/")
    ("lodac" . "http://lod.ac/ns/lodac#")
    ("lode" . "http://linkedevents.org/ontology/")
    ("lofv" . "http://purl.org/legal_form/vocab#")
    ("log" . "http://www.w3.org/2000/10/swap/log#")
    ("logies" . "https://data.vlaanderen.be/ns/logies#")
    ("loinc" . "https://loinc.org/")
    ("lol" . "https://sbalot.github.io/lol/")
    ("lom" . "http://ltsc.ieee.org/rdf/lomv1p0/lom#")
    ("lomvoc" . "http://ltsc.ieee.org/rdf/lomv1p0/vocabulary#")
    ("losp" . "http://sparql.sstu.ru:3030/speciality/")
    ("loted" . "http://loted.eu/ontology#")
    ("lotico" . "http://www.lotico.com/resource/")
    ("loticoowl" . "http://www.lotico.com/ontology/")
    ("loupe" . "http://ont-loupe.linkeddata.es/def/core/")
    ("lovc" . "https://w3id.org/lovcube/ns/lovcube#")
    ("lp" . "http://launchpad.net/rdf/launchpad#")
    ("lpeu" . "http://purl.org/linkedpolitics/vocabulary/eu/plenary/")
    ("lprov" . "http://id.learning-provider.data.ac.uk/terms#")
    ("lpto" . "http://w3id.org/lpto#")
    ("lpwc" . "https://linkedpaperswithcode.com/property/")
    ("lr" . "http://linkedrecipes.org/schema/")
    ("lrcommon" . "http://landregistry.data.gov.uk/def/common/")
    ("lrm" . "https://iflastandards.info/ns/lrm/lrmoo/")
    ("ls" . "http://linkedspending.aksw.org/instance/")
    ("lsc" . "http://linkedscience.org/lsc/ns#")
    ("lsd" . "http://linkedwidgets.org/statisticaldata/ontology/")
    ("lslife" . "http://ontology.cybershare.utep.edu/ELSEWeb/elseweb-lifemapper.owl#")
    ("lsmap" . "http://ontology.cybershare.utep.edu/ELSEWeb/elseweb-data.owl#")
    ("lso" . "http://linkedspending.aksw.org/ontology/")
    ("lsq" . "http://lsq.aksw.org/vocab#")
    ("lsqr" . "http://lsq.aksw.org/")
    ("lsqv" . "http://lsq.aksw.org/vocab#")
    ("lsweb" . "http://ontology.cybershare.utep.edu/ELSEWeb/elseweb-data.owl#")
    ("lswmo" . "http://ontology.cybershare.utep.edu/ELSEWeb/elseweb-modelling.owl#")
    ("lswpm" . "http://ontology.cybershare.utep.edu/ELSEWeb/elseweb-lifemapper-parameters.owl#")
    ("lt" . "http://diplomski.nelakolundzija.org/LTontology.rdf#")
    ("lu" . "http://www.ontologydesignpatterns.org/ont/framenet/abox/lu/")
    ("luc" . "http://www.ontotext.com/owlim/lucene#")
    ("ludo" . "http://ns.inria.fr/ludo/v1#")
    ("luigiusai" . "https://www.luigiusai.it/wp#")
    ("lv" . "http://purl.org/lobid/lv#")
    ("lv2" . "http://lv2plug.in/ns/lv2core/")
    ("lvont" . "http://lexvo.org/ontology#")
    ("lw" . "http://linkedwidgets.org/ontologies/")
    ("lx" . "http://purl.org/NET/lx#")
    ("lyon" . "http://dbpedia.org/resource/Lyon/")
    ("lyou" . "http://purl.org/linkingyou/")
    ("m3" . "http://sensormeasurement.appspot.com/m3#")
    ("m3lite" . "http://purl.org/iot/vocab/m3-lite#")
    ("m4i" . "http://w3id.org/nfdi4ing/metadata4ing#")
    ("m8g" . "http://data.europa.eu/m8g/")
    ("ma" . "http://www.w3.org/ns/ma-ont#")
    ("mads" . "http://www.loc.gov/mads/rdf/v1#")
    ("madsrdf" . "http://www.loc.gov/mads/rdf/v1#")
    ("maeco" . "http://edg.topbraid.solutions/maeco/")
    ("maeo" . "http://w3id.org/emmo-maeo/maeo#")
    ("maet" . "http://edg.topbraid.solutions/taxonomy/macroeconomics/")
    ("mag" . "https://makg.org/property/")
    ("magmardl" . "http://www.semanticweb.org/magma-core/rdl#")
    ("magmauser" . "http://www.semanticweb.org/magma-core/user#")
    ("malaka" . "http://george.gr/")
    ("malignneo" . "http://www.agfa.com/w3c/2009/malignantNeoplasm#")
    ("mammal" . "http://lod.taxonconcept.org/ontology/p01/Mammalia/index.owl#")
    ("mandaat" . "http://data.vlaanderen.be/ns/mandaat#")
    ("manto" . "http://com.vortic3.MANTO/")
    ("marc" . "http://www.loc.gov/MARC21/slim/")
    ("marcgt" . "https://id.loc.gov/vocabulary/marcgt/")
    ("marcrel" . "http://id.loc.gov/vocabulary/relators/")
    ("marcrole" . "http://id.loc.gov/vocabulary/relators/")
    ("markus" . "http://www.markus.com/")
    ("marl" . "http://www.gsi.dit.upm.es/ontologies/marl/ns#")
    ("maroc" . "http://fr.dbpedia.org/page/Maroc/")
    ("marshall" . "http://sites.google.com/site/xgmaitc/")
    ("maso" . "http://securitytoolbox.appspot.com/MASO#")
    ("master1" . "http://idl.u-grenoble3.fr/")
    ("math" . "http://www.w3.org/2000/10/swap/math#")
    ("matmine" . "http://materialsmine.org/ns/")
    ("matrycs" . "http://matrycs.com/")
    ("matvoc" . "http://stream-ontology.com/matvoc/")
    ("mb" . "http://dbtune.org/musicbrainz/resource/instrument/")
    ("mbgd" . "http://mbgd.genome.ad.jp/owl/mbgd.owl#")
    ("mbkeys" . "https://pastebin.com/ThBfphb8#")
    ("mccv" . "http://purl.jp/bio/10/mccv#")
    ("md" . "http://www.w3.org/ns/md#")
    ("mdcs" . "https://mdcs.monumentenkennis.nl/damageatlas/ontology#")
    ("mdi" . "http://w3id.org/multidimensional-interface/ontology#")
    ("mdont" . "http://ont.matchdeck.com/")
    ("mds" . "http://doc.metalex.eu/id/")
    ("meat" . "http://example.com/")
    ("meb" . "http://rdf.myexperiment.org/ontologies/base/")
    ("media" . "http://search.yahoo.com/searchmonkey/media/")
    ("medred" . "http://w3id.org/medred/medred#")
    ("meeting" . "http://www.w3.org/2002/07/meeting#")
    ("meetup" . "http://www.lotico.com/meetup/")
    ("mei" . "http://www.music-encoding.org/ns/mei/")
    ("melding" . "http://lblod.data.gift/vocabularies/automatische-melding/")
    ("mem" . "http://mementoweb.org/ns#")
    ("memento" . "http://mementoweb.org/ns#")
    ("memo" . "http://ontologies.smile.deri.ie/2009/02/27/memo#")
    ("memorix" . "http://memorix.io/ontology#")
    ("merge" . "http://jazz.net/ns/lqe/merge/")
    ("mesh" . "http://id.nlm.nih.gov/mesh/")
    ("mesh2021" . "http://id.nlm.nih.gov/mesh/2021/")
    ("meshv" . "http://id.nlm.nih.gov/mesh/vocab#")
    ("meta" . "https://krr.triply.cc/krr/sameas-meta/def/")
    ("metadata" . "http://purl.oreilly.com/ns/meta/")
    ("metalex" . "http://www.metalex.eu/schema/1.0#")
    ("meteo" . "http://purl.org/ns/meteo#")
    ("mexalgo" . "http://mex.aksw.org/mex-algo#")
    ("mexcore" . "http://mex.aksw.org/mex-core#")
    ("mexperf" . "http://mex.aksw.org/mex-perf#")
    ("mexv" . "http://mex.aksw.org/mex-algo#")
    ("mf" . "http://www.w3.org/2001/sw/DataAccess/tests/test-manifest#")
    ("mfo" . "http://purl.obolibrary.org/obo/ZP_")
    ("mged" . "http://mged.sourceforge.net/ontologies/MGEDOntology.owl#")
    ("mgv" . "http://mangaview.fr/mgv#")
    ("mi" . "http://www.marineinfo.org/ns/ontology#")
    ("mibc" . "http://marineinfo.org/ns/library/bibcodes#")
    ("mibt" . "https://marineinfo.org/ns/library/bibtypes#")
    ("mico" . "http://www.mico-project.eu/ns/platform/1.0/schema#")
    ("mifesto" . "https://w3id.org/mifesto#")
    ("mil" . "http://rdf.muninn-project.org/ontologies/military#")
    ("mime" . "https://www.iana.org/assignments/media-types/")
    ("mindat" . "https://www.mindat.org/")
    ("minim" . "http://purl.org/minim/minim#")
    ("miprog" . "https://marineinfo.org/ns/progress#")
    ("mir" . "http://marineinfo.org/ns/person/roles#")
    ("misp" . "http://purl.org/cyber/misp#")
    ("mit" . "http://purl.org/ontology/mo/mit#")
    ("mls" . "http://www.w3.org/ns/mls#")
    ("mltd" . "https://mltd.pikopikopla.net/mltd-schema#")
    ("mm" . "http://linkedmultimedia.org/sparql-mm/ns/2.0.0/function#")
    ("mmd" . "http://musicbrainz.org/ns/mmd-1.0#")
    ("mmf" . "http://linkedmultimedia.org/sparql-mm/ns/1.0.0/function#")
    ("mml" . "http://www.w3.org/1998/Math/MathML/")
    ("mmm" . "http://www.mico-project.eu/ns/mmm/2.0/schema#")
    ("mmms" . "http://ldf.fi/schema/mmm/")
    ("mmo" . "http://purl.org/momayo/mmo/")
    ("mmoon" . "http://mmoon.org/mmoon/")
    ("mmt" . "http://linkedmultimedia.org/sparql-mm/functions/temporal#")
    ("mnx" . "https://rdf.metanetx.org/schema/")
    ("mo" . "http://purl.org/ontology/mo/")
    ("moac" . "http://observedchange.com/moac/ns#")
    ("moat" . "http://moat-project.org/ns#")
    ("mobiliteit" . "https://data.vlaanderen.be/ns/mobiliteit#")
    ("mobivoc" . "http://schema.mobivoc.org/")
    ("moby" . "http://www.mygrid.org.uk/mygrid-moby-service#")
    ("mocanal" . "http://www.semanticweb.org/asow/ontologies/2013/9/untitled-ontology-36#")
    ("mod" . "http://www.isibang.ac.in/ns/mod#")
    ("mods" . "http://www.loc.gov/mods/v3#")
    ("modsci" . "https://w3id.org/skgo/modsci#")
    ("mohammad" . "http://manesht.ir/")
    ("mondo" . "http://purl.obolibrary.org/obo/")
    ("money" . "http://purl.org/net/rdf-money/")
    ("moo" . "http://www.movieontology.org/2009/11/09/movieontology.owl#")
    ("moont" . "https://w3id.org/moont/")
    ("motogp" . "http://www.motogp.com/")
    ("movie" . "http://data.linkedmdb.org/resource/movie/")
    ("movieo" . "http://movie.com/ontology/")
    ("mp" . "http://jicamaro.info/mp#")
    ("mpeg7" . "http://rhizomik.net/ontologies/2005/03/Mpeg7-2001.owl#")
    ("mpg123" . "https://devuan.net.br/wiki/mpg123/")
    ("mpio" . "http://purl.obolibrary.org/obo/ZP_")
    ("mr" . "http://marineregions.org/ns/ontology#")
    ("mrel" . "http://id.loc.gov/vocabulary/relators/")
    ("mrk" . "http://www.mydomain.org/Mrk-ns#")
    ("mrt" . "http://marineregions.org/ns/placetypes#")
    ("ms" . "http://purl.org/obo/owl/MS#")
    ("msm" . "http://iserve.kmi.open.ac.uk/ns/msm#")
    ("msr" . "http://www.telegraphis.net/ontology/measurement/measurement#")
    ("mt" . "http://www.w3.org/2001/sw/DataAccess/tests/test-manifest#")
    ("mte" . "http://nl.ijs.si/ME/owl/")
    ("mtecore" . "http://purl.org/olia/mte/multext-east.owl#")
    ("mtlo" . "http://www.ics.forth.gr/isl/MarineTLO/v4/marinetlo.owl#")
    ("mu" . "http://mu.semte.ch/vocabularies/core/")
    ("muldicat" . "http://iflastandards.info/ns/muldicat#")
    ("munc" . "http://ns.inria.fr/munc#")
    ("muni" . "http://vocab.linkeddata.es/urbanismo-infraestructuras/territorio#")
    ("muo" . "http://purl.oclc.org/NET/muo/muo#")
    ("mus" . "http://data.doremus.org/ontology#")
    ("music" . "http://musicontology.com/")
    ("musim" . "http://purl.org/ontology/similarity/")
    ("muto" . "http://purl.org/muto/core#")
    ("mv" . "http://schema.mobivoc.org/")
    ("mvco" . "http://purl.oclc.org/NET/mvco.owl#")
    ("mwapi" . "https://www.mediawiki.org/ontology#API/")
    ("my" . "http://www.mobile.com/model/")
    ("mydb" . "http://mydb.org/")
    ("mygrid" . "http://www.mygrid.org.uk/ontology#")
    ("myprefix" . "http://myprefix.org/")
    ("myspace" . "http://purl.org/ontology/myspace#")
    ("myspo" . "http://purl.org/ontology/myspace#")
    ("mysql" . "http://web-semantics.org/ns/mysql/")
    ("nalt" . "https://lod.nal.usda.gov/nalt/")
    ("name" . "http://example.org/name#")
    ("namespaces" . "https://vg.no/")
    ("nanopub" . "http://www.nanopub.org/nschema#")
    ("nao" . "http://www.semanticdesktop.org/ontologies/2007/08/15/nao#")
    ("nas" . "https://data.nasa.gov/ontologies/atmonto/NAS#")
    ("nature" . "http://deductions.github.io/nature_observation.owl.ttl#")
    ("naval" . "http://rdf.muninn-project.org/ontologies/naval#")
    ("navm" . "https://w3id.org/navigation_menu#")
    ("nbo" . "http://data.bioontology.org/ontologies/NBO/")
    ("ncal" . "http://www.semanticdesktop.org/ontologies/2007/04/02/ncal#")
    ("ncbi" . "https://www.ncbi.nlm.nih.gov/")
    ("ncbigene" . "http://identifiers.org/ncbigene/")
    ("ncbitaxon" . "http://purl.org/obo/owl/NCBITaxon#")
    ("ncicp" . "http://ncicb.nci.nih.gov/xml/owl/EVS/Thesaurus.owl#")
    ("ncit" . "https://ncit.nci.nih.gov/ncitbrowser/ConceptReport.jsp?dictionary=NCI_Thesaurus&ns=ncit&code=")
    ("nco" . "http://www.semanticdesktop.org/ontologies/2007/03/22/nco#")
    ("ndl" . "http://schemas.ogf.org/nml/2013/05/base#")
    ("ndnp" . "http://chroniclingamerica.loc.gov/terms#")
    ("ne" . "http://umbel.org/umbel/ne/")
    ("nen2660" . "https://w3id.org/nen2660/def#")
    ("neotec" . "http://neotec.rc.unesp.br/resource/Neotectonics/")
    ("neotecbib" . "http://neotec.rc.unesp.br/resource/NeotectonicsBibliography/")
    ("nerd" . "http://nerd.eurecom.fr/ontology#")
    ("net" . "http://www.w3.org/2007/uwa/context/network.owl#")
    ("newsevents" . "http://www.aifb.uni-karlsruhe.de/WBS/uhe/ontologies#")
    ("nex" . "http://www.nexml.org/2009/")
    ("nexif" . "http://www.semanticdesktop.org/ontologies/2007/05/10/nexif#")
    ("nfo" . "http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#")
    ("ngeo" . "http://geovocab.org/geometry#")
    ("ngeoi" . "http://vocab.lenka.no/geo-deling#")
    ("nid3" . "http://www.semanticdesktop.org/ontologies/2007/05/10/nid3#")
    ("nidm" . "http://nidm.nidash.org/")
    ("nie" . "http://www.semanticdesktop.org/ontologies/2007/01/19/nie#")
    ("nif" . "http://persistence.uni-leipzig.org/nlp2rdf/ontologies/nif-core#")
    ("nih" . "http://ncicb.nci.nih.gov/xml/owl/EVS/Thesaurus.owl#")
    ("nkos" . "http://w3id.org/nkos#")
    ("nlon" . "http://lod.nl.go.kr/ontology/")
    ("nmo" . "http://www.semanticdesktop.org/ontologies/2007/03/22/nmo#")
    ("nndsr" . "http://semanticdiet.com/schema/usda/nndsr/")
    ("nno" . "https://w3id.org/nno/ontology#")
    ("no" . "http://km.aifb.kit.edu/projects/numbers/number#")
    ("nobel" . "http://data.nobelprize.org/terms/")
    ("nocal" . "http://vocab.deri.ie/nocal#")
    ("noise" . "http://vocab.linkeddata.es/datosabiertos/def/medio-ambiente/contaminacion-acustica#")
    ("nom" . "https://nomenclature.info/nom/")
    ("nomo" . "https://nomenclature.info/nom/ontology/")
    ("nosql" . "http://purl.org/db/nosql#")
    ("notify" . "http://www.w3.org/ns/solid/notifications#")
    ("np" . "http://www.nanopub.org/nschema#")
    ("npdv" . "http://sws.ifi.uio.no/vocab/npd#")
    ("npg" . "http://ns.nature.com/terms/")
    ("npgd" . "http://ns.nature.com/datasets/")
    ("npgg" . "http://ns.nature.com/graphs/")
    ("npgx" . "http://ns.nature.com/extensions/")
    ("nprl" . "http://data.nobelprize.org/resource/laureate/")
    ("nrl" . "http://www.semanticdesktop.org/ontologies/2007/08/15/nrl#")
    ("nrv" . "http://ns.inria.fr/nrv#")
    ("ns1" . "http://www.w3.org/1999/xhtml/vocab#")
    ("ns2" . "http://ogp.me/ns#video:")
    ("nsa" . "http://multimedialab.elis.ugent.be/organon/ontologies/ninsuna#")
    ("nsd" . "https://w3id.org/nsd#")
    ("nsg" . "https://neuroshapes.org/")
    ("nsl" . "http://purl.org/ontology/storyline/")
    ("nsogi" . "http://prefix.cc/nsogi:")
    ("nt" . "http://ns.inria.fr/nicetag/2010/09/09/voc#")
    ("ntag" . "http://ns.inria.fr/nicetag/2010/09/09/voc#")
    ("ntp" . "https://schema.finto.fi/ntp#")
    ("number" . "http://km.aifb.kit.edu/projects/numbers/number#")
    ("numbers" . "http://km.aifb.kit.edu/projects/numbers/")
    ("nuts" . "http://dd.eionet.europa.eu/vocabulary/common/nuts/")
    ("nutscode" . "http://data.europa.eu/nuts/code/")
    ("nxp" . "http://purl.org/nxp/schema/v1/")
    ("nxs" . "http://www.neclimateus.org/")
    ("nyt" . "http://data.nytimes.com/")
    ("nytimes" . "http://data.nytimes.com/elements/")
    ("oa" . "http://www.w3.org/ns/oa#")
    ("oac" . "https://w3id.org/oac#")
    ("oad" . "http://lod.xdams.org/reload/oad/")
    ("oae" . "http://www.ics.forth.gr/isl/oae/core#")
    ("oan" . "http://data.lirmm.fr/ontologies/oan/")
    ("oarj" . "http://opendepot.org/reference/linked/1.0/")
    ("oat" . "http://openlinksw.com/schemas/oat/")
    ("oauth" . "http://demiblog.org/vocab/oauth#")
    ("oav" . "http://lod.openaire.eu/vocab/")
    ("oax" . "http://www.w3.org/ns/openannotation/extensions/")
    ("obeu" . "http://data.openbudgets.eu/ontology/")
    ("obj" . "http://www.openrdf.org/rdf/2009/object#")
    ("obo" . "http://purl.obolibrary.org/obo/")
    ("oboe" . "http://ecoinformatics.org/oboe/oboe.1.0/oboe-core.owl#")
    ("oboinowl" . "http://www.geneontology.org/formats/oboInOwl#")
    ("obom" . "https://w3id.org/open-bom/ont/open-bom#")
    ("oboro" . "http://obofoundry.org/ro/ro.owl#")
    ("oboso" . "http://purl.org/obo/owl/SO#")
    ("obsm" . "http://rdf.geospecies.org/methods/observationMethod#")
    ("obws" . "http://delicias.dia.fi.upm.es/ontologies/ObjectWithStates.owl#")
    ("oc" . "http://opencoinage.org/rdf/")
    ("occ" . "http://w3id.org/occ#")
    ("occult" . "http://data.totl.net/occult/")
    ("occupation" . "http://nikunj.org/ontology/occupatioin#")
    ("ocd" . "http://dati.camera.it/ocd/")
    ("ocds" . "http://purl.org/onto-ocds/ocds#")
    ("ocmv" . "https://w3id.org/ontouml-models/vocabulary#")
    ("oco" . "https://w3id.org/oc/ontology/")
    ("ocsw" . "http://data.diekb.org/def/ocsw#")
    ("od" . "http://purl.org/twc/vocab/opendap#")
    ("odapp" . "http://vocab.deri.ie/odapp#")
    ("odapps" . "http://semweb.mmlab.be/ns/odapps#")
    ("odbc" . "http://www.openlinksw.com/ontology/odbc#")
    ("odcs" . "http://opendata.cz/infrastructure/odcleanstore/")
    ("odf" . "http://docs.oasis-open.org/ns/office/1.2/meta/odf#")
    ("odo" . "http://ocean-data.org/schema/")
    ("odp" . "http://ontologydesignpatterns.org/")
    ("odpart" . "http://www.ontologydesignpatterns.org/cp/owl/participation.owl#")
    ("odrl" . "http://www.w3.org/ns/odrl/2/")
    ("odrs" . "http://schema.theodi.org/odrs#")
    ("ods" . "http://lod.xdams.org/ontologies/ods/")
    ("odv" . "http://reference.data.gov.uk/def/organogram/")
    ("odw" . "http://odw.tw/")
    ("oecc" . "http://www.oegov.org/core/owl/cc#")
    ("oecd" . "http://oecd.270a.info/dataset/")
    ("oeo" . "http://openenergy-platform.org/ontology/oeo/")
    ("oeso" . "http://www.opensilex.org/vocabularies/oeso#")
    ("of" . "http://owlrep.eu01.aws.af.cm/fridge#")
    ("ofn" . "http://www.ontotext.com/sparql/functions/")
    ("ofo" . "https://w3id.org/ofo#")
    ("ofrd" . "http://purl.org/opdm/refrigerator#")
    ("og" . "http://opengraphprotocol.org/schema/")
    ("ogbd" . "http://www.ogbd.fr/2012/ontologie#")
    ("ogc" . "http://www.opengis.net/def/")
    ("ogcf" . "http://www.opengis.net/def/function/geosparql/")
    ("ogdl4m" . "https://github.com/martynui/OGDL4M/")
    ("ogham" . "http://lod.ogham.link/data/")
    ("oghamonto" . "http://ontology.ogham.link/")
    ("ogorg" . "http://opengraph.org/schema/")
    ("ogp" . "http://ogp.me/ns#")
    ("ogura" . "https://sparql.crssnky.xyz/Ogura_Hyakunin_Isshu_LinkedRDF/URIs/Ogura_Hyakunin_Isshu_schema.ttl#")
    ("oh" . "http://semweb.mmlab.be/ns/oh#")
    ("ohd" . "http://purl.obolibrary.org/obo/ZP_")
    ("oidc" . "http://www.w3.org/ns/solid/oidc#")
    ("oils" . "http://lemon-model.net/oils#")
    ("oio" . "http://www.geneontology.org/formats/oboInOwl#")
    ("oj" . "http://ontojob.at/")
    ("ok" . "http://okkam.org/terms#")
    ("okg" . "http://openknowledgegraph.org/ontology/")
    ("okh" . "https://w3id.org/oseg/ont/okh#")
    ("okkam" . "http://models.okkam.org/ENS-core-vocabulary#")
    ("olac" . "http://www.language-archives.org/OLAC/1.0/")
    ("olac11" . "http://www.language-archives.org/OLAC/1.1/")
    ("olad" . "http://openlad.org/vocab#")
    ("olca" . "http://www.lingvoj.org/olca#")
    ("olia" . "http://purl.org/olia/olia.owl#")
    ("olias" . "http://purl.org/olia/system.owl#")
    ("oliasystem" . "http://purl.org/olia/system.owl#")
    ("olis" . "http://olis.dev/")
    ("olo" . "http://purl.org/ontology/olo/core#")
    ("om" . "http://opendata.caceres.es/def/ontomunicipio#")
    ("omapi" . "http://purl.org/omapi/0.2/#")
    ("omb" . "http://purl.org/ontomedia/ext/common/being#")
    ("omc" . "http://purl.org/ontomedia/ext/common/bestiary#")
    ("omdoc" . "http://omdoc.org/ontology/")
    ("ome" . "http://purl.org/ontomedia/core/expression#")
    ("omg" . "https://w3id.org/omg#")
    ("omim" . "http://purl.bioontology.org/ontology/OMIM/")
    ("oml" . "http://def.seegrid.csiro.au/ontology/om/om-lite#")
    ("omm" . "http://purl.org/ontomedia/core/media#")
    ("omn" . "http://open-multinet.info/ontology/omn#")
    ("omnfed" . "http://open-multinet.info/ontology/omn-federation#")
    ("omnlc" . "http://open-multinet.info/ontology/omn-lifecycle#")
    ("omnlife" . "http://open-multinet.info/ontology/omn-lifecycle#")
    ("omop" . "http://api.ohdsi.org/WebAPI/vocabulary/concept/")
    ("omp" . "http://purl.org/ontomedia/ext/common/profession#")
    ("omt" . "http://purl.org/ontomedia/ext/common/trait#")
    ("omv" . "http://omv.ontoware.org/2005/05/ontology#")
    ("onc" . "http://www.ics.forth.gr/isl/oncm/core#")
    ("ondc" . "http://www.semanticweb.org/ontologies/2012/1/Ontology1329913965202.owl#")
    ("one" . "https://bioportal.bioontology.org/ontologies/ONE/")
    ("onisep" . "http://rdf.onisep.fr/resource/")
    ("onssprel" . "http://www.ordnancesurvey.co.uk/ontology/SpatialRelations/v0.2/SpatialRelations.owl#")
    ("ont" . "http://purl.org/net/ns/ontology-annot#")
    ("onto" . "http://www.ontotext.com/")
    ("ontobras" . "http://www.semanticweb.org/fefar/ontologies/ontobras#")
    ("ontohgis" . "https://onto.kul.pl/ontohgis/")
    ("ontolex" . "http://www.w3.org/ns/lemon/ontolex#")
    ("ontologia" . "http://ub.edu/dades/ontologia/Cinema#Cinemes#")
    ("ontology" . "http://dbpedia.org/ontology/")
    ("ontoneo" . "http://purl.obolibrary.org/obo/ontoneo/")
    ("ontop" . "https://w3id.org/ontop/")
    ("ontopic" . "http://www.ontologydesignpatterns.org/ont/dul/ontopic.owl#")
    ("ontosec" . "http://www.semanticweb.org/ontologies/2008/11/OntologySecurity.owl#")
    ("ontouml" . "https://w3id.org/ontouml#")
    ("onyx" . "http://www.gsi.dit.upm.es/ontologies/onyx/ns#")
    ("oo" . "http://purl.org/openorg/")
    ("oop" . "http://w3id.org/oop#")
    ("op" . "http://environment.data.gov.au/def/op#")
    ("opa" . "https://w3id.org/laas-iot/adream#")
    ("open" . "http://open.vocab.org/terms/")
    ("open311" . "http://ontology.eil.utoronto.ca/open311#")
    ("opencyc" . "http://sw.opencyc.org/concept/")
    ("opengov" . "http://www.w3.org/opengov#")
    ("openlinks" . "http://www.openlinksw.com/schemas/virtrdf#")
    ("opensearch" . "http://a9.com/-/spec/opensearch/1.1/")
    ("openskos" . "http://openskos.org/xmlns#")
    ("oper" . "http://sweet.jpl.nasa.gov/2.0/mathOperation.owl#")
    ("opl" . "http://openlinksw.com/schema/attribution#")
    ("oplacl" . "http://www.openlinksw.com/ontology/acl#")
    ("oplangel" . "http://www.openlinksw.com/schemas/angel#")
    ("oplben" . "http://www.openlinksw.com/ontology/benefits#")
    ("oplbenefit" . "http://www.openlinksw.com/ontology/benefits#")
    ("oplcb" . "http://www.openlinksw.com/schemas/crunchbase#")
    ("oplcert" . "http://www.openlinksw.com/schemas/cert#")
    ("oplecrm" . "http://www.openlinksw.com/ontology/ecrm#")
    ("oplfeat" . "http://www.openlinksw.com/ontology/features#")
    ("oplgit" . "http://www.openlinksw.com/schemas/github#")
    ("oplli" . "http://www.openlinksw.com/schemas/linkedin#")
    ("opllic" . "http://www.openlinksw.com/ontology/licenses#")
    ("opllog" . "http://www.openlinksw.com/ontology/logging#")
    ("oplmarket" . "http://www.openlinksw.com/ontology/market#")
    ("oplmkt" . "http://www.openlinksw.com/ontology/market#")
    ("oplp" . "http://www.openlinksw.com/ontology/purchases#")
    ("oplprod" . "http://www.openlinksw.com/ontology/products#")
    ("oplres" . "http://www.openlinksw.com/ontology/restrictions#")
    ("oplsoft" . "http://www.openlinksw.com/ontology/software#")
    ("oplstocks" . "http://www.openlinksw.com/ontology/stocks#")
    ("opltw" . "http://www.openlinksw.com/schemas/twitter#")
    ("oplweb" . "http://www.openlinksw.com/schemas/oplweb#")
    ("oplwebsrv" . "http://www.openlinksw.com/ontology/webservices#")
    ("opm" . "https://w3id.org/opm#")
    ("opmo" . "http://openprovenance.org/model/opmo#")
    ("opmv" . "http://purl.org/net/opmv/ns#")
    ("opmw" . "http://www.opmw.org/ontology/")
    ("opo" . "http://online-presence.net/opo/ns#")
    ("oprovo" . "http://openprovenance.org/ontology#")
    ("ops" . "https://w3id.org/ops#")
    ("opus" . "http://lsdis.cs.uga.edu/projects/semdis/opus#")
    ("opwn" . "http://www.ontologyportal.org/WordNet.owl#")
    ("or" . "http://openresearch.org/vocab/")
    ("orca" . "http://geni-orca.renci.org/owl/topology.owl#")
    ("orcid" . "http://orcid.org/")
    ("ordf" . "http://purl.org/NET/ordf/")
    ("ordo" . "http://www.orpha.net/ORDO/")
    ("ore" . "http://www.openarchives.org/ore/terms/")
    ("org" . "http://www.w3.org/ns/org#")
    ("organ" . "http://www.univalle.edu.co/ontologies/Organ#")
    ("organism" . "http://eulersharp.sourceforge.net/2003/03swap/organism#")
    ("organiz" . "http://eulersharp.sourceforge.net/2003/03swap/organization#")
    ("orges" . "http://datos.gob.es/def/sector-publico/organizacion#")
    ("orgesv2" . "http://datos.gob.es/sites/default/files/OntologiaDIR3/orges.owl#")
    ("origins" . "http://origins.link/")
    ("orth" . "http://purl.org/net/orth#")
    ("os" . "http://www.w3.org/2000/10/swap/os#")
    ("osadm" . "http://data.ordnancesurvey.co.uk/ontology/admingeo/")
    ("osag" . "http://www.ordnancesurvey.co.uk/ontology/AdministrativeGeography/v2.0/AdministrativeGeography.rdf#")
    ("osd" . "http://a9.com/-/spec/opensearch/1.1/")
    ("osdu" . "https://w3id.org/OSDU#")
    ("osgb" . "http://data.ordnancesurvey.co.uk/id/")
    ("osgeom" . "http://data.ordnancesurvey.co.uk/ontology/geometry/")
    ("osh" . "https://w3id.org/oseg/ont/osh#")
    ("oslc" . "http://open-services.net/ns/core#")
    ("oslo" . "http://purl.org/oslo/ns/localgov#")
    ("osmm" . "https://www.openstreetmap.org/meta/")
    ("osmnode" . "https://www.openstreetmap.org/node/")
    ("osmo" . "https://purl.org/vimmp/osmo#")
    ("osmrel" . "https://www.openstreetmap.org/relation/")
    ("osmsemnet" . "http://spatial.ucd.ie/2012/08/osmsemnet/")
    ("osmt" . "https://wiki.openstreetmap.org/wiki/Key:")
    ("osmway" . "https://www.openstreetmap.org/way/")
    ("osn" . "http://spatial.ucd.ie/lod/osn/")
    ("osoc" . "http://web-semantics.org/ns/opensocial#")
    ("osp" . "http://data.lirmm.fr/ontologies/osp#")
    ("ospost" . "http://data.ordnancesurvey.co.uk/ontology/postcode/")
    ("osr" . "http://dati.senato.it/osr/")
    ("oss" . "http://opendata.caceres.es/def/ontosemanasanta#")
    ("osspr" . "http://data.ordnancesurvey.co.uk/ontology/spatialrelations/")
    ("ost" . "http://w3id.org/ost/ns#")
    ("ostop" . "http://www.ordnancesurvey.co.uk/ontology/Topography/v0.1/Topography.owl#")
    ("osukdt" . "http://www.ordnancesurvey.co.uk/ontology/Datatypes.owl#")
    ("osys" . "http://purl.org/olia/system.owl#")
    ("otl" . "https://w3id.org/opentrafficlights#")
    ("otrl" . "https://w3id.org/oseg/ont/otrl#")
    ("ottr" . "http://ns.ottr.xyz/templates#")
    ("ou" . "http://opendata.unex.es/def/ontouniversidad#")
    ("oup" . "http://purl.org/ontology-use-patterns#")
    ("out" . "http://ontologies.hypios.com/out#")
    ("output" . "http://volt-name.space/vocab/output#")
    ("ov" . "http://open.vocab.org/terms/")
    ("overheid" . "http://standaarden.overheid.nl/owms/")
    ("owl" . "http://www.w3.org/2002/07/owl#")
    ("owl2xml" . "http://www.w3.org/2006/12/owl2-xml#")
    ("owlim" . "http://www.ontotext.com/trree/owlim#")
    ("owls" . "http://www.daml.org/services/owl-s/1.2/Service.owl#")
    ("owlse" . "http://www.daml.org/services/owl-s/1.2/generic/Expression.owl#")
    ("owltime" . "http://www.w3.org/TR/owl-time#")
    ("owms" . "http://standaarden.overheid.nl/owms/terms/")
    ("owsom" . "https://onlinesocialmeasures.wordpress.com/")
    ("ox" . "http://vocab.ox.ac.uk/projectfunding#")
    ("oxi" . "http://omerxi.com/ontologies/core.owl.ttl#")
    ("p20" . "http://zbw.eu/beta/p20/vocab/")
    ("p2po" . "https://purl.org/p2p-o#")
    ("p3p" . "http://www.w3.org/2002/01/p3prdfv1#")
    ("paam" . "https://lod.mediathek-tanz-theater.de/schema/paam/")
    ("paf" . "https://paf.link/")
    ("paia" . "http://purl.org/ontology/paia#")
    ("pair" . "http://virtual-assembly.org/ontologies/pair#")
    ("pam" . "http://prismstandard.org/namespaces/pam/2.0/")
    ("pand" . "http://bag.basisregistraties.overheid.nl/bag/id/pand/")
    ("parl" . "https://id.parliament.uk/schema/")
    ("part" . "http://purl.org/vocab/participation/schema#")
    ("particip" . "http://purl.org/vocab/participation/schema#")
    ("passim" . "http://data.lirmm.fr/ontologies/passim#")
    ("pat" . "http://purl.org/hpi/patchr#")
    ("pato" . "http://purl.obolibrary.org/obo/")
    ("pattern" . "http://www.essepuntato.it/2008/12/pattern#")
    ("pav" . "http://purl.org/pav/")
    ("pay" . "http://reference.data.gov.uk/def/payment#")
    ("payment" . "http://reference.data.gov.uk/def/payment#")
    ("pbac" . "https://w3id.org/pbac#")
    ("pbo" . "http://purl.org/ontology/pbo/core#")
    ("pbody" . "http://reference.data.gov.uk/def/public-body/")
    ("pc" . "http://purl.org/procurement/public-contracts#")
    ("pccz" . "http://purl.org/procurement/public-contracts-czech#")
    ("pcdm" . "http://pcdm.org/models#")
    ("pcdmuse" . "http://pcdm.org/use#")
    ("pcdt" . "http://purl.org/procurement/public-contracts-datatypes#")
    ("pcit" . "http://public-contracts.nexacenter.org/id/propertiesRole/")
    ("pco" . "http://purl.org/procurement/public-contracts#")
    ("pcp" . "https://pcp-on-web.de/ontology/0.2/index-en.html#")
    ("pdf" . "http://ns.adobe.com/pdf/1.3/")
    ("pdo" . "http://ontologies.smile.deri.ie/pdo#")
    ("peco" . "https://w3id.org/peco#")
    ("penis" . "http://penis.to/#")
    ("penn" . "http://purl.org/olia/penn.owl#")
    ("pep" . "https://w3id.org/pep/")
    ("perscido" . "https://perscido.univ-grenoble-alpes.fr/")
    ("persee" . "http://data.persee.fr/ontology/persee_ontology/")
    ("person" . "http://www.w3.org/ns/person#")
    ("persoon" . "http://data.vlaanderen.be/ns/persoon#")
    ("pext" . "http://www.ontotext.com/proton/protonext#")
    ("pf" . "http://jena.hpl.hp.com/ARQ/property#")
    ("pfeepsa" . "https://w3id.org/pfeepsa#")
    ("pgo" . "http://ii.uwb.edu.pl/pgo#")
    ("pgterms" . "http://www.gutenberg.org/2009/pgterms/")
    ("pgxo" . "http://pgxo.loria.fr/")
    ("pham" . "https://w3id.org/skgo/pham#")
    ("phdd" . "http://rdf-vocabulary.ddialliance.org/phdd#")
    ("phil" . "http://philosurfical.open.ac.uk/ontology/philosurfical.owl#")
    ("photoshop" . "http://ns.adobe.com/photoshop/1.0/")
    ("phss" . "http://ns.poundhill.com/phss/1.0/")
    ("phto" . "http://rhizomik.net/ontologies/PlantHealthThreats.owl.ttl#")
    ("phy" . "https://w3id.org/skgo/phy#")
    ("physics" . "http://www.astro.umd.edu/~eshaya/astro-onto/owl/physics.owl#")
    ("physo" . "http://merlin.phys.uni.lodz.pl/onto/physo/physo.owl#")
    ("pic" . "http://www.ipaw.info/ns/picaso#")
    ("pid" . "http://permid.org/ontology/organization/")
    ("piero" . "http://reactionontology.org/piero/")
    ("pim" . "http://www.w3.org/ns/pim/space#")
    ("pimo" . "http://www.semanticdesktop.org/ontologies/2007/11/01/pimo#")
    ("pineapple" . "http://hexananas.com/pineapple#")
    ("ping" . "https://namso-gen.com/")
    ("pingback" . "http://purl.org/net/pingback/")
    ("pit" . "http://data.elsevier.com/vocabulary/ElsevierPubItemTypes/")
    ("pizza" . "http://www.co-ode.org/ontologies/pizza/pizza.owl#")
    ("pkgsrc" . "http://pkgsrc.co/schema#")
    ("pkm" . "http://www.ontotext.com/proton/protonkm#")
    ("pkmn" . "http://pokedex.dataincubator.org/pkm/")
    ("place" . "http://purl.org/ontology/places/")
    ("places" . "http://purl.org/ontology/places#")
    ("planet" . "http://dbpedia.org/")
    ("plant" . "http://example.org/plant/")
    ("plasma" . "https://w3id.org/plasma#")
    ("play" . "http://uriplay.org/spec/ontology/#")
    ("ple" . "http://pleiades.stoa.org/places/")
    ("plg" . "http://parliament.uk/ontologies/legislation/")
    ("plink" . "http://buzzword.org.uk/rdf/personal-link-types#")
    ("plo" . "http://purl.org/net/po#")
    ("pm" . "http://premon.fbk.eu/resource/")
    ("pmc" . "http://identifiers.org/pmc/")
    ("pmd" . "https://w3id.org/pmd/co/")
    ("pmhb" . "http://pmhb.org/")
    ("pml" . "http://provenanceweb.org/ns/pml#")
    ("pmlj" . "http://inference-web.org/2.0/pml-justification.owl#")
    ("pmlp" . "http://inference-web.org/2.0/pml-provenance.owl#")
    ("pmlr" . "http://inference-web.org/2.0/pml-relation.owl#")
    ("pmlt" . "http://inference-web.org/2.0/pml-trust.owl#")
    ("pmo" . "http://premon.fbk.eu/ontology/core#")
    ("pmofn" . "http://premon.fbk.eu/ontology/fn#")
    ("pmonb" . "http://premon.fbk.eu/ontology/nb#")
    ("pmopb" . "http://premon.fbk.eu/ontology/pb#")
    ("pmovn" . "http://premon.fbk.eu/ontology/vn#")
    ("pmt" . "http://tipsy.googlecode.com/svn/trunk/vocab/pmt#")
    ("pna" . "http://data.press.net/ontology/asset/")
    ("pnc" . "http://data.press.net/ontology/classification/")
    ("pne" . "http://data.press.net/ontology/event/")
    ("pni" . "http://data.press.net/ontology/identifier/")
    ("pns" . "http://data.press.net/ontology/stuff/")
    ("pnt" . "http://data.press.net/ontology/tag/")
    ("pnv" . "https://w3id.org/pnv#")
    ("po" . "http://purl.org/ontology/po/")
    ("pobo" . "http://purl.obolibrary.org/obo/")
    ("pod" . "https://project-open-data.cio.gov/v1.1/schema/#")
    ("poder" . "http://poderopedia.com/vocab/")
    ("pois" . "http://purl.oclc.org/POIS/vcblr#")
    ("poke" . "https://pokemonkg.org/ontology#")
    ("pol" . "http://escience.rpi.edu/ontology/semanteco/2/0/pollution.owl#")
    ("politico" . "http://www.rdfabout.com/rdf/schema/politico/")
    ("pom" . "http://maven.apache.org/POM/4.0.0#")
    ("pop" . "http://wiki.dbpedia.org/")
    ("pos" . "http://www.w3.org/2003/01/geo/wgs84_pos#")
    ("posh" . "http://poshrdf.org/ns/posh/")
    ("postcode" . "http://data.ordnancesurvey.co.uk/id/postcodeunit/")
    ("poste" . "http://data.lirmm.fr/ontologies/poste#")
    ("powder" . "http://www.w3.org/2007/05/powder#")
    ("powla" . "http://purl.org/powla/powla.owl#")
    ("pp" . "http://peoplesplaces.de/ontology#")
    ("ppeer" . "http://parliament.uk/ontologies/peerage/")
    ("pplan" . "http://purl.org/net/p-plan#")
    ("ppn" . "http://parliament.uk/ontologies/person-name/")
    ("ppo" . "http://vocab.deri.ie/ppo#")
    ("ppr" . "http://purl.org/datanode/ppr/ns/")
    ("pproc" . "http://contsem.unizar.es/def/sector-publico/pproc#")
    ("pq" . "http://www.wikidata.org/prop/qualifier/")
    ("pr" . "http://purl.org/ontology/prv/core#")
    ("prefix" . "http://prefix.cc/")
    ("premis" . "http://www.loc.gov/premis/rdf/v3/")
    ("prf" . "http://www.openmobilealliance.org/tech/profiles/UAPROF/ccppschema-20021212#")
    ("prism" . "http://prismstandard.org/namespaces/basic/2.0/")
    ("prism21" . "http://prismstandard.org/namespaces/basic/2.1/")
    ("prismdb" . "https://prismdb.takanakahiko.me/prism-schema.ttl#")
    ("prissma" . "http://ns.inria.fr/prissma/v1#")
    ("prj" . "http://purl.org/stuff/project/")
    ("pro" . "http://purl.org/hpi/patchr#")
    ("probont" . "http://www.probonto.org/ontology#")
    ("product" . "http://purl.org/commerce/product#")
    ("prof" . "http://www.w3.org/ns/dx/prof/")
    ("profiling" . "http://ontologi.es/profiling#")
    ("prog" . "http://purl.org/prog/")
    ("prohow" . "https://w3id.org/prohow#")
    ("prolog" . "http://eulersharp.sourceforge.net/2003/03swap/prolog#")
    ("proms" . "http://promsns.org/def/proms#")
    ("pronom" . "http://reference.data.gov.uk/technical-registry/")
    ("prop" . "http://dbpedia.org/property/")
    ("property" . "http://fr.dbpedia.org/property/")
    ("prot" . "http://www.proteinontology.info/po.owl#")
    ("protege" . "http://protege.stanford.edu/system#")
    ("protegedc" . "http://protege.stanford.edu/plugins/owl/dc/protege-dc.owl#")
    ("proton" . "http://www.ontotext.com/proton/")
    ("protons" . "http://proton.semanticweb.org/2005/04/protons#")
    ("prov" . "http://www.w3.org/ns/prov#")
    ("provenir" . "http://knoesis.wright.edu/provenir/provenir.owl#")
    ("provinsi" . "http://provinsi.com/")
    ("provoc" . "http://ns.inria.fr/provoc/")
    ("provone" . "http://purl.org/provone#")
    ("prv" . "http://purl.org/net/provenance/ns#")
    ("prviv" . "http://purl.org/net/provenance/integrity#")
    ("prvr" . "http://purl.org/ontology/prv/rules#")
    ("prvt" . "http://purl.org/net/provenance/types#")
    ("prvtypes" . "http://purl.org/net/provenance/types#")
    ("przecieki" . "http://onlyfans.com/emiliaszymanska/")
    ("ps" . "https://w3id.org/payswarm#")
    ("psh" . "http://ns.inria.fr/probabilistic-shacl/")
    ("pso" . "http://purl.org/spar/pso/")
    ("psv" . "http://www.wikidata.org/prop/statement/value/")
    ("psych" . "http://purl.org/vocab/psychometric-profile/")
    ("psys" . "http://proton.semanticweb.org/protonsys#")
    ("pto" . "http://www.productontology.org/id/")
    ("ptop" . "http://www.ontotext.com/proton/protontop#")
    ("ptr" . "http://www.w3.org/2009/pointers#")
    ("pubchem" . "https://pubchem.ncbi.nlm.nih.gov/")
    ("pubmed" . "http://bio2rdf.org/pubmed_vocabulary:")
    ("puc" . "http://purl.org/NET/puc#")
    ("puelia" . "http://kwijibo.talis.com/vocabs/puelia#")
    ("puml" . "http://plantuml.com/ontology#")
    ("purl" . "http://www.purl.org/")
    ("push" . "http://www.w3.org/2007/uwa/context/push.owl#")
    ("pv" . "http://ns.inria.fr/provoc#")
    ("pvcs" . "http://purl.org/twc/vocab/pvcs#")
    ("pwkso" . "http://ns.inria.fr/pwkso/")
    ("pwo" . "http://purl.org/spar/pwo/")
    ("qa" . "http://www.mit.jyu.fi/ai/TRUST_Ontologies/QA.owl#")
    ("qb" . "http://purl.org/linked-data/cube#")
    ("qb4o" . "http://purl.org/olap#")
    ("qbe" . "http://citydata.wu.ac.at/qb-equations#")
    ("qdoslf" . "http://foaf.qdos.com/lastfm/schema/")
    ("qk" . "http://qudt.org/vocab/quantitykind/")
    ("qkdv" . "http://qudt.org/vocab/dimensionvector/")
    ("ql" . "http://www.w3.org/2004/ql#")
    ("qms" . "http://data.europa.eu/esco/qms#")
    ("qrl" . "http://www.aifb.kit.edu/project/ld-retriever/qrl#")
    ("qu" . "http://purl.oclc.org/NET/ssnx/qu/qu#")
    ("quak" . "http://dev.w3.org/cvsweb/2000/quacken/vocab#")
    ("quantities" . "http://eulersharp.sourceforge.net/2003/03swap/quantitiesExtension#")
    ("quantity" . "http://qudt.org/schema/quantity#")
    ("qud" . "http://qudt.org/1.1/schema/qudt#")
    ("qudt" . "http://qudt.org/schema/qudt/")
    ("quest" . "https://rb.gy/ntg7l/")
    ("quid" . "https://w3id.org/quid/")
    ("quit" . "http://quit.aksw.org/vocab/")
    ("quran" . "http://khalidaloufi.sa/quran#")
    ("quty" . "http://www.telegraphis.net/ontology/measurement/quantity#")
    ("qvoc" . "http://mlode.nlp2rdf.org/quranvocab#")
    ("r2r" . "http://www4.wiwiss.fu-berlin.de/bizer/r2r/")
    ("r2rml" . "http://www.w3.org/ns/r2rml#")
    ("r3d" . "http://www.re3data.org/schema/3-0#")
    ("r4r" . "http://guava.iis.sinica.edu.tw/r4r/")
    ("r4ta" . "http://ns.inria.fr/ratio4ta/v1#")
    ("raad" . "https://raadzaam.nl/schema/")
    ("rad" . "http://www.w3.org/ns/rad#")
    ("radar" . "http://www.radar-projekt.org/display/")
    ("radion" . "http://www.w3.org/ns/radion#")
    ("rail" . "http://ontologi.es/rail/vocab#")
    ("rami" . "http://iais.fraunhofer.de/vocabs/rami#")
    ("ramon" . "http://rdfdata.eionet.europa.eu/ramon/ontology/")
    ("rank" . "http://www.ontotext.com/owlim/RDFRank#")
    ("rankrage" . "https://rankrage.de/")
    ("rating" . "http://www.tvblob.com/ratings/#")
    ("raul" . "http://vocab.deri.ie/raul#")
    ("raum" . "https://terminology.fraunhofer.de/voc/raum#")
    ("rb" . "https://w3id.org/riverbench/schema/metadata#")
    ("rbdoc" . "https://w3id.org/riverbench/schema/documentation#")
    ("rc" . "https://w3id.org/rc#")
    ("rcgs" . "https://collection.rcgs.jp/terms/")
    ("rda" . "http://www.rdaregistry.info/")
    ("rdaa" . "http://rdaregistry.info/Elements/a/")
    ("rdaad" . "http://rdaregistry.info/Elements/a/datatype/")
    ("rdaao" . "http://rdaregistry.info/Elements/a/object/")
    ("rdaar" . "http://rdaregistry.info/termList/AspectRatio/")
    ("rdabf" . "http://rdaregistry.info/termList/bookFormat/")
    ("rdabm" . "http://rdaregistry.info/termList/RDABaseMaterial/")
    ("rdabs" . "http://rdaregistry.info/termList/broadcastStand/")
    ("rdac" . "http://rdaregistry.info/Elements/c/")
    ("rdacarrier" . "http://rdvocab.info/termList/RDACarrierType/")
    ("rdacarx" . "http://rdaregistry.info/termList/RDACarrierEU/")
    ("rdacc" . "http://rdaregistry.info/termList/RDAColourContent/")
    ("rdacct" . "http://rdaregistry.info/termList/CollTitle/")
    ("rdacdt" . "http://rdaregistry.info/termList/RDACartoDT/")
    ("rdaco" . "http://rdaregistry.info/termList/RDAContentType/")
    ("rdacontent" . "http://rdvocab.info/termList/RDAContentType/")
    ("rdacpc" . "http://rdaregistry.info/termList/configPlayback/")
    ("rdact" . "http://rdaregistry.info/termList/RDACarrierType/")
    ("rdae" . "http://rdaregistry.info/Elements/e/")
    ("rdaed" . "http://rdaregistry.info/Elements/e/datatype/")
    ("rdaemm" . "http://rdaregistry.info/termList/emulsionMicro/")
    ("rdaeo" . "http://rdaregistry.info/Elements/e/object/")
    ("rdaep" . "http://rdaregistry.info/termList/RDAExtensionPlan/")
    ("rdafmn" . "http://rdaregistry.info/termList/MusNotation/")
    ("rdafnm" . "http://rdaregistry.info/termList/FormNoteMus/")
    ("rdafnv" . "http://rdaregistry.info/termList/noteForm/")
    ("rdafr" . "http://rdaregistry.info/termList/frequency/")
    ("rdafrbr" . "http://rdvocab.info/uri/schema/FRBRentitiesRDA/")
    ("rdafs" . "http://rdaregistry.info/termList/fontSize/")
    ("rdaft" . "http://rdaregistry.info/termList/fileType/")
    ("rdaftn" . "http://rdaregistry.info/termList/TacNotation/")
    ("rdag1" . "http://rdvocab.info/Elements/")
    ("rdag2" . "http://rdvocab.info/ElementsGr2/")
    ("rdag3" . "http://rdvocab.info/ElementsGr3/")
    ("rdagd" . "http://rdaregistry.info/termList/gender/")
    ("rdagen" . "http://rdaregistry.info/termList/RDAGeneration/")
    ("rdagr1" . "http://rdvocab.info/Elements/")
    ("rdagrp" . "http://rdaregistry.info/termList/groovePitch/")
    ("rdagw" . "http://rdaregistry.info/termList/grooveWidth/")
    ("rdai" . "http://rdaregistry.info/Elements/i/")
    ("rdaid" . "http://rdaregistry.info/Elements/i/datatype/")
    ("rdaill" . "http://rdaregistry.info/termList/IllusContent/")
    ("rdaim" . "http://rdaregistry.info/termList/RDAInteractivityMode/")
    ("rdaio" . "http://rdaregistry.info/Elements/i/object/")
    ("rdalay" . "http://rdaregistry.info/termList/layout/")
    ("rdam" . "http://rdaregistry.info/Elements/m/")
    ("rdamat" . "http://rdaregistry.info/termList/RDAMaterial/")
    ("rdamd" . "http://rdaregistry.info/Elements/m/datatype/")
    ("rdamedia" . "http://rdvocab.info/termList/RDAMediaType/")
    ("rdami" . "http://rdaregistry.info/termList/modeIssue/")
    ("rdamo" . "http://rdaregistry.info/Elements/m/object/")
    ("rdamt" . "http://rdaregistry.info/termList/RDAMediaType/")
    ("rdan" . "http://rdaregistry.info/Elements/n/")
    ("rdand" . "http://rdaregistry.info/Elements/n/datatype/")
    ("rdano" . "http://rdaregistry.info/Elements/n/object/")
    ("rdap" . "http://rdaregistry.info/Elements/p/")
    ("rdapath" . "http://rdaregistry.info/termList/RDARecordingMethods/")
    ("rdapd" . "http://rdaregistry.info/Elements/p/datatype/")
    ("rdapf" . "http://rdaregistry.info/termList/presFormat/")
    ("rdapm" . "http://rdaregistry.info/termList/RDAproductionMethod/")
    ("rdapmt" . "http://rdaregistry.info/termList/prodTactile/")
    ("rdapo" . "http://rdaregistry.info/Elements/p/object/")
    ("rdapol" . "http://rdaregistry.info/termList/RDAPolarity/")
    ("rdare" . "http://rdaregistry.info/termList/RDARegionalEncoding/")
    ("rdarel" . "http://rdvocab.info/RDARelationshipsWEMI/")
    ("rdarel2" . "http://metadataregistry.org/uri/schema/RDARelationshipsGR2/")
    ("rdarm" . "http://registry.info/termList/recMedium/")
    ("rdarole" . "http://rdvocab.info/roles/")
    ("rdarr" . "http://rdaregistry.info/termList/RDAReductionRatio/")
    ("rdasca" . "http://rdaregistry.info/termList/scale/")
    ("rdasco" . "http://rdaregistry.info/termList/soundCont/")
    ("rdasoi" . "http://rdaregistry.info/termList/statIdentification/")
    ("rdasource" . "http://rdaregistry.info/termList/RDARecordingSources/")
    ("rdaspc" . "http://rdaregistry.info/termList/specPlayback/")
    ("rdat" . "http://rdaregistry.info/Elements/t/")
    ("rdatask" . "http://rdaregistry.info/termList/RDATasks/")
    ("rdatb" . "http://rdaregistry.info/termList/RDATypeOfBinding/")
    ("rdatc" . "http://rdaregistry.info/termList/trackConfig/")
    ("rdatd" . "http://rdaregistry.info/Elements/t/datatype/")
    ("rdaterm" . "http://rdaregistry.info/termList/RDATerms/")
    ("rdato" . "http://rdaregistry.info/Elements/t/object/")
    ("rdatr" . "http://rdaregistry.info/termList/typeRec/")
    ("rdau" . "http://rdaregistry.info/Elements/u/")
    ("rdaut" . "http://rdaregistry.info/termList/RDAUnitOfTime/")
    ("rdavf" . "http://rdaregistry.info/termList/videoFormat/")
    ("rdaw" . "http://rdaregistry.info/Elements/w/")
    ("rdawd" . "http://rdaregistry.info/Elements/w/datatype/")
    ("rdawo" . "http://rdaregistry.info/Elements/w/object/")
    ("rdax" . "http://rdaregistry.info/Elements/x/")
    ("rdaxd" . "http://rdaregistry.info/Elements/x/datatype/")
    ("rdaxo" . "http://rdaregistry.info/Elements/x/object/")
    ("rdaz" . "http://rdaregistry.info/Elements/z/")
    ("rdb" . "http://www.dbs.cs.uni-duesseldorf.de/RDF/relational#")
    ("rdf" . "http://www.w3.org/1999/02/22-rdf-syntax-ns#")
    ("rdf123" . "http://rdf123.umbc.edu/ns/")
    ("rdfa" . "http://www.w3.org/ns/rdfa#")
    ("rdfdata" . "http://rdf.data-vocabulary.org/rdf.xml#")
    ("rdfdf" . "http://www.openlinksw.com/virtrdf-data-formats#")
    ("rdfg" . "http://www.w3.org/2004/03/trix/rdfg-1/")
    ("rdfp" . "https://w3id.org/rdfp/")
    ("rdfs" . "http://www.w3.org/2000/01/rdf-schema#")
    ("rdfsharp" . "https://rdfsharp.codeplex.com/")
    ("rdl" . "http://data.posccaesar.org/rdl/")
    ("rdo" . "http://purl.org/rdo/ns#")
    ("rdrel" . "http://rdvocab.info/RDARelationshipsWEMI/")
    ("re" . "http://www.w3.org/2000/10/swap/reason#")
    ("react" . "https://w3id.org/react#")
    ("rec" . "http://purl.org/ontology/rec/core#")
    ("rec54" . "http://www.w3.org/2001/02pd/rec54.rdf#")
    ("recipe" . "http://linkedrecipes.org/schema/")
    ("reco" . "http://purl.org/reco#")
    ("reegle" . "http://reegle.info/schema#")
    ("ref" . "http://purl.org/vocab/relationship/")
    ("refe" . "http://orion.tw.rpi.edu/~xgmatwc/refe/")
    ("refexo" . "http://purl.jp/bio/01/refexo#")
    ("reg" . "http://purl.org/linked-data/registry#")
    ("regorg" . "http://www.w3.org/ns/regorg#")
    ("rei" . "http://www.w3.org/2004/06/rei#")
    ("rel" . "http://purl.org/vocab/relationship/")
    ("relation" . "http://www.iana.org/assignments/relation/")
    ("religion" . "http://rdf.muninn-project.org/ontologies/religion#")
    ("reloc" . "https://w3id.org/reloc#")
    ("remetca" . "http://www.purl.org/net/remetca#")
    ("remus" . "http://www.semanticweb.org/ontologies/2010/6/Ontology1279614123500.owl#")
    ("rep" . "http://www.openrdf.org/config/repository#")
    ("req" . "http://purl.org/req/")
    ("res" . "http://dbpedia.org/resource/")
    ("resex" . "http://resex.rkbexplorer.com/ontologies/resex#")
    ("resist" . "http://www.rkbexplorer.com/ontologies/resist#")
    ("resource" . "http://dbpedia.org/resource/")
    ("respond" . "https://w3id.org/respond#")
    ("rev" . "http://purl.org/stuff/rev#")
    ("reve" . "http://data.eurecom.fr/ontology/reve#")
    ("rfd" . "http://com.intrinsec//ontology#")
    ("rgml" . "http://purl.org/puninj/2001/05/rgml-schema#")
    ("rich" . "http://rdf.data-vocabulary.org/")
    ("rico" . "https://www.ica.org/standards/RiC/ontology#")
    ("rif" . "http://www.w3.org/2007/rif#")
    ("rimmf" . "http://rimmf.com/vocab/")
    ("risk" . "https://www.w3id.org/risk#")
    ("rism" . "http://rism.online/")
    ("rkd" . "http://data.rkd.nl/def#")
    ("rl" . "http://rl.com/resources/")
    ("rlno" . "http://rdflivenews.aksw.org/ontology/")
    ("rlnr" . "http://rdflivenews.aksw.org/resource/")
    ("rlog" . "http://persistence.uni-leipzig.org/nlp2rdf/ontologies/rlog#")
    ("rls" . "https://w3id.org/lovcube/ns/relovstats#")
    ("rm" . "http://jazz.net/ns/rm#")
    ("rml" . "http://w3id.org/rml/")
    ("rmlt" . "http://semweb.mmlab.be/ns/rml-target#")
    ("rmo" . "http://eatld.et.tu-dresden.de/rmo#")
    ("rnce" . "https://data.cultureelerfgoed.nl/id/rnce#")
    ("rnews" . "http://iptc.org/std/rNews/2011-10-07#")
    ("ro" . "http://purl.org/wf4ever/ro#")
    ("roadmap" . "http://mappings.roadmap.org/")
    ("roar" . "https://w3id.org/roar#")
    ("robotarm" . "https://solid.ti.rw.fau.de/public/ns/robotArm#")
    ("roc" . "https://w3id.org/ro/curate#")
    ("roevo" . "http://purl.org/wf4ever/roevo#")
    ("rofch" . "http://rdaregistry.info/termList/rofch/")
    ("rofchrda" . "http://rdaregistry.info/termList/rofchrda/")
    ("rofem" . "http://rdaregistry.info/termList/rofem/")
    ("rofer" . "http://rdaregistry.info/termList/rofer/")
    ("rofet" . "http://rdaregistry.info/termList/rofet/")
    ("roffgrda" . "http://rdaregistry.info/termList/roffgrda/")
    ("rofhf" . "http://rdaregistry.info/termList/rofhf/")
    ("rofid" . "http://rdaregistry.info/termList/rofid/")
    ("rofim" . "http://rdaregistry.info/termList/rofim/")
    ("rofin" . "http://rdaregistry.info/termList/rofin/")
    ("rofit" . "http://rdaregistry.info/termList/rofit/")
    ("rofitrda" . "http://rdaregistry.info/termList/rofitrda/")
    ("rofrm" . "http://rdaregistry.info/termList/rofrm/")
    ("rofrr" . "http://rdaregistry.info/termList/rofrr/")
    ("rofrt" . "http://rdaregistry.info/termList/rofrt/")
    ("rofsf" . "http://rdaregistry.info/termList/rofsf/")
    ("rofsfrda" . "http://rdaregistry.info/termList/rofsfrda/")
    ("rofsm" . "http://rdaregistry.info/termList/rofsm/")
    ("roh" . "http://w3id.org/roh#")
    ("role" . "https://w3id.org/role/")
    ("room" . "http://vocab.deri.ie/rooms#")
    ("rooms" . "http://vocab.deri.ie/rooms#")
    ("roterms" . "http://purl.org/wf4ever/roterms#")
    ("rov" . "http://www.w3.org/ns/regorg#")
    ("rpath" . "https://w3id.org/lodsight/rdf-path#")
    ("rpg" . "http://rpg.data.is4.site/")
    ("rpubl" . "http://rinfo.lagrummet.se/ns/2008/11/rinfo/publ#")
    ("rr" . "http://www.w3.org/ns/r2rml#")
    ("rro" . "http://semanticweb.org/patricia/ontologies/rro#")
    ("rs" . "http://rightsstatements.org/vocab/")
    ("rsa" . "http://www.w3.org/ns/auth/rsa#")
    ("rsctx" . "http://softeng.polito.it/rsctx#")
    ("rso" . "http://www.researchspace.org/ontology/")
    ("rsp" . "http://www.researchspace.org/resource/")
    ("rss" . "http://purl.org/rss/1.0/")
    ("rssynd" . "http://web.resource.org/rss/1.0/modules/syndication/")
    ("rsx" . "http://rdf4j.org/shacl-extensions#")
    ("rtedurp" . "http://purl.org/eduo/rtedurp/")
    ("rto" . "https://w3id.org/rail/topo#")
    ("ru" . "http://purl.org/imbi/ru-meta.owl#")
    ("ruian" . "https://data.cssz.cz/ontology/ruian/")
    ("rulz" . "http://purl.org/NET/rulz#")
    ("rut" . "http://rdfunit.aksw.org/ns/core#")
    ("ruto" . "http://rdfunit.aksw.org/ns/core#")
    ("rv" . "http://wifo-ravensburg.de/semanticweb.rdf#")
    ("rvdata" . "http://data.rvdata.us/")
    ("rvl" . "http://purl.org/rvl/")
    ("rvz" . "http://rdfvizler.dyreriket.xyz/vocabulary/core#")
    ("rxno" . "http://purl.obolibrary.org/obo/ZP_")
    ("s223" . "http://data.ashrae.org/standard223#")
    ("s2s" . "http://escience.rpi.edu/ontology/sesf/s2s/4/0/")
    ("s3db" . "http://www.s3db.org/core#")
    ("s3n" . "http://w3id.org/s3n/")
    ("s4ac" . "http://ns.inria.fr/s4ac/v2#")
    ("s4agri" . "https://saref.etsi.org/saref4agri/")
    ("s4bldg" . "https://w3id.org/def/saref4bldg#")
    ("s4city" . "https://saref.etsi.org/saref4city/")
    ("s4ee" . "https://w3id.org/saref4ee#")
    ("s4ener" . "https://saref.etsi.org/saref4ener/")
    ("s4envi" . "https://w3id.org/def/saref4envi#")
    ("s4syst" . "https://saref.etsi.org/saref4syst/")
    ("sad" . "http://vocab.deri.ie/sad#")
    ("saif" . "http://wwwiti.cs.uni-magdeburg.de/~srahman/")
    ("sail" . "http://www.openrdf.org/config/sail#")
    ("sakthi" . "http://infotech.nitk.ac.in/research-scholars/sakthi-murugan-r/")
    ("salad" . "https://w3id.org/cwl/salad#")
    ("sam" . "http://def.seegrid.csiro.au/isotc211/iso19156/2011/sampling#")
    ("samfl" . "http://def.seegrid.csiro.au/ontology/om/sam-lite#")
    ("samian" . "http://lod.archaeology.link/data/samian/")
    ("san" . "http://www.irit.fr/recherches/MELODI/ontologies/SAN#")
    ("sao" . "http://salt.semanticauthoring.org/ontologies/sao#")
    ("saref" . "https://saref.etsi.org/core/")
    ("saref4envi" . "https://saref.etsi.org/saref4envi/")
    ("saws" . "http://purl.org/saws/ontology#")
    ("sawsdl" . "http://www.w3.org/ns/sawsdl#")
    ("saxon" . "http://saxon.sf.net/")
    ("say" . "http://example.org/say/")
    ("sbench" . "http://swat.cse.lehigh.edu/onto/univ-bench.owl#")
    ("sc" . "http://purl.org/science/owl/sciencecommons/")
    ("scco" . "http://rdf.ebi.ac.uk/terms/surechembl#")
    ("schema" . "http://schema.org/")
    ("scho" . "http://www.scholarlydata.org/ontology/conference-ontology.owl#")
    ("schoi" . "https://w3id.org/scholarlydata/ontology/indicators-ontology.owl#")
    ("scholl" . "http://menemeneml.com/school#")
    ("sci" . "http://data.scientology.org/ns/")
    ("scip" . "http://lod.taxonconcept.org/ontology/sci_people.owl#")
    ("sciprov" . "http://sweetontology.net/reprSciProvenance/")
    ("scms" . "http://ns.aksw.org/scms/annotations/")
    ("sco" . "http://purl.org/ontology/sco#")
    ("scor" . "http://purl.org/eis/vocab/scor#")
    ("scoro" . "http://purl.org/spar/scoro/")
    ("scot" . "http://rdfs.org/scot/ns#")
    ("scovo" . "http://purl.org/NET/scovo#")
    ("scowt" . "http://purl.org/weso/ontologies/scowt#")
    ("scra" . "http://purl.org/net/schemarama#")
    ("scsv" . "http://purl.org/NET/schema-org-csv#")
    ("sct" . "http://snomed.info/id/")
    ("scufl2" . "http://ns.taverna.org.uk/2010/scufl2#")
    ("scv" . "http://purl.org/NET/scovo#")
    ("sd" . "http://www.w3.org/ns/sparql-service-description#")
    ("sdgp" . "http://stats.data-gov.ie/property/")
    ("sdl" . "http://purl.org/vocab/riro/sdl#")
    ("sdm" . "https://w3id.org/okn/o/sdm#")
    ("sdmx" . "http://purl.org/linked-data/sdmx#")
    ("sdmxa" . "http://purl.org/linked-data/sdmx/2009/attribute#")
    ("sdmxc" . "http://purl.org/linked-data/sdmx/2009/concept#")
    ("sdmxcode" . "http://purl.org/linked-data/sdmx/2009/code#")
    ("sdmxd" . "http://purl.org/linked-data/sdmx/2009/dimension#")
    ("sdmxdim" . "http://purl.org/linked-data/sdmx/2009/dimension#")
    ("sdmxm" . "http://purl.org/linked-data/sdmx/2009/measure#")
    ("sdo" . "https://schema.org/")
    ("sds" . "https://w3id.org/sds#")
    ("sdshare" . "http://www.sdshare.org/2012/extension/")
    ("sdt" . "http://statisticaldata.linkedwidgets.org/terms/")
    ("sdterms" . "http://statisticaldata.linkedwidgets.org/terms/")
    ("search" . "http://sindice.com/vocab/search#")
    ("seas" . "https://w3id.org/seas/")
    ("seasd" . "https://w3id.org/seas/")
    ("sec" . "https://w3id.org/security#")
    ("security" . "http://securitytoolbox.appspot.com/securityMain#")
    ("sede" . "http://eventography.org/sede/0.1/")
    ("seeds" . "http://deductions.github.io/seeds.owl.ttl#")
    ("sem" . "http://semanticweb.cs.vu.nl/2009/11/sem/")
    ("semapv" . "https://w3id.org/semapv/vocab/")
    ("semio" . "http://www.lingvoj.org/semio#")
    ("semiot" . "http://w3id.org/semiot/ontologies/semiot#")
    ("semsur" . "http://purl.org/SemSur/")
    ("semtweet" . "http://semantictweet.com/")
    ("sense" . "https://w3id.org/sense#")
    ("seo" . "http://sda.tech/SEOontology/SEO/")
    ("seokoeln" . "http://rankrage.de/")
    ("sep" . "http://purl.obolibrary.org/obo/ZP_")
    ("seq" . "http://www.ontologydesignpatterns.org/cp/owl/sequence.owl#")
    ("service" . "http://purl.org/ontology/service#")
    ("ses" . "http://lod.taxonconcept.org/ses/")
    ("sesame" . "http://www.openrdf.org/schema/sesame#")
    ("session" . "http://redfoot.net/2005/session#")
    ("set" . "http://www.w3.org/2000/10/swap/set#")
    ("setl" . "http://purl.org/twc/vocab/setl/")
    ("sf" . "http://www.opengis.net/ont/sf#")
    ("sfd" . "http://semantic-forms.cc:9112/ldp/")
    ("sfl" . "http://data.finlex.fi/schema/sfl/")
    ("sfn" . "http://semweb.datasciencelab.be/ns/sfn#")
    ("sg" . "http://name.scigraph.com/ontologies/core/")
    ("sgfn" . "http://w3id.org/sparql-generate/fn/")
    ("sgg" . "http://www.springernature.com/scigraph/graphs/")
    ("sgiter" . "http://w3id.org/sparql-generate/iter/")
    ("sgv" . "http://www.w3.org/TR/SVG/")
    ("sh" . "http://www.w3.org/ns/shacl#")
    ("shacl" . "http://www.w3.org/ns/shacl#")
    ("she" . "http://shacleditor.org/")
    ("shema" . "http://schema.org/")
    ("shex" . "http://www.w3.org/ns/shex#")
    ("shoah" . "http://dati.cdec.it/lod/shoah/")
    ("shui" . "https://vocab.eccenca.com/shui/")
    ("shv" . "http://ns.aksw.org/spatialHierarchy/")
    ("shw" . "http://paul.staroch.name/thesis/SmartHomeWeather.owl#")
    ("si" . "http://sisteminformasi.com/")
    ("sibo" . "http://purl.obolibrary.org/obo/ZP_")
    ("sider" . "http://www4.wiwiss.fu-berlin.de/sider/resource/sider/")
    ("sig" . "http://purl.org/signature#")
    ("signify" . "http://purl.org/signify/ns#")
    ("sim" . "http://www.w3id.org/simulation/ontology/")
    ("sindice" . "http://vocab.sindice.net/")
    ("sio" . "http://semanticscience.org/resource/")
    ("sioc" . "http://rdfs.org/sioc/ns#")
    ("sioca" . "http://rdfs.org/sioc/actions#")
    ("siocserv" . "http://rdfs.org/sioc/services#")
    ("sioct" . "http://rdfs.org/sioc/types#")
    ("sioctypes" . "http://rdfs.org/sioc/types#")
    ("sirene" . "https://sireneld.io/vocab/sirene#")
    ("sirext" . "http://t.me/sirextt/247:")
    ("sism" . "http://purl.oclc.org/NET/sism/0.1/")
    ("sit" . "http://www.ontologydesignpatterns.org/cp/owl/situation.owl#")
    ("site" . "http://ns.ontowiki.net/SysOnt/Site/")
    ("situ" . "http://www.ontologydesignpatterns.org/cp/owl/situation.owl#")
    ("skip" . "http://skipforward.net/skipforward/resource/")
    ("skiresort" . "http://www.openlinksw.com/ski_resorts/schema#")
    ("skos" . "http://www.w3.org/2004/02/skos/core#")
    ("skos08" . "http://www.w3.org/2008/05/skos#")
    ("skoslex" . "https://bp4mc2.org/def/skos-lex#")
    ("skosm" . "http://www.w3.org/2004/02/skos/mapping#")
    ("skosno" . "http://data.norge.no/skosno#")
    ("skosthes" . "http://purl.org/iso25964/skos-thes#")
    ("skosxl" . "http://www.w3.org/2008/05/skos-xl#")
    ("sl" . "http://www.semanlink.net/2001/00/semanlink-schema#")
    ("slm" . "http://urn.fi/URN:NBN:fi:au:slm:")
    ("sm" . "http://topbraid.org/sparqlmotion#")
    ("smartapi" . "http://smart-api.io/ontology/1.0/smartapi#")
    ("smf" . "http://topbraid.org/sparqlmotionfunctions#")
    ("smg" . "http://ns.cerise-project.nl/energy/def/cim-smartgrid#")
    ("smiley" . "http://www.smileyontology.com/ns#")
    ("smithy" . "https://awslabs.github.io/smithy/rdf-1.0#")
    ("sml" . "https://w3id.org/sml/def#")
    ("smxm" . "http://smxm.ga/")
    ("snac" . "http://socialarchive.iath.virginia.edu/")
    ("snarm" . "http://rdf.myexperiment.org/ontologies/snarm/")
    ("snomedct" . "http://purl.bioontology.org/ontology/SNOMEDCT/")
    ("so" . "http://schema.org/")
    ("soa" . "https://semopenalex.org/ontology/")
    ("soall" . "http://sweetontology.net/sweetAll/")
    ("soap" . "http://www.w3.org/2003/05/soap-envelope/")
    ("soc" . "http://purl.org/net/hdlipcores/ontology/soc#")
    ("soch" . "http://kulturarvsdata.se/ksamsok#")
    ("soft" . "http://www.w3.org/2007/uwa/context/software.owl#")
    ("sohu" . "http://sweetontology.net/human/")
    ("sohua" . "http://sweetontology.net/humanAgriculture/")
    ("sohuc" . "http://sweetontology.net/humanCommerce/")
    ("sohud" . "http://sweetontology.net/humanDecision/")
    ("sohuea" . "http://sweetontology.net/humanEnvirAssessment/")
    ("sohueccont" . "http://sweetontology.net/humanEnvirControl/")
    ("sohuecons" . "http://sweetontology.net/humanEnvirConservation/")
    ("sohues" . "http://sweetontology.net/humanEnvirStandards/")
    ("sohuj" . "http://sweetontology.net/humanJurisdiction/")
    ("sohukd" . "http://sweetontology.net/humanKnowledgeDomain/")
    ("sohur" . "http://sweetontology.net/humanResearch/")
    ("sohut" . "http://sweetontology.net/humanTransportation/")
    ("sohutr" . "http://sweetontology.net/humanTechReadiness/")
    ("solid" . "http://www.w3.org/ns/solid/terms#")
    ("soma" . "http://sweetontology.net/matr/")
    ("somaae" . "http://sweetontology.net/matrAerosol/")
    ("somab" . "http://sweetontology.net/matrBiomass/")
    ("somac" . "http://sweetontology.net/matrCompound/")
    ("somael" . "http://sweetontology.net/matrElement/")
    ("somaem" . "http://sweetontology.net/matrElementalMolecule/")
    ("somaen" . "http://sweetontology.net/matrEnergy/")
    ("somaeq" . "http://sweetontology.net/matrEquipment/")
    ("somaf" . "http://sweetontology.net/matrFacility/")
    ("somaind" . "http://sweetontology.net/matrIndustrial/")
    ("somains" . "http://sweetontology.net/matrInstrument/")
    ("somaio" . "http://sweetontology.net/matrIon/")
    ("somais" . "http://sweetontology.net/matrIsotope/")
    ("somamic" . "http://sweetontology.net/matrMicrobiota/")
    ("somamin" . "http://sweetontology.net/matrMineral/")
    ("soman" . "http://sweetontology.net/matrAnimal/")
    ("somanr" . "http://sweetontology.net/matrNaturalResource/")
    ("somaoc" . "http://sweetontology.net/matrOrganicCompound/")
    ("somapa" . "http://sweetontology.net/matrParticle/")
    ("somapl" . "http://sweetontology.net/matrPlant/")
    ("somarock" . "http://sweetontology.net/matrRock/")
    ("somarocki" . "http://sweetontology.net/matrRockIgneous/")
    ("somas" . "http://sweetontology.net/matrSediment/")
    ("somaw" . "http://sweetontology.net/matrWater/")
    ("soph" . "http://sweetontology.net/phen/")
    ("sophatmo" . "http://sweetontology.net/phenAtmo/")
    ("sophatmoc" . "http://sweetontology.net/phenAtmoCloud/")
    ("sophatmofo" . "http://sweetontology.net/phenAtmoFog/")
    ("sophatmofr" . "http://sweetontology.net/phenAtmoFront/")
    ("sophatmol" . "http://sweetontology.net/phenAtmoLightning/")
    ("sophatmopc" . "http://sweetontology.net/phenAtmoPrecipitation/")
    ("sophatmops" . "http://sweetontology.net/phenAtmoPressure/")
    ("sophatmos" . "http://sweetontology.net/phenAtmoSky/")
    ("sophatmot" . "http://sweetontology.net/phenAtmoTransport/")
    ("sophatmow" . "http://sweetontology.net/phenAtmoWind/")
    ("sophatmowm" . "https://sweetontology.net/phenAtmoWindMesoscale/")
    ("sophb" . "http://sweetontology.net/phenBiol/")
    ("sophcm" . "http://sweetontology.net/phenCycleMaterial/")
    ("sophcr" . "http://sweetontology.net/phenCryo/")
    ("sophcy" . "http://sweetontology.net/phenCycle/")
    ("sophec" . "http://sweetontology.net/phenEcology/")
    ("sophei" . "http://sweetontology.net/phenEnvirImpact/")
    ("sophel" . "http://sweetontology.net/phenElecMag/")
    ("sophen" . "http://sweetontology.net/phenEnergy/")
    ("sophfd" . "http://sweetontology.net/phenFluidDynamics/")
    ("sophfi" . "http://sweetontology.net/phenFluidInstability/")
    ("sophft" . "http://sweetontology.net/phenFluidTransport/")
    ("sophg" . "http://sweetontology.net/phenGeol/")
    ("sophgf" . "http://sweetontology.net/phenGeolFault/")
    ("sophgg" . "http://sweetontology.net/phenGeolGeomorphology/")
    ("sophgs" . "http://sweetontology.net/phenGeolSeismicity/")
    ("sophgt" . "http://sweetontology.net/phenGeolTectonic/")
    ("sophgv" . "http://sweetontology.net/phenGeolVolcano/")
    ("sophhe" . "http://sweetontology.net/phenHelio/")
    ("sophhy" . "http://sweetontology.net/phenHydro/")
    ("sophm" . "http://sweetontology.net/phenMixing/")
    ("sopho" . "http://sweetontology.net/phenOcean/")
    ("sophoc" . "http://sweetontology.net/phenOceanCoastal/")
    ("sophod" . "http://sweetontology.net/phenOceanDynamics/")
    ("sophpc" . "http://sweetontology.net/phenPlanetClimate/")
    ("sophr" . "http://sweetontology.net/phenReaction/")
    ("sophso" . "http://sweetontology.net/phenSolid/")
    ("sophst" . "http://sweetontology.net/phenStar/")
    ("sophsy" . "http://sweetontology.net/phenSystem/")
    ("sophsyc" . "http://sweetontology.net/phenSystemComplexity/")
    ("sophw" . "http://sweetontology.net/phenWave/")
    ("sophwn" . "http://sweetontology.net/phenWaveNoise/")
    ("soproc" . "http://sweetontology.net/proc/")
    ("soprocc" . "http://sweetontology.net/procChemical/")
    ("soprocp" . "http://sweetontology.net/procPhysical/")
    ("soprocsc" . "http://sweetontology.net/procStateChange/")
    ("soprocw" . "http://sweetontology.net/procWave/")
    ("soprop" . "http://sweetontology.net/prop/")
    ("sopropb" . "http://sweetontology.net/propBinary/")
    ("sopropcap" . "http://sweetontology.net/propCapacity/")
    ("sopropcat" . "http://sweetontology.net/propCategorical/")
    ("sopropcha" . "http://sweetontology.net/propCharge/")
    ("sopropche" . "http://sweetontology.net/propChemical/")
    ("sopropcon" . "http://sweetontology.net/propConductivity/")
    ("sopropcou" . "http://sweetontology.net/propCount/")
    ("sopropdife" . "http://sweetontology.net/propDifference/")
    ("sopropdifu" . "http://sweetontology.net/propDiffusivity/")
    ("sopropdr" . "http://sweetontology.net/propDimensionlessRatio/")
    ("soprope" . "http://sweetontology.net/propEnergy/")
    ("sopropef" . "http://sweetontology.net/propEnergyFlux/")
    ("sopropfr" . "http://sweetontology.net/propFraction/")
    ("sopropfu" . "http://sweetontology.net/propFunction/")
    ("sopropi" . "http://sweetontology.net/propIndex/")
    ("sopropm" . "http://sweetontology.net/propMass/")
    ("sopropmf" . "http://sweetontology.net/propMassFlux/")
    ("sopropo" . "http://sweetontology.net/propOrdinal/")
    ("sopropp" . "http://sweetontology.net/propPressure/")
    ("sopropq" . "http://sweetontology.net/propQuantity/")
    ("sopropr" . "http://sweetontology.net/propRotation/")
    ("soprops" . "http://sweetontology.net/propSpace/")
    ("sopropsdir" . "http://sweetontology.net/propSpaceDirection/")
    ("sopropsdis" . "http://sweetontology.net/propSpaceDistance/")
    ("sopropsh" . "http://sweetontology.net/propSpaceHeight/")
    ("sopropsl" . "http://sweetontology.net/propSpaceLocation/")
    ("sopropsm" . "http://sweetontology.net/propSpaceMultidimensional/")
    ("sopropsp" . "http://sweetontology.net/propSpeed/")
    ("sopropst" . "http://sweetontology.net/propSpaceThickness/")
    ("sopropt" . "http://sweetontology.net/propTemperature/")
    ("soproptf" . "http://sweetontology.net/propTimeFrequency/")
    ("soproptg" . "http://sweetontology.net/propTemperatureGradient/")
    ("sopropti" . "http://sweetontology.net/propTime/")
    ("sor" . "http://purl.org/net/soron/")
    ("sorea" . "http://sweetontology.net/realm/")
    ("soreaa" . "http://sweetontology.net/realmAtmo/")
    ("soreaab" . "http://sweetontology.net/realmAstroBody/")
    ("soreaabl" . "http://sweetontology.net/realmAtmoBoundaryLayer/")
    ("soreaah" . "http://sweetontology.net/realmAstroHelio/")
    ("soreaas" . "http://sweetontology.net/realmAstroStar/")
    ("soreaaw" . "http://sweetontology.net/realmAtmoWeather/")
    ("soreabb" . "http://sweetontology.net/realmBiolBiome/")
    ("soreac" . "http://sweetontology.net/realmCryo/")
    ("soreacz" . "http://sweetontology.net/realmClimateZone/")
    ("soreaer" . "http://sweetontology.net/realmEarthReference/")
    ("soreahb" . "http://sweetontology.net/realmHydroBody/")
    ("soreal" . "http://sweetontology.net/realmLandform/")
    ("soreala" . "http://sweetontology.net/realmLandAeolian/")
    ("sorealc" . "http://sweetontology.net/realmLandCoastal/")
    ("sorealf" . "http://sweetontology.net/realmLandFluvial/")
    ("sorealg" . "http://sweetontology.net/realmLandGlacial/")
    ("sorealo" . "http://sweetontology.net/realmLandOrographic/")
    ("sorealp" . "http://sweetontology.net/realmLandProtected/")
    ("sorealt" . "http://sweetontology.net/realmLandTectonic/")
    ("sorealv" . "http://sweetontology.net/realmLandVolcanic/")
    ("soreao" . "http://sweetontology.net/realmOcean/")
    ("soreaofe" . "http://sweetontology.net/realmOceanFeature/")
    ("soreaofl" . "http://sweetontology.net/realmOceanFloor/")
    ("sorear" . "http://sweetontology.net/realmRegion/")
    ("soreas" . "http://sweetontology.net/realmSoil/")
    ("sorel" . "http://sweetontology.net/rela/")
    ("sorelch" . "http://sweetontology.net/relaChemical/")
    ("sorelcl" . "http://sweetontology.net/relaClimate/")
    ("sorelh" . "http://sweetontology.net/relaHuman/")
    ("sorelm" . "http://sweetontology.net/relaMath/")
    ("sorelph" . "http://sweetontology.net/relaPhysical/")
    ("sorelpr" . "http://sweetontology.net/relaProvenance/")
    ("sorelsc" . "http://sweetontology.net/relaSci/")
    ("sorelsp" . "http://sweetontology.net/relaSpace/")
    ("sorelt" . "http://sweetontology.net/relaTime/")
    ("sorep" . "http://sweetontology.net/repr/")
    ("sorepdf" . "http://sweetontology.net/reprDataFormat/")
    ("sorepdm" . "http://sweetontology.net/reprDataModel/")
    ("sorepdp" . "http://sweetontology.net/reprDataProduct/")
    ("sorepds" . "http://sweetontology.net/reprDataService/")
    ("sorepdsa" . "http://sweetontology.net/reprDataServiceAnalysis/")
    ("sorepdsg" . "http://sweetontology.net/reprDataServiceGeospatial/")
    ("sorepdsr" . "http://sweetontology.net/reprDataServiceReduction/")
    ("sorepdsv" . "http://sweetontology.net/reprDataServiceValidation/")
    ("sorepm" . "http://sweetontology.net/reprMath/")
    ("sorepmf" . "http://sweetontology.net/reprMathFunction/")
    ("sorepmfo" . "http://sweetontology.net/reprMathFunctionOrthogonal/")
    ("sorepmg" . "http://sweetontology.net/reprMathGraph/")
    ("sorepmo" . "http://sweetontology.net/reprMathOperation/")
    ("sorepmso" . "http://sweetontology.net/reprMathSolution/")
    ("sorepmst" . "http://sweetontology.net/reprMathStatistics/")
    ("soreps" . "http://sweetontology.net/reprSpace/")
    ("sorepsc" . "http://sweetontology.net/reprSciComponent/")
    ("sorepscd" . "http://sweetontology.net/reprSpaceCoordinate/")
    ("sorepsd" . "http://sweetontology.net/reprSpaceDirection/")
    ("sorepsf" . "http://sweetontology.net/reprSciFunction/")
    ("sorepsg3" . "http://sweetontology.net/reprSpaceGeometry3D/")
    ("sorepsl" . "http://sweetontology.net/reprSciLaw/")
    ("sorepsme" . "http://sweetontology.net/reprSciMethodology/")
    ("sorepsmo" . "http://sweetontology.net/reprSciModel/")
    ("sorepsp" . "http://sweetontology.net/reprSciProvenance/")
    ("sorepsrs" . "http://sweetontology.net/reprSpaceReferenceSystem/")
    ("sorepsu" . "http://sweetontology.net/reprSciUnits/")
    ("sorept" . "http://sweetontology.net/reprTime/")
    ("soreptd" . "http://sweetontology.net/reprTimeDay/")
    ("sorepts" . "http://sweetontology.net/reprTimeSeason/")
    ("sorg" . "http://schema.org/")
    ("sosa" . "http://www.w3.org/ns/sosa/")
    ("sost" . "http://sweetontology.net/state/")
    ("sostb" . "http://sweetontology.net/stateBiological/")
    ("sostc" . "http://sweetontology.net/stateChemical/")
    ("sostdp" . "http://sweetontology.net/stateDataProcessing/")
    ("sostef" . "http://sweetontology.net/stateEnergyFlux/")
    ("sostf" . "http://sweetontology.net/stateFluid/")
    ("sosto" . "http://sweetontology.net/stateOrdinal/")
    ("sostp" . "http://sweetontology.net/statePhysical/")
    ("sostrb" . "http://sweetontology.net/stateRoleBiological/")
    ("sostrc" . "http://sweetontology.net/stateRoleChemical/")
    ("sostre" . "http://sweetontology.net/stateRealm/")
    ("sostrg" . "http://sweetontology.net/stateRoleGeographic/")
    ("sostri" . "http://sweetontology.net/stateRoleImpact/")
    ("sostro" . "http://sweetontology.net/stateRole/")
    ("sostrr" . "http://sweetontology.net/stateRoleRepresentative/")
    ("sostrt" . "http://sweetontology.net/stateRoleTrust/")
    ("sostsb" . "http://sweetontology.net/stateSpectralBand/")
    ("sostsc" . "http://sweetontology.net/stateSpaceConfiguration/")
    ("sostsl" . "http://sweetontology.net/stateSpectralLine/")
    ("sostso" . "http://sweetontology.net/stateSolid/")
    ("sostsp" . "http://sweetontology.net/stateSpace/")
    ("sostss" . "http://sweetontology.net/stateSpaceScale/")
    ("sostst" . "http://sweetontology.net/stateStorm/")
    ("sostsy" . "http://sweetontology.net/stateSystem/")
    ("sosttc" . "http://sweetontology.net/stateTimeCycle/")
    ("sosttf" . "http://sweetontology.net/stateTimeFrequency/")
    ("sosttg" . "http://sweetontology.net/stateTimeGeologic/")
    ("sostth" . "http://sweetontology.net/stateThermodynamic/")
    ("sostti" . "http://sweetontology.net/stateTime/")
    ("sostv" . "http://sweetontology.net/stateVisibility/")
    ("sou" . "http://qudt.org/vocab/sou/")
    ("sp" . "http://spinrdf.org/sp#")
    ("spa" . "https://paul.ti.rw.fau.de/~jo00defe/voc/spa#")
    ("space" . "http://purl.org/net/schemas/space/")
    ("spacerel" . "http://data.ordnancesurvey.co.uk/ontology/spatialrelations/")
    ("span" . "http://www.ifomis.org/bfo/1.1/span#")
    ("sparql" . "http://www.w3.org/ns/sparql#")
    ("spatial" . "http://geovocab.org/spatial#")
    ("spatialf" . "http://jena.apache.org/function/spatial#")
    ("spc" . "http://purl.org/ontomedia/core/space#")
    ("spcm" . "http://spi-fm.uca.es/spdef/models/deployment/spcm/1.0#")
    ("spdx" . "http://spdx.org/rdf/terms#")
    ("spec" . "http://www.w3.org/ns/spec#")
    ("spfood" . "http://kmi.open.ac.uk/projects/smartproducts/ontologies/food.owl#")
    ("spif" . "http://spinrdf.org/spif#")
    ("spin" . "http://spinrdf.org/spin#")
    ("spl" . "http://spinrdf.org/spl#")
    ("spo" . "https://w3id.org/steel/ProcessOntology/")
    ("sport" . "http://purl.org/ontology/sport/")
    ("spt" . "http://spitfire-project.eu/ontology/ns/")
    ("spv" . "http://completeness.inf.unibz.it/sp-vocab#")
    ("spvqa" . "https://bmake.th-brandenburg.de/spv#")
    ("sql" . "http://ns.inria.fr/ast/sql#")
    ("sr" . "http://www.openrdf.org/config/repository/sail#")
    ("sri" . "https://w3id.org/sri#")
    ("srmo" . "https://w3id.org/srmo#")
    ("sro" . "http://salt.semanticauthoring.org/ontologies/sro#")
    ("srr" . "https://w3id.org/srr#")
    ("srt" . "http://w3id.org/srt#")
    ("srtun" . "https://www.inf.bi.rub.de/srtun#")
    ("sru" . "http://www.loc.gov/zing/srw/")
    ("srv" . "http://www.daml.org/services/owl-s/1.2/Service.owl#")
    ("srx" . "http://www.w3.org/2005/sparql-results#")
    ("ssn" . "http://www.w3.org/ns/ssn/")
    ("ssno" . "http://www.w3.org/ns/ssn/")
    ("ssnx" . "http://purl.oclc.org/NET/ssnx/ssn#")
    ("sso" . "http://nlp2rdf.lod2.eu/schema/sso/")
    ("ssso" . "http://purl.org/ontology/ssso#")
    ("sssom" . "https://w3id.org/sssom/")
    ("st" . "http://ns.inria.fr/sparql-template/")
    ("stac" . "http://securitytoolbox.appspot.com/stac#")
    ("stanford" . "http://purl.org/olia/stanford.owl#")
    ("stat" . "http://www.w3.org/ns/posix/stat#")
    ("states" . "http://www.w3.org/2005/07/aaa#")
    ("static" . "http://vocab-ld.org/vocab/static-ld#")
    ("stats" . "http://purl.org/rdfstats/stats#")
    ("status" . "http://www.w3.org/2003/06/sw-vocab-status/ns#")
    ("stax" . "https://w3id.org/stax/ontology#")
    ("steel" . "https://w3id.org/steel/ProcessOntology/")
    ("stencila" . "http://schema.stenci.la/")
    ("step" . "http://purl.org/net/step#")
    ("stirdata" . "https://w3id.org/stirdata/vocabulary/")
    ("stix" . "http://purl.org/cyber/stix#")
    ("sto" . "https://w3id.org/i40/sto#")
    ("stories" . "http://purl.org/ontology/stories/")
    ("str" . "http://nlp2rdf.lod2.eu/schema/string/")
    ("strdf" . "http://strdf.di.uoa.gr/ontology#")
    ("stream" . "http://dbpedia.org/ontology/Stream/")
    ("string" . "http://www.w3.org/2000/10/swap/string#")
    ("studiop" . "http://purl.org/resource/pilatesstudio/")
    ("stx" . "http://purl.org/cyber/stix#")
    ("sty" . "http://purl.bioontology.org/ontology/STY/")
    ("summa" . "http://purl.org/voc/summa/")
    ("sure" . "http://ns.inria.fr/sure#")
    ("sv" . "http://schemas.talis.com/2005/service/schema#")
    ("svcs" . "http://rdfs.org/sioc/services#")
    ("sw" . "http://linkedwidgets.org/statisticalwidget/ontology/")
    ("swa" . "http://topbraid.org/swa#")
    ("swanag" . "http://purl.org/swan/1.2/agents/")
    ("swanci" . "http://purl.org/swan/1.2/citations/")
    ("swanco" . "http://purl.org/swan/1.2/swan-commons/")
    ("swande" . "http://purl.org/swan/1.2/discourse-elements/")
    ("swandr" . "http://purl.org/swan/1.2/discourse-relationships/")
    ("swanpav" . "http://purl.org/swan/1.2/pav/")
    ("swanq" . "http://purl.org/swan/1.2/qualifiers/")
    ("swanqs" . "http://purl.org/swan/1.2/qualifiers/")
    ("swc" . "http://data.semanticweb.org/ns/swc/ontology#")
    ("swcomp" . "https://github.com/ali1k/ld-reactor/blob/master/vocabulary/index.ttl#")
    ("sweet" . "http://sweetontology.net/")
    ("swh" . "http://plugin.org.uk/swh-plugins/")
    ("swid" . "http://semanticweb.org/id/")
    ("swivt" . "http://semantic-mediawiki.org/swivt/1.0#")
    ("swo" . "http://www.ebi.ac.uk/swo/")
    ("swp" . "http://www.w3.org/2004/03/trix/swp-2/")
    ("swpatho" . "http://swpatho.ag-nbi.de/context/meta.owl#")
    ("swperson" . "http://data.semanticweb.org/person/")
    ("swpm" . "http://spi-fm.uca.es/spdef/models/deployment/swpm/1.0#")
    ("swpo" . "http://sw-portal.deri.org/ontologies/swportal#")
    ("swrc" . "http://swrc.ontoware.org/ontology#")
    ("swrc2" . "https://www.cs.vu.nl/~mcaklein/onto/swrc_ext/2005/05#")
    ("swrcfe" . "http://www.morelab.deusto.es/ontologies/swrcfe#")
    ("swrl" . "http://www.w3.org/2003/11/swrl#")
    ("swrlb" . "http://www.w3.org/2003/11/swrlb#")
    ("sx" . "http://shex.io/ns/shex#")
    ("sylld" . "http://www.semanticweb.org/syllabus/data/")
    ("sysont" . "http://ns.ontowiki.net/SysOnt/")
    ("system" . "http://www.univalle.edu.co/ontologies/System#")
    ("tac" . "http://ns.bergnet.org/tac/0.1/triple-access-control#")
    ("tadirah" . "http://tadirah.dariah.eu/vocab/")
    ("tag" . "http://www.holygoat.co.uk/owl/redwood/0.1/tags/")
    ("tags" . "http://www.holygoat.co.uk/owl/redwood/0.1/tags/")
    ("tao" . "http://pubannotation.org/ontology/tao.owl#")
    ("tarot" . "http://data.totl.net/tarot/card/")
    ("tarql" . "http://tarql.github.io/tarql#")
    ("task" . "http://deductions.github.io/task-management.owl.ttl#")
    ("tavprov" . "http://ns.taverna.org.uk/2012/tavernaprov/")
    ("taxo" . "http://purl.org/rss/1.0/modules/taxonomy/")
    ("taxon" . "http://purl.org/biodiversity/taxon/")
    ("taxref" . "http://taxref.mnhn.fr/lod/taxon/")
    ("taxrefprop" . "http://taxref.mnhn.fr/lod/property/")
    ("tb" . "https://w3id.org/timebank#")
    ("tblcard" . "http://www.w3.org/People/Berners-Lee/card#")
    ("tcga" . "http://purl.org/tcga/core#")
    ("tci" . "https://w3id.org/lbs/tci#")
    ("td" . "https://www.w3.org/2019/wot/td#")
    ("td5" . "http://td5.org/#")
    ("tdb" . "http://jena.hpl.hp.com/2008/tdb#")
    ("tddo" . "http://databugger.aksw.org/ns/core#")
    ("tdm" . "http://www.w3.org/ns/tdmrep#")
    ("te" . "http://www.w3.org/2006/time-entry#")
    ("teach" . "http://linkedscience.org/teach/ns#")
    ("teamwork" . "http://topbraid.org/teamwork#")
    ("tei" . "http://www.tei-c.org/ns/1.0/")
    ("telix" . "http://purl.org/telix#")
    ("telmap" . "http://purl.org/telmap/")
    ("tempo" . "http://purl.org/tempo/")
    ("terms" . "http://purl.org/dc/terms/")
    ("tern" . "http://w3id.org/tern/ontologies/tern/")
    ("test" . "https://test4.example.com/")
    ("test2" . "http://this.invalid/test2#")
    ("text" . "http://jena.apache.org/text#")
    ("textgrid" . "https://textgridrep.org/")
    ("tg" . "https://triplydb.com/Triply/tg/def/")
    ("tgm" . "http://id.loc.gov/vocabulary/graphicMaterials/")
    ("tgn" . "http://vocab.getty.edu/tgn/")
    ("theatre" . "http://purl.org/theatre#")
    ("theme" . "http://voc.odw.tw/theme/")
    ("thors" . "http://resource.geosciml.org/ontology/timescale/thors#")
    ("threat" . "https://cve.mitre.org/")
    ("thub" . "http://vocabularis.crai.ub.edu/thub/")
    ("ti" . "http://www.ontologydesignpatterns.org/cp/owl/timeinterval.owl#")
    ("tikag" . "https://www.tikag.com/")
    ("time" . "http://www.w3.org/2006/time#")
    ("timeline" . "http://purl.org/NET/c4dm/timeline.owl#")
    ("timex" . "http://data.wu.ac.at/ns/timex#")
    ("tio" . "http://purl.org/tio/ns#")
    ("tis" . "http://www.ontologydesignpatterns.org/cp/owl/timeindexedsituation.owl#")
    ("tisc" . "http://observedchange.com/tisc/ns#")
    ("tissue" . "http://www.univalle.edu.co/ontologies/Tissue#")
    ("tix" . "http://toptix.com/2010/esro/")
    ("tl" . "http://purl.org/NET/c4dm/timeline.owl#")
    ("tm" . "http://def.seegrid.csiro.au/isotc211/iso19108/2002/temporal#")
    ("tmo" . "http://www.semanticdesktop.org/ontologies/2008/05/20/tmo#")
    ("tmpl" . "http://purl.org/restdesc/http-template#")
    ("toaru" . "https://metadata.moe/toaru-sparql/elements/")
    ("toby" . "http://tobyinkster.co.uk/#")
    ("topo" . "http://data.ign.fr/def/topo#")
    ("tosh" . "http://topbraid.org/tosh#")
    ("tp" . "https://triplydb.com/Triply/tp/def/")
    ("tr" . "http://www.thomsonreuters.com/")
    ("trackback" . "http://madskills.com/public/xml/rss/module/trackback/")
    ("traffic" . "http://www.sensormeasurement.appspot.com/ont/transport/traffic#")
    ("trait" . "http://contextus.net/ontology/ontomedia/ext/common/trait#")
    ("trak" . "https://trakmetamodel.sourceforge.io/vocab/rdf-schema.rdf#")
    ("transit" . "http://vocab.org/transit/terms/")
    ("transmed" . "http://www.w3.org/2001/sw/hcls/ns/transmed/")
    ("trao" . "http://linkeddata.finki.ukim.mk/lod/ontology/tao#")
    ("travel" . "http://www.co-ode.org/roberts/travel.owl#")
    ("tree" . "https://w3id.org/tree#")
    ("trek" . "https://w3id.org/trek/")
    ("trig" . "http://www.w3.org/2004/03/trix/rdfg-1/")
    ("tripfs" . "http://purl.org/tripfs/2010/02#")
    ("tripfs2" . "http://purl.org/tripfs/2010/06#")
    ("tro" . "https://w3id.org/TRO/")
    ("tsdc" . "https://w3id.org/oseg/ont/tsdc/core#")
    ("tsdcreq" . "https://w3id.org/oseg/ont/tsdc/req#")
    ("tsioc" . "http://rdfs.org/sioc/types#")
    ("tsn" . "http://purl.org/net/tsn#")
    ("tsnchange" . "http://purl.org/net/tsnchange#")
    ("tso" . "https://w3id.org/tso#")
    ("tsso" . "https://scch.org/technical_standards#")
    ("ttl" . "http://www.w3.org/2008/turtle#")
    ("ttla" . "https://w3id.org/ttla/")
    ("ttp" . "http://eample.com/test#")
    ("ttrpg" . "https://w3id.org/TTRpg#")
    ("tui" . "http://data.ifs.tuwien.ac.at/study/resource/")
    ("turismo" . "http://idi.fundacionctic.org/cruzar/turismo#")
    ("tvc" . "http://www.essepuntato.it/2012/04/tvc/")
    ("tw" . "http://tw.rpi.edu/schema/")
    ("twaapi" . "http://purl.org/twc/vocab/aapi-schema#")
    ("twitter" . "http://stocktwits.com/")
    ("tx" . "http://swtmp.gitlab.io/vocabulary/templates.owl#")
    ("txn" . "http://lod.taxonconcept.org/ontology/txn.owl#")
    ("txpo" . "http://purl.obolibrary.org/obo/ZP_")
    ("type" . "https://webiomed.ai/blog/obzor-rossiiskikh-sistem-podderzhki-priniatiia-vrachebnykh-reshenii/")
    ("tzont" . "http://www.w3.org/2006/timezone#")
    ("ub" . "http://www.lehigh.edu/~zhp2/2004/0401/univ-bench.owl#")
    ("uberon" . "http://purl.obolibrary.org/obo/UBERON_")
    ("ubiq" . "http://server.ubiqore.com/ubiq/core#")
    ("uby" . "http://purl.org/olia/ubyCat.owl#")
    ("uc" . "http://ucuenca.edu.ec/ontology#")
    ("uco" . "http://purl.org/uco/ns#")
    ("ucum" . "http://purl.oclc.org/NET/muo/ucum/")
    ("ufmedia" . "http://purl.org/microformat/hmedia/")
    ("ufo" . "http://ufo.com/#")
    ("ui" . "http://www.w3.org/ns/ui#")
    ("uimo" . "http://vocab.sti2.at/uimo/")
    ("uio" . "https://www.mitre.org/mparmelee/ontologies/2023/6/UserIntentOntology/")
    ("uiot" . "http://www.w3id.org/urban-iot/core#")
    ("uis" . "http://uis.270a.info/dataset/")
    ("ul" . "http://underlay.mit.edu/ns/")
    ("ulan" . "http://vocab.getty.edu/ulan/")
    ("ultragaz" . "https://ultragaz24horas.com/")
    ("um" . "http://intelleo.eu/ontologies/user-model/ns/")
    ("umbel" . "http://umbel.org/umbel#")
    ("umbelrc" . "http://umbel.org/umbel/rc/")
    ("umls" . "http://bioportal.bioontology.org/ontologies/umls/")
    ("un" . "http://www.w3.org/2007/ont/unit#")
    ("undata" . "http://citydata.wu.ac.at/Linked-UNData/data/")
    ("uneskos" . "http://purl.org/voc/uneskos#")
    ("uni" . "http://purl.org/weso/uni/uni.html#")
    ("uniprot" . "http://purl.uniprot.org/uniprot/")
    ("unit" . "http://qudt.org/vocab/unit/")
    ("units" . "http://eulersharp.sourceforge.net/2003/03swap/units#")
    ("univ" . "http://univ.io/")
    ("unspsc" . "http://ontoview.org/schema/unspsc/1#")
    ("uom" . "http://www.opengis.net/def/uom/OGC/1.0/")
    ("up" . "http://purl.uniprot.org/core/")
    ("uri" . "http://purl.org/NET/uri#")
    ("uri4uri" . "http://uri4uri.net/vocab#")
    ("url" . "http://schema.org/")
    ("urn" . "http://fliqz.com/")
    ("user" . "http://schemas.talis.com/2005/user/schema#")
    ("usgov" . "http://www.rdfabout.com/rdf/schema/usgovt/")
    ("uta" . "http://uptheasset.org/ontology#")
    ("va" . "http://code-research.eu/ontology/visual-analytics#")
    ("vacseen1" . "http://www.semanticweb.org/parthasb/ontologies/2014/6/vacseen1/")
    ("vaem" . "http://www.linkedmodel.org/schema/vaem#")
    ("vag" . "http://www.essepuntato.it/2013/10/vagueness/")
    ("value" . "http://gfgfd.vs/")
    ("valueflows" . "https://w3id.org/valueflows/")
    ("vam" . "http://www.metmuseum.org/")
    ("vann" . "http://purl.org/vocab/vann/")
    ("vapour" . "http://vapour.sourceforge.net/vocab.rdf#")
    ("vartrans" . "http://www.w3.org/ns/lemon/vartrans#")
    ("vcard" . "http://www.w3.org/2006/vcard/ns#")
    ("vcard2006" . "http://www.w3.org/2006/vcard/ns#")
    ("vcardx" . "http://buzzword.org.uk/rdf/vcardx#")
    ("vcs" . "https://data.vlaanderen.be/ns/chemische_stof#")
    ("vdpp" . "http://data.lirmm.fr/ontologies/vdpp#")
    ("veelana" . "http://onlyfans.com/veelana/")
    ("vehma" . "http://deductions.github.io/vehicule-management.owl.ttl#")
    ("vehman" . "http://deductions.github.io/vehicule-management.owl.ttl#")
    ("veo" . "http://linkeddata.finki.ukim.mk/lod/ontology/veo#")
    ("ver" . "https://w3id.org/version/ontology#")
    ("verb" . "https://w3id.org/verb/")
    ("version" . "https://version.link/")
    ("vext" . "http://ldf.fi/void-ext#")
    ("vf" . "https://w3id.org/valueflows/ont/vf#")
    ("vgo" . "http://purl.org/net/VideoGameOntology#")
    ("vhbieo" . "https://w3id.org/vhbieo#")
    ("viaf" . "http://viaf.org/viaf/")
    ("video" . "http://purl.org/ontology/video#")
    ("videogame" . "http://purl.org/net/vgo#")
    ("vidont" . "http://vidont.org/")
    ("vin" . "http://www.w3.org/TR/2003/PR-owl-guide-20031209/wine#")
    ("vir" . "http://w3id.org/vir#")
    ("visit" . "http://purl.org/net/vocab/2004/07/visit#")
    ("visko" . "http://trust.utep.edu/visko/ontology/visko-operator-v3.owl#")
    ("viskoo" . "http://trust.utep.edu/visko/ontology/visko-operator-v3.owl#")
    ("viskov" . "http://trust.utep.edu/visko/ontology/visko-view-v3.owl#")
    ("viso" . "http://purl.org/viso/")
    ("vitro" . "http://vitro.mannlib.cornell.edu/ns/vitro/public#")
    ("vivo" . "http://vivoweb.org/ontology/core#")
    ("vl" . "https://version.link/")
    ("vlueprint" . "https://vlueprint.org/schema/")
    ("vmm" . "http://spi-fm.uca.es/spdef/models/genericTools/vmm/1.0#")
    ("vntourism" . "http://www.semanticweb.org/minhn/ontologies/2021/0/vntourism#")
    ("voaf" . "http://purl.org/vocommons/voaf#")
    ("voag" . "http://voag.linkedmodel.org/schema/voag#")
    ("voc" . "http://voc.odw.tw/")
    ("vocab" . "http://rdf.ontology2.com/vocab#")
    ("vocals" . "http://w3id.org/rsp/vocals#")
    ("vocnet" . "http://schema.vocnet.org/")
    ("vogd" . "http://ogd.ifs.tuwien.ac.at/vienna/geo/")
    ("void" . "http://rdfs.org/ns/void#")
    ("voidex" . "http://www.swi-prolog.org/rdf/library/")
    ("voidext" . "http://rdfs.org/ns/void-ext#")
    ("voidp" . "http://www.enakting.org/provenance/voidp/")
    ("voidwh" . "http://www.ics.forth.gr/isl/VoIDWarehouse/VoID_Extension_Schema.owl#")
    ("volt" . "http://volt-name.space/ontology/")
    ("vort" . "http://rockets.topbraid.solutions/vort/")
    ("vote" . "http://www.rdfabout.com/rdf/schema/vote/")
    ("vph" . "http://purl.org/ozo/vph.owl#")
    ("vplan" . "http://www.ifs.tuwien.ac.at/~miksa/ontologies/VPlan.owl#")
    ("vr" . "https://www.w3.org/2018/credentials/v1/")
    ("vra" . "http://purl.org/vra/")
    ("vrank" . "http://purl.org/voc/vrank#")
    ("vs" . "http://www.w3.org/2003/06/sw-vocab-status/ns#")
    ("vsearch" . "http://vocab.sti2.at/vsearch#")
    ("vso" . "http://purl.org/vso/ns#")
    ("vsr" . "http://purl.org/twc/vocab/vsr#")
    ("vss" . "http://automotive.eurecom.fr/vsso#")
    ("vsso" . "http://automotive.eurecom.fr/vsso#")
    ("vsto" . "http://escience.rpi.edu/ontology/vsto/2/0/vsto.owl#")
    ("vstoi" . "http://hadatac.org/ont/vstoi#")
    ("vsw" . "http://verticalsearchworks.com/ontology/")
    ("vsws" . "http://verticalsearchworks.com/ontology/synset#")
    ("vvo" . "http://purl.org/vvo/ns#")
    ("w3" . "http://www.w3.org/")
    ("w3cgeo" . "http://www.w3.org/2003/01/geo/wgs84_pos#")
    ("w3con" . "http://www.w3.org/2000/10/swap/pim/contact#")
    ("w3geo" . "http://www.w3.org/2003/01/geo/wgs84_pos#")
    ("w3id" . "https://w3id.org/")
    ("w3p" . "http://prov4j.org/w3p/")
    ("w3po" . "http://purl.org/provenance/w3p/w3po#")
    ("waa" . "http://purl.oclc.org/NET/WebApiAuthentication#")
    ("waarde" . "https://lod.milieuinfo.be/ns/waarde#")
    ("wab" . "http://wab.uib.no/cost-a32_philospace/wittgenstein.owl#")
    ("wai" . "http://purl.org/wai#")
    ("wail" . "http://www.eyrie.org/~zednenem/2002/wail/")
    ("wairole" . "http://www.w3.org/2005/01/wai-rdf/GUIRoleTaxonomy#")
    ("walmart" . "https://www.amazon.de/")
    ("wao" . "http://webtlab.it.uc3m.es/2010/10/WebAppsOntology#")
    ("wapp" . "http://ns.rww.io/wapp#")
    ("wasa" . "http://vocab.sti2.at/wasa/")
    ("water" . "http://escience.rpi.edu/ontology/semanteco/2/0/water.owl#")
    ("wb" . "http://data.worldbank.org/")
    ("wbc" . "http://worldbank.270a.info/classification/")
    ("wbp" . "http://worldbank.270a.info/property/")
    ("wd" . "http://www.wikidata.org/entity/")
    ("wde" . "http://www.wikidata.org/entity/")
    ("wdno" . "http://www.wikidata.org/prop/novalue/")
    ("wdr" . "http://www.w3.org/2007/05/powder#")
    ("wdrs" . "http://www.w3.org/2007/05/powder-s#")
    ("wds" . "http://www.wikidata.org/entity/statement/")
    ("wdt" . "http://www.wikidata.org/prop/direct/")
    ("wdtn" . "http://www.wikidata.org/prop/direct-normalized/")
    ("wdv" . "http://www.wikidata.org/value/")
    ("web" . "http://www.w3.org/2007/uwa/context/web.owl#")
    ("webac" . "http://fedora.info/definitions/v4/webac#")
    ("webbox" . "http://webbox.ecs.soton.ac.uk/ns#")
    ("webservice" . "http://www.openlinksw.com/ontology/webservices#")
    ("webtlab" . "http://webtlab.it.uc3m.es/")
    ("weki" . "https://en.wikipedia.org/wiki/")
    ("wf" . "http://www.w3.org/2005/01/wf/flow#")
    ("wf4ever" . "http://purl.org/wf4ever/wf4ever#")
    ("wfdesc" . "http://purl.org/wf4ever/wfdesc#")
    ("wfm" . "http://purl.org/net/wf-motifs#")
    ("wfn" . "http://webofcode.org/wfn/")
    ("wfont" . "https://w3id.org/wfont#")
    ("wfprov" . "http://purl.org/wf4ever/wfprov#")
    ("wfs" . "http://schemas.opengis.net/wfs/")
    ("wgs" . "http://www.w3.org/2003/01/geo/wgs84_pos#")
    ("wgs84" . "http://www.w3.org/2003/01/geo/wgs84_pos#")
    ("wgspos" . "http://www.w3.org/2003/01/geo/wgs84_pos#")
    ("whisky" . "http://vocab.org/whisky/terms/")
    ("who" . "http://www.who.int/vocab/ontology#")
    ("whois" . "http://www.kanzaki.com/ns/whois#")
    ("wi" . "http://purl.org/ontology/wi/core#")
    ("wiki" . "http://en.wikipedia.org/wiki/")
    ("wikibase" . "http://wikiba.se/ontology#")
    ("wikidata" . "http://www.wikidata.org/entity/")
    ("wikim" . "http://spi-fm.uca.es/spdef/models/genericTools/wikim/1.0#")
    ("wikimedia" . "http://upload.wikimedia.org/wikipedia/commons/f/f6/")
    ("wikipedia" . "https://en.wikipedia.org/wiki/")
    ("wikterms" . "http://wiktionary.dbpedia.org/terms/")
    ("wild" . "http://purl.org/wild/vocab#")
    ("wimpo" . "http://rdfex.org/withImports?uri=")
    ("wisski" . "http://wiss-ki.eu/")
    ("wkd" . "http://schema.wolterskluwer.de/")
    ("wl" . "http://www.wsmo.org/ns/wsmo-lite#")
    ("wlo" . "http://purl.org/ontology/wo/")
    ("wlp" . "http://weblab-project.org/core/model/property/processing/")
    ("wm" . "http://ns.inria.fr/webmarks#")
    ("wn" . "http://xmlns.com/wordnet/1.6/")
    ("wn20" . "http://www.w3.org/2006/03/wn/wn20/")
    ("wn20schema" . "http://www.w3.org/2006/03/wn/wn20/schema/")
    ("wn30" . "http://purl.org/vocabularies/princeton/wn30/")
    ("wn31" . "http://wordnet-rdf.princeton.edu/wn31/")
    ("wno" . "http://wordnet-rdf.princeton.edu/ontology#")
    ("wnschema" . "http://www.cogsci.princeton.edu/~wn/schema/")
    ("wo" . "http://purl.org/ontology/wo/")
    ("won" . "https://w3id.org/won/core#")
    ("wordmap" . "http://purl.org/net/ns/wordmap#")
    ("wordnet" . "http://wordnet-rdf.princeton.edu/ontology#")
    ("worldbank" . "http://worldbank.270a.info/dataset/")
    ("wot" . "http://xmlns.com/wot/0.1/")
    ("wotc" . "http://purl.org/wot-catalogue#")
    ("wotsec" . "https://www.w3.org/2019/wot/security#")
    ("wp" . "http://vocabularies.wikipathways.org/wp#")
    ("wro" . "http://purl.org/net/wf4ever/ro#")
    ("wrroc" . "https://w3id.org/ro/terms/workflow-run#")
    ("ws" . "http://www.w3.org/ns/pim/space#")
    ("wsc" . "http://www.openk.org/wscaim.owl#")
    ("wscaim" . "http://www.openk.org/wscaim.owl#")
    ("wsdl" . "http://www.w3.org/ns/wsdl-rdf#")
    ("wsl" . "http://www.wsmo.org/ns/wsmo-lite#")
    ("wv" . "http://vocab.org/waiver/terms/")
    ("xapi" . "https://w3id.org/xapi/ontology#")
    ("xbrli" . "http://www.xbrl.org/2003/instance#")
    ("xbrll" . "https://w3id.org/vocab/xbrll#")
    ("xch" . "http://oanda2rdf.appspot.com/xch/")
    ("xcql" . "http://docs.oasis-open.org/ns/search-ws/xcql#")
    ("xds" . "http://www.w3.org/2001/XMLSchema#")
    ("xen" . "http://buzzword.org.uk/rdf/xen#")
    ("xesam" . "http://freedesktop.org/standards/xesam/1.0/core#")
    ("xf" . "http://www.w3.org/2002/xforms/")
    ("xfn" . "http://gmpg.org/xfn/11#")
    ("xfnv" . "http://vocab.sindice.com/xfn#")
    ("xforms" . "http://www.w3.org/2002/xforms/")
    ("xhe" . "http://buzzword.org.uk/rdf/xhtml-elements#")
    ("xhtml" . "http://www.w3.org/1999/xhtml#")
    ("xhtmlvocab" . "http://www.w3.org/1999/xhtml/vocab/")
    ("xhv" . "http://www.w3.org/1999/xhtml/vocab#")
    ("xkos" . "http://rdf-vocabulary.ddialliance.org/xkos#")
    ("xl" . "http://langegger.at/xlwrap/vocab#")
    ("xlime" . "http://xlime-project.org/vocab/")
    ("xlink" . "https://es.scribd.com/doc/79794476/05-Ejercicios-Resueltos-Caja-Negra-y-Recapitulacion/")
    ("xml" . "http://www.w3.org/XML/1998/namespace/")
    ("xmlns" . "http://xmlns.com/foaf/0.1/")
    ("xmls" . "http://www.w3.org/2001/XMLSchema#")
    ("xmp" . "http://ns.adobe.com/xap/1.0/")
    ("xrd" . "http://docs.oasis-open.org/ns/xri/xrd-1.0#")
    ("xro" . "http://purl.org/xro/ns#")
    ("xs" . "http://www.w3.org/2001/XMLSchema#")
    ("xsd" . "http://www.w3.org/2001/XMLSchema#")
    ("xsi" . "http://www.w3.org/2001/XMLSchema-instance#")
    ("xsl" . "http://www.w3.org/1999/XSL/Transform#")
    ("xslopm" . "http://purl.org/net/opmv/types/xslt#")
    ("xt" . "http://purl.org/twc/vocab/cross-topix#")
    ("xtypes" . "http://purl.org/xtypes/")
    ("xyz" . "http://sparql.xyz/facade-x/data/")
    ("ya" . "http://blogs.yandex.ru/schema/foaf/")
    ("yaco" . "https://www.irit.fr/recherches/MELODI/ontologies/cinema#")
    ("yago" . "http://yago-knowledge.org/resource/")
    ("yandex" . "http://yandex.ru/")
    ("yanice" . "http://yanice-boady.webflow.io/")
    ("yd" . "https://yodata.io/")
    ("year" . "http://www.w3.org/year/")
    ("yo" . "http://yovisto.com/")
    ("yoda" . "http://purl.org/NET/yoda#")
    ("ypc" . "http://www.semanticweb.org/sunsr/ontologies/2024/ypc#")
    ("yso" . "http://www.yso.fi/onto/yso/")
    ("zbwext" . "http://zbw.eu/namespaces/zbw-extensions/")
    ("zem" . "http://s.zemanta.com/ns#")
    ("zoology" . "http://purl.org/NET/biol/zoology#")
    ("zoomaterms" . "http://rdf.ebi.ac.uk/vocabulary/zooma/")
    ("zr" . "http://explain.z3950.org/dtd/2.0/")))

(defvar rdf-prefix-history nil
  "History list for RDF prefix lookup.")

(defun rdf-prefix-lookup (prefix)
  "Return URI associated with PREFIX.
Prefixes are defined by the variable `rdf-prefix-alist'."
  (cdr (assoc prefix rdf-prefix-alist)))

;;;###autoload
(defun rdf-prefix-insert (prefix)
  "Insert URI associated with PREFIX.
Prefixes are defined by the variable `rdf-prefix-alist'."
  (interactive
   (let ((completion-ignore-case t))
     (list (completing-read
            "RDF prefix: " rdf-prefix-alist nil t nil 'rdf-prefix-history))))
  (insert (rdf-prefix-lookup prefix)))

(provide 'rdf-prefix)

;;; rdf-prefix.el ends here
